'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

var overlays = require('@react-native-aria/overlays');
var reactNative = require('react-native');
var cssToReactNative = require('css-to-react-native');
var React = require('react');
var PropTypes = require('prop-types');
var invariant = require('tiny-invariant');
var focus = require('@react-native-aria/focus');
var reactNativeSvg = require('react-native-svg');

function _interopDefaultLegacy (e) { return e && typeof e === 'object' && 'default' in e ? e : { 'default': e }; }

var React__default = /*#__PURE__*/_interopDefaultLegacy(React);
var PropTypes__default = /*#__PURE__*/_interopDefaultLegacy(PropTypes);
var invariant__default = /*#__PURE__*/_interopDefaultLegacy(invariant);

const checkFunction = (char, silent) => {
  if (typeof char !== 'function') {
    return true;
  }
  if (silent) {
    return false;
  }
  throw new Error("CSS syntax error: Unexpected function.");
};
class InputStream {
  constructor(fragments) {
    for (var _len = arguments.length, tags = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
      tags[_key - 1] = arguments[_key];
    }
    this.dictionary = fragments.reduce((result, current, i) => {
      const value = current.split('');
      const tag = tags[i - 1];
      if (!tag) {
        return [...result, ...value];
      }
      if (typeof tag !== 'string') {
        return [...result, tag, ...value];
      }
      return [...result, ...tag.split(''), ...value];
    });
    this.cursor = 0;
  }
  peek() {
    let offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    return this.dictionary[this.cursor + offset];
  }
  read(marker) {
    const char = this.peek();
    if (marker && marker !== char) {
      throw new Error("CSS syntax error: Expected \"".concat(marker, "\", but found \"").concat(char, "\""));
    }
    if (this.remainingChars() === 0) {
      throw new Error("CSS syntax error: Unexpected end of string.");
    }
    this.cursor += 1;
    return char;
  }
  charsWhile(check) {
    let silent = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : false;
    let value = '';
    while (checkFunction(this.peek(), silent) && check(this.peek())) {
      value += this.read();
    }
    return value;
  }
  remainingChars() {
    return this.dictionary.length - this.cursor;
  }
}

function isIdent(char) {
  return /[a-z0-9_-]/i.test(char);
}

function isWhitespace(char) {
  return /\s/.test(char);
}

const breaksDeclaration = char => typeof char !== 'function' && char !== '$' && char !== ';' && char !== '}' &&
// char !== '(' &&
char !== '';
const declaration = {
  locate(input) {
    return /[a-z_]/i.test(input.peek());
  },
  read(input) {
    // Parse name.
    const name = input.charsWhile(isIdent);

    // Parse whitespaces, separator
    input.charsWhile(isWhitespace);
    input.read(':');
    input.charsWhile(isWhitespace, true);

    // Parse value.
    const value = [];
    do {
      // Add function to resolve variable.
      if (input.peek() === '$') {
        input.read('$');
        const variableName = input.charsWhile(isIdent);
        value.push(variables => {
          if (variables[variableName] === undefined) {
            throw new Error("Variable $".concat(variableName, " is not defined."));
          }
          return variables[variableName];
        });
      }

      // Add function.
      if (typeof input.peek() === 'function') {
        value.push(input.read());
      }
      const part = input.charsWhile(breaksDeclaration, true);

      // TODO: Parse functions
      /* if (input.peek() === '(') {
        } */

      if (part.length > 0) {
        value.push(part);
      }
    } while (input.peek() === '$' || typeof input.peek() === 'function');
    if (input.peek() === ';') {
      input.read(';');
    }
    return {
      type: 'declaration',
      name,
      value
    };
  }
};

const variable = {
  locate(input) {
    return input.peek() === '$';
  },
  read(input) {
    input.read('$');
    if (!declaration.locate(input)) {
      throw new Error("CSS syntax error: Unexpected char after $.");
    }
    const {
      name,
      value
    } = declaration.read(input);
    return {
      type: 'variable',
      name,
      value
    };
  }
};

const consumeArgumentSeperator = input => {
  if (input.peek() !== ',') {
    return false;
  }
  input.read(',');
  return true;
};
const directive = {
  locate(input) {
    return input.peek() === '@';
  },
  read(input, parseBlock) {
    input.read('@');
    const directiveName = input.charsWhile(isIdent);
    if (directiveName !== 'include') {
      throw new Error('Only @include directive is supported.');
    }
    input.charsWhile(isWhitespace);
    const name = input.charsWhile(isIdent);
    if (name.length === 0) {
      throw new Error('No name.');
    }
    input.charsWhile(isWhitespace);
    input.read('(');
    const args = [];
    do {
      input.charsWhile(isWhitespace);
      args.push(input.charsWhile(isIdent));
      input.charsWhile(isWhitespace);
    } while (consumeArgumentSeperator(input));
    input.read(')');
    input.charsWhile(isWhitespace);
    input.read('{');
    const children = [];
    while (input.peek() !== '}') {
      const block = parseBlock(input);
      if (block) {
        children.push(block);
      }
    }
    input.read('}');
    return {
      type: 'block',
      scopes: [{
        type: 'mixin',
        name,
        args
      }],
      children
    };
  }
};

const SELECTOR_TYPES = ['hover', 'focus', 'focus-visible', 'active'];
const selector = {
  locate(input) {
    return input.peek() === '&' && input.peek(1) === ':';
  },
  read(input, parseBlock) {
    input.read('&');
    input.read(':');
    const name = input.charsWhile(isIdent);
    if (!SELECTOR_TYPES.includes(name)) {
      throw new Error("CSS syntax error: Unexpected selector name \"".concat(name, "\"."));
    }
    input.charsWhile(isWhitespace);
    input.read('{');
    const children = [];
    while (input.peek() !== '}') {
      const block = parseBlock(input);
      if (block) {
        children.push(block);
      }
    }
    input.read('}');
    return {
      type: 'block',
      scopes: [{
        type: 'selector',
        name
      }],
      children
    };
  }
};

const consumeAsterisk = input => {
  input.read('*');
  if (input.peek() === '/') {
    input.read('/');
    return false;
  }
  return true;
};
const comment = {
  locate(input) {
    return input.peek() === '/' && (input.peek(1) === '*' || input.peek(1) === '/');
  },
  read(input) {
    input.read('/');

    // Read until new line for inline comments
    if (input.peek() === '/') {
      input.read('/');
      input.charsWhile(char => char !== '\n');
      return null;
    }
    input.read('*');

    // Read until comment ending
    do {
      input.charsWhile(char => char !== '*');
    } while (consumeAsterisk(input));
    return null;
  }
};

function parseBlock(input) {
  if (isWhitespace(input.peek())) {
    input.charsWhile(isWhitespace);
    return null;
  }
  if (variable.locate(input)) {
    return variable.read(input);
  }
  if (declaration.locate(input)) {
    return declaration.read(input);
  }
  if (selector.locate(input)) {
    return selector.read(input, parseBlock);
  }
  if (directive.locate(input)) {
    return directive.read(input, parseBlock);
  }
  if (comment.locate(input)) {
    return comment.read(input);
  }
  throw new Error("CSS syntax error: Unknown error at \"".concat(input.peek(), "\""));
}

function parse() {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }
  const input = new InputStream(...args);
  const children = [];
  while (input.remainingChars() > 0) {
    const block = parseBlock(input);
    if (block) {
      children.push(block);
    }
  }
  return {
    type: 'root',
    children
  };
}

function ownKeys(e, r) {
  var t = Object.keys(e);
  if (Object.getOwnPropertySymbols) {
    var o = Object.getOwnPropertySymbols(e);
    r && (o = o.filter(function (r) {
      return Object.getOwnPropertyDescriptor(e, r).enumerable;
    })), t.push.apply(t, o);
  }
  return t;
}
function _objectSpread2(e) {
  for (var r = 1; r < arguments.length; r++) {
    var t = null != arguments[r] ? arguments[r] : {};
    r % 2 ? ownKeys(Object(t), !0).forEach(function (r) {
      _defineProperty(e, r, t[r]);
    }) : Object.getOwnPropertyDescriptors ? Object.defineProperties(e, Object.getOwnPropertyDescriptors(t)) : ownKeys(Object(t)).forEach(function (r) {
      Object.defineProperty(e, r, Object.getOwnPropertyDescriptor(t, r));
    });
  }
  return e;
}
function _defineProperty(obj, key, value) {
  key = _toPropertyKey(key);
  if (key in obj) {
    Object.defineProperty(obj, key, {
      value: value,
      enumerable: true,
      configurable: true,
      writable: true
    });
  } else {
    obj[key] = value;
  }
  return obj;
}
function _extends() {
  _extends = Object.assign ? Object.assign.bind() : function (target) {
    for (var i = 1; i < arguments.length; i++) {
      var source = arguments[i];
      for (var key in source) {
        if (Object.prototype.hasOwnProperty.call(source, key)) {
          target[key] = source[key];
        }
      }
    }
    return target;
  };
  return _extends.apply(this, arguments);
}
function _objectDestructuringEmpty(obj) {
  if (obj == null) throw new TypeError("Cannot destructure " + obj);
}
function _objectWithoutPropertiesLoose(source, excluded) {
  if (source == null) return {};
  var target = {};
  var sourceKeys = Object.keys(source);
  var key, i;
  for (i = 0; i < sourceKeys.length; i++) {
    key = sourceKeys[i];
    if (excluded.indexOf(key) >= 0) continue;
    target[key] = source[key];
  }
  return target;
}
function _objectWithoutProperties(source, excluded) {
  if (source == null) return {};
  var target = _objectWithoutPropertiesLoose(source, excluded);
  var key, i;
  if (Object.getOwnPropertySymbols) {
    var sourceSymbolKeys = Object.getOwnPropertySymbols(source);
    for (i = 0; i < sourceSymbolKeys.length; i++) {
      key = sourceSymbolKeys[i];
      if (excluded.indexOf(key) >= 0) continue;
      if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue;
      target[key] = source[key];
    }
  }
  return target;
}
function _taggedTemplateLiteral(strings, raw) {
  if (!raw) {
    raw = strings.slice(0);
  }
  return Object.freeze(Object.defineProperties(strings, {
    raw: {
      value: Object.freeze(raw)
    }
  }));
}
function _toPrimitive(input, hint) {
  if (typeof input !== "object" || input === null) return input;
  var prim = input[Symbol.toPrimitive];
  if (prim !== undefined) {
    var res = prim.call(input, hint || "default");
    if (typeof res !== "object") return res;
    throw new TypeError("@@toPrimitive must return a primitive value.");
  }
  return (hint === "string" ? String : Number)(input);
}
function _toPropertyKey(arg) {
  var key = _toPrimitive(arg, "string");
  return typeof key === "symbol" ? key : String(key);
}

const transformREMUnitRE = /([+-]+)?([\d.Ee]+)rem/g;
const convertRemToPx = value => reactNative.PixelRatio.getFontScale() * 16 * value;
function rem(value) {
  if (reactNative.Platform.OS === 'web') {
    return value;
  }
  return value.replace(transformREMUnitRE, function (_) {
    let unary = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    let number = arguments.length > 2 ? arguments[2] : undefined;
    return "".concat(unary).concat(convertRemToPx(number), "px");
  });
}

const valueRE = /^([+-]?(?:\d+|\d*\.\d+))(rem|px|%)?$/;
class UnitValue {
  constructor(value) {
    let unit = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'number';
    _defineProperty(this, "value", void 0);
    _defineProperty(this, "unit", void 0);
    this.value = value;
    this.unit = unit;
  }
  static parse(value) {
    if (value instanceof UnitValue) {
      return value;
    }
    if (typeof value === 'number') {
      return new UnitValue(value, 'number');
    }
    const match = value.match(valueRE);
    if (!match) {
      throw new Error("Cannot parse number \"".concat(value, "\"."));
    }
    return new UnitValue(parseFloat(match[1]), match[2] === '%' ? 'percent' : match[2]);
  }
  toNumber() {
    if (this.unit === 'percent') {
      return this.value / 100;
    }
    if (this.unit === 'rem') {
      return this.value * reactNative.PixelRatio.getFontScale() * 16;
    }
    return this.value;
  }
  toString() {
    if (this.unit === 'number') {
      return this.value;
    }
    if (this.unit === 'percent') {
      return "".concat(this.value, "%");
    }
    return "".concat(this.value).concat(this.unit);
  }
}

const POWER = 10 ** 8;
const UNIT_ORDER = ['percent', 'number', 'px', 'rem'];
const fixRounding = value => Math.round(value * POWER) / POWER;
const normalizeValue$1 = (number1, number2) => {
  if (number1.unit === 'px' && number2.unit === 'rem') {
    return number1.value / (reactNative.PixelRatio.getFontScale() * 16);
  }
  if (number1.unit === 'percent' && number2.unit !== 'percent') {
    return number1.value / 100;
  }
  return number1.value;
};
const calculateValue = (number1, operator, number2) => {
  const value1 = normalizeValue$1(number1, number2);
  const value2 = normalizeValue$1(number2, number1);
  switch (operator) {
    case '+':
      return value1 + value2;
    case '-':
      return value1 - value2;
    case '*':
      return fixRounding(value1 * value2);
    case '/':
      return fixRounding(value1 / value2);
    case '%':
      return value1 % value2;
    default:
      throw new Error('Unknown operator.');
  }
};
const determineUnit = (number1, number2) => {
  const index1 = UNIT_ORDER.indexOf(number1.unit);
  const index2 = UNIT_ORDER.indexOf(number2.unit);
  return index1 > index2 ? number1.unit : number2.unit;
};
function calculate(value1, operator, value2) {
  const number1 = UnitValue.parse(value1);
  const number2 = UnitValue.parse(value2);
  const value = calculateValue(number1, operator, number2);
  const unit = determineUnit(number1, number2);
  return new UnitValue(value, unit).toString();
}
function normalizeNumber(value) {
  return UnitValue.parse(value).toNumber();
}

const formulaRE = /([+-]+)?([\d.Ee]+)(rem|px|%)?\s*(\+|-|\*|%)\s*([+-]+)?([\d.Ee]+)(rem|px|%)?/g;
function formula(value) {
  // Naïve approach to calculate simple formulas.
  // TODO: Support more complex formulas including parenthesis.
  return value.replace(formulaRE, function (_) {
    let leftUnary = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : '';
    let leftNumber = arguments.length > 2 ? arguments[2] : undefined;
    let leftUnit = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : '';
    let operator = arguments.length > 4 ? arguments[4] : undefined;
    let rightUnary = arguments.length > 5 && arguments[5] !== undefined ? arguments[5] : '';
    let rightNumber = arguments.length > 6 ? arguments[6] : undefined;
    let rightUnit = arguments.length > 7 && arguments[7] !== undefined ? arguments[7] : '';
    const leftValue = "".concat(leftUnary).concat(leftNumber).concat(leftUnit);
    const rightValue = "".concat(rightUnary).concat(rightNumber).concat(rightUnit);
    return calculate(leftValue, operator, rightValue);
  });
}

// Copied from https://github.com/styled-components/polished/blob/main/src/color/parseToRgb.js
const hexRE = /^#[a-fA-F0-9]{6}$/;
const hexRgbaRE = /^#[a-fA-F0-9]{8}$/;
const shortHexRE = /^#[a-fA-F0-9]{3}$/;
const shortRgbaHexRE = /^#[a-fA-F0-9]{4}$/;
const rgbRE = /^rgb\(\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*\)$/i;
const rgbaRE = /^rgb(?:a)?\(\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,)?\s*(\d{1,3})\s*(?:,|\/)\s*([-+]?\d*[.]?\d+[%]?)\s*\)$/i;
const hslRE = /^hsl\(\s*(\d{0,3}[.]?[0-9]+(?:deg)?)\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*\)$/i;
const hslaRE = /^hsl(?:a)?\(\s*(\d{0,3}[.]?[0-9]+(?:deg)?)\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,)?\s*(\d{1,3}[.]?[0-9]?)%\s*(?:,|\/)\s*([-+]?\d*[.]?\d+[%]?)\s*\)$/i;

// Copied from https://reactnative.dev/docs/colors
// prettier-ignore
const colorNames = {
  aliceblue: '#f0f8ff',
  antiquewhite: '#faebd7',
  aqua: '#00ffff',
  aquamarine: '#7fffd4',
  azure: '#f0ffff',
  beige: '#f5f5dc',
  bisque: '#ffe4c4',
  black: '#000000',
  blanchedalmond: '#ffebcd',
  blue: '#0000ff',
  blueviolet: '#8a2be2',
  brown: '#a52a2a',
  burlywood: '#deb887',
  cadetblue: '#5f9ea0',
  chartreuse: '#7fff00',
  chocolate: '#d2691e',
  coral: '#ff7f50',
  cornflowerblue: '#6495ed',
  cornsilk: '#fff8dc',
  crimson: '#dc143c',
  cyan: '#00ffff',
  darkblue: '#00008b',
  darkcyan: '#008b8b',
  darkgoldenrod: '#b8860b',
  darkgray: '#a9a9a9',
  darkgreen: '#006400',
  darkgrey: '#a9a9a9',
  darkkhaki: '#bdb76b',
  darkmagenta: '#8b008b',
  darkolivegreen: '#556b2f',
  darkorange: '#ff8c00',
  darkorchid: '#9932cc',
  darkred: '#8b0000',
  darksalmon: '#e9967a',
  darkseagreen: '#8fbc8f',
  darkslateblue: '#483d8b',
  darkslategrey: '#2f4f4f',
  darkturquoise: '#00ced1',
  darkviolet: '#9400d3',
  deeppink: '#ff1493',
  deepskyblue: '#00bfff',
  dimgray: '#696969',
  dimgrey: '#696969',
  dodgerblue: '#1e90ff',
  firebrick: '#b22222',
  floralwhite: '#fffaf0',
  forestgreen: '#228b22',
  fuchsia: '#ff00ff',
  gainsboro: '#dcdcdc',
  ghostwhite: '#f8f8ff',
  gold: '#ffd700',
  goldenrod: '#daa520',
  gray: '#808080',
  green: '#008000',
  greenyellow: '#adff2f',
  grey: '#808080',
  honeydew: '#f0fff0',
  hotpink: '#ff69b4',
  indianred: '#cd5c5c',
  indigo: '#4b0082',
  ivory: '#fffff0',
  khaki: '#f0e68c',
  lavender: '#e6e6fa',
  lavenderblush: '#fff0f5',
  lawngreen: '#7cfc00',
  lemonchiffon: '#fffacd',
  lightblue: '#add8e6',
  lightcoral: '#f08080',
  lightcyan: '#e0ffff',
  lightgoldenrodyellow: '#fafad2',
  lightgray: '#d3d3d3',
  lightgreen: '#90ee90',
  lightgrey: '#d3d3d3',
  lightpink: '#ffb6c1',
  lightsalmon: '#ffa07a',
  lightseagreen: '#20b2aa',
  lightskyblue: '#87cefa',
  lightslategrey: '#778899',
  lightsteelblue: '#b0c4de',
  lightyellow: '#ffffe0',
  lime: '#00ff00',
  limegreen: '#32cd32',
  linen: '#faf0e6',
  magenta: '#ff00ff',
  maroon: '#800000',
  mediumaquamarine: '#66cdaa',
  mediumblue: '#0000cd',
  mediumorchid: '#ba55d3',
  mediumpurple: '#9370db',
  mediumseagreen: '#3cb371',
  mediumslateblue: '#7b68ee',
  mediumspringgreen: '#00fa9a',
  mediumturquoise: '#48d1cc',
  mediumvioletred: '#c71585',
  midnightblue: '#191970',
  mintcream: '#f5fffa',
  mistyrose: '#ffe4e1',
  moccasin: '#ffe4b5',
  navajowhite: '#ffdead',
  navy: '#000080',
  oldlace: '#fdf5e6',
  olive: '#808000',
  olivedrab: '#6b8e23',
  orange: '#ffa500',
  orangered: '#ff4500',
  orchid: '#da70d6',
  palegoldenrod: '#eee8aa',
  palegreen: '#98fb98',
  paleturquoise: '#afeeee',
  palevioletred: '#db7093',
  papayawhip: '#ffefd5',
  peachpuff: '#ffdab9',
  peru: '#cd853f',
  pink: '#ffc0cb',
  plum: '#dda0dd',
  powderblue: '#b0e0e6',
  purple: '#800080',
  rebeccapurple: '#663399',
  red: '#ff0000',
  rosybrown: '#bc8f8f',
  royalblue: '#4169e1',
  saddlebrown: '#8b4513',
  salmon: '#fa8072',
  sandybrown: '#f4a460',
  seagreen: '#2e8b57',
  seashell: '#fff5ee',
  sienna: '#a0522d',
  silver: '#c0c0c0',
  skyblue: '#87ceeb',
  slateblue: '#6a5acd',
  slategray: '#708090',
  snow: '#fffafa',
  springgreen: '#00ff7f',
  steelblue: '#4682b4',
  tan: '#d2b48c',
  teal: '#008080',
  thistle: '#d8bfd8',
  tomato: '#ff6347',
  turquoise: '#40e0d0',
  violet: '#ee82ee',
  wheat: '#f5deb3',
  white: '#ffffff',
  whitesmoke: '#f5f5f5',
  yellow: '#ffff00',
  yellowgreen: '#9acd32'
};
const hslToRgb = (h, s, l) => {
  const a = s * Math.min(l, 1 - l);
  const f = function (n) {
    let k = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : (n + h / 30) % 12;
    return l - a * Math.max(Math.min(k - 3, 9 - k, 1), -1);
  };
  return [f(0), f(8), f(4)];
};
class RgbaValue {
  constructor(red, green, blue) {
    let alpha = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : 1;
    _defineProperty(this, "red", void 0);
    _defineProperty(this, "green", void 0);
    _defineProperty(this, "blue", void 0);
    _defineProperty(this, "alpha", void 0);
    this.red = red;
    this.green = green;
    this.blue = blue;
    this.alpha = alpha;
  }
  static parse(value) {
    if (value instanceof RgbaValue) {
      return value;
    }
    const color = colorNames[value] || value;

    // Handle hex value
    const hexMatch = color.match(hexRE) || color.match(hexRgbaRE) || color.match(shortHexRE) || color.match(shortRgbaHexRE);
    if (hexMatch) {
      const params = (hexMatch[0].length <= 4 ? hexMatch[0].match(/\w/g).map(x => "".concat(x).concat(x)) : hexMatch[0].match(/\w\w/g)).map((hex, key) => {
        const x = parseInt(hex, 16);
        const alpha = key === 3;
        return alpha ? (x / 255).toFixed(2) : x;
      });
      return new RgbaValue(...params);
    }

    // Handle rgb(a) value
    const rgbMatch = color.match(rgbRE) || color.match(rgbaRE);
    if (rgbMatch) {
      const params = rgbMatch.slice(1).map((x, key) => {
        const alpha = key === 3;
        return alpha ? parseFloat(x) : parseInt(x, 10);
      });
      return new RgbaValue(...params);
    }

    // Handle hsl(a) value
    const hslMatch = color.match(hslRE) || color.match(hslaRE);
    if (hslMatch) {
      const h = parseInt(hslMatch[1], 10);
      const s = parseInt(hslMatch[2], 10) / 100;
      const l = parseInt(hslMatch[3], 10) / 100;
      const alpha = hslMatch[4] && parseFloat(hslMatch[4]);
      return new RgbaValue(...[...hslToRgb(h, s, l), alpha]);
    }
    throw new Error("Unknown color \"".concat(value, "\"."));
  }
  toRgb() {
    return [this.red, this.green, this.blue];
  }
  toRgba() {
    return [...this.toRgb(), this.alpha];
  }
  toHex() {
    const [...values] = this.toRgb();
    if (this.alpha < 1) {
      values.push(this.alpha);
    }
    return "#".concat(values.map(x => {
      const hex = x.toString(16);
      return hex.length === 1 ? "0".concat(hex) : hex;
    }).join(''));
  }
}

// Sass equivalent
function rgba$1(value, alpha) {
  const color = RgbaValue.parse(value);
  return "rgba(".concat(color.red, ",").concat(color.green, ",").concat(color.blue, ",").concat(alpha, ")");
}

// Sass equivalent
function opacity(value) {
  return RgbaValue.parse(value).alpha;
}

// Sass equivalent
function mix(color1, color2) {
  let weight = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : 0.5;
  const rgb1 = RgbaValue.parse(color1).toRgb();
  const rgb2 = RgbaValue.parse(color2).toRgb();
  const percentage = UnitValue.parse(weight).toNumber();
  const [r, g, b] = rgb1.map((value, key) => Math.round(rgb2[key] + (value - rgb2[key]) * percentage));
  return new RgbaValue(r, g, b).toHex();
}

const transformRgbaRE = /rgba\(\s*([#0-9a-z]+)\s*,\s*([\d.Ee]+)\s*\)/g;
function rgba(value) {
  return value.replace(transformRgbaRE, (_, hex, alpha) => rgba$1(hex, alpha));
}

// Spec: https://w3c.github.io/csswg-drafts/css-backgrounds/#the-background-size
function backgroundSize(value) {
  const values = value.split(' ');
  const [first, second = 'auto'] = values;
  if (values.length === 1) {
    return {
      backgroundSize: cssToReactNative.transformRawValue('backgroundSize', first)
    };
  }
  if (values.length === 2) {
    return {
      backgroundSize: {
        width: cssToReactNative.transformRawValue('backgroundSize', first),
        height: cssToReactNative.transformRawValue('backgroundSize', second)
      }
    };
  }
  return null;
}

const positionRE = /(top|right|bottom|left|center)/;
const sortPairs = (first, second) => {
  const firstValue = {
    position: first[0],
    offset: first[1] ? cssToReactNative.transformRawValue('backgroundPosition', first[1]) : undefined
  };
  const secondValue = {
    position: second[0],
    offset: second[1] ? cssToReactNative.transformRawValue('backgroundPosition', second[1]) : undefined
  };
  const shouldReversePairs = first[0] === 'top' || first[0] === 'bottom' || second[0] === 'left' || second[0] === 'right';
  return shouldReversePairs ? [secondValue, firstValue] : [firstValue, secondValue];
};

// Spec: https://w3c.github.io/csswg-drafts/css-backgrounds-3/#background-position
function backgroundPosition(value) {
  const values = value.split(' ');
  const [first, second = 'center', third, fourth] = values;
  if (values.length <= 2) {
    const [x, y] = sortPairs(first.match(positionRE) ? [first] : ['left', first], second.match(positionRE) ? [second] : ['top', second]);
    return {
      backgroundPositionX: x,
      backgroundPositionY: y
    };
  }
  if (values.length <= 4) {
    const [x, y] = second.match(positionRE) ? sortPairs([first], [second, third]) : sortPairs([first, second], [third, fourth]);
    return {
      backgroundPositionX: x,
      backgroundPositionY: y
    };
  }
  return null;
}

function backgroundPositionX(value) {
  const values = value.split(' ');
  const [first, second = 'auto'] = values;
  if (values.length === 1) {
    return {
      backgroundPositionX: cssToReactNative.transformRawValue('backgroundPositionX', first)
    };
  }
  if (values.length === 2) {
    return {
      backgroundPositionX: {
        position: cssToReactNative.transformRawValue('backgroundPositionX', first),
        offset: cssToReactNative.transformRawValue('backgroundPositionX', second)
      }
    };
  }
  return null;
}

function backgroundPositionY(value) {
  const values = value.split(' ');
  const [first, second = 'auto'] = values;
  if (values.length === 1) {
    return {
      backgroundPositionY: cssToReactNative.transformRawValue('backgroundPositionY', first)
    };
  }
  if (values.length === 2) {
    return {
      backgroundPositionY: {
        position: cssToReactNative.transformRawValue('backgroundPositionY', first),
        offset: cssToReactNative.transformRawValue('backgroundPositionY', second)
      }
    };
  }
  return null;
}

const urlRE = /^url\(.*?\)$/g;
const applyVariables = (variables, key, value) => typeof value === 'function' ? value(variables, key) : value;
const applyTransforms = result => {
  // Do not transform values that belong to an url().
  if (result.match(urlRE)) {
    return result;
  }
  return rgba(formula(rem(result)));
};
const resolveValue = (value, definition, theme, options) => {
  const variables = options.preferTheme ? _objectSpread2(_objectSpread2({}, definition.variables), theme) : _objectSpread2(_objectSpread2({}, theme), definition.variables);

  // If there is only one part, we allow other results than strings as well.
  if (value.length === 1) {
    const result = applyVariables(variables, options.key, value[0]);
    return typeof result === 'string' ? applyTransforms(result) : result;
  }
  const stringifiedResult = value.reduce((previous, current) => "".concat(previous).concat(applyVariables(variables, options.key, current)), '');
  return applyTransforms(stringifiedResult);
};
function transform(children, theme) {
  let options = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {};
  let scopes = arguments.length > 3 && arguments[3] !== undefined ? arguments[3] : [];
  let variables = arguments.length > 4 && arguments[4] !== undefined ? arguments[4] : {};
  let definitions = [{
    scopes,
    declarations: {},
    variables: _objectSpread2({}, variables)
  }];
  children.forEach(child => {
    if (child.type === 'variable' || child.type === 'declaration') {
      // Transform value to react native compatible value.
      const value = resolveValue(child.value, definitions[0], theme, options);
      if (child.type === 'variable') {
        definitions[0].variables[child.name] = value;
      }

      // Only add value if value is not null.
      if (child.type === 'declaration' && value !== 'null') {
        if (child.name === 'box-shadow') {
          if (reactNative.Platform.OS === 'web') {
            Object.assign(definitions[0].declarations, {
              boxShadow: value
            });
          }
        } else if (child.name === 'margin-vertical') {
          Object.assign(definitions[0].declarations, _objectSpread2(_objectSpread2({}, cssToReactNative.getStylesForProperty('marginTop', value)), cssToReactNative.getStylesForProperty('marginBottom', value)));
        } else if (child.name === 'margin-horizontal') {
          // Among other things workaround for react-native issue #350
          // https://github.com/facebook/react-native/issues/350#issuecomment-375238958
          Object.assign(definitions[0].declarations, _objectSpread2(_objectSpread2({}, cssToReactNative.getStylesForProperty('marginLeft', value)), cssToReactNative.getStylesForProperty('marginRight', value)));
        } else if (child.name === 'padding-vertical') {
          Object.assign(definitions[0].declarations, _objectSpread2(_objectSpread2({}, cssToReactNative.getStylesForProperty('paddingTop', value)), cssToReactNative.getStylesForProperty('paddingBottom', value)));
        } else if (child.name === 'padding-horizontal') {
          Object.assign(definitions[0].declarations, _objectSpread2(_objectSpread2({}, cssToReactNative.getStylesForProperty('paddingLeft', value)), cssToReactNative.getStylesForProperty('paddingRight', value)));
        } else if (child.name === 'background-size') {
          Object.assign(definitions[0].declarations, backgroundSize(value));
        } else if (child.name === 'background-position') {
          Object.assign(definitions[0].declarations, backgroundPosition(value));
        } else if (child.name === 'background-position-x') {
          Object.assign(definitions[0].declarations, backgroundPositionX(value));
        } else if (child.name === 'background-position-y') {
          Object.assign(definitions[0].declarations, backgroundPositionY(value));
        } else if (child.name === 'border-color' && value.split(' ').length === 1) {
          // Workaround for react-native issue #19981
          // https://github.com/facebook/react-native/issues/19981
          Object.assign(definitions[0].declarations, {
            borderColor: value
          });
        } else {
          // TODO: Pre-process css-to-react-native transformation, so that we only
          // need to insert theme variables here.
          Object.assign(definitions[0].declarations, cssToReactNative.getStylesForProperty(cssToReactNative.getPropertyName(child.name), value));
        }
      }
    }
    if (child.type === 'block') {
      definitions = definitions.concat(transform(child.children, theme, options,
      // Add child scopes to current scopes.
      [...scopes, ...child.scopes],
      // Pass down variables, so that we can extend them.
      definitions[0].variables));
    }
  });

  // Filter empty definitions and return.
  return definitions.filter(definition => Object.keys(definition.declarations).length > 0 || Object.keys(definition.variables).length > 0);
}

const mediaBreakpointUp$3 = {
  include() {
    return true;
  },
  apply(scope, _ref) {
    let {
      media
    } = _ref;
    return media.up(scope.args[0]) && media.down(scope.args[1]);
  }
};

const mediaBreakpointUp$2 = {
  include() {
    return true;
  },
  apply(scope, _ref) {
    let {
      media
    } = _ref;
    return media.down(scope.args[0]);
  }
};

const mediaBreakpointUp$1 = {
  include() {
    return true;
  },
  apply(scope, _ref) {
    let {
      media
    } = _ref;
    return media.up(scope.args[0]) && media.down(scope.args[0]);
  }
};

const mediaBreakpointUp = {
  include() {
    return true;
  },
  apply(scope, _ref) {
    let {
      media
    } = _ref;
    return media.up(scope.args[0]);
  }
};

const platform = {
  include(scope) {
    return scope.args[0] === 'native' ? reactNative.Platform.OS === 'android' || reactNative.Platform.OS === 'ios' : reactNative.Platform.OS === scope.args[0];
  },
  apply() {
    return true;
  }
};

const BOOTSTRAP_RN_STYLE = Symbol.for('bootstrap-rn.style');
const mixins = {
  'media-breakpoint-between': mediaBreakpointUp$3,
  'media-breakpoint-down': mediaBreakpointUp$2,
  'media-breakpoint-only': mediaBreakpointUp$1,
  'media-breakpoint-up': mediaBreakpointUp,
  platform
};
const hasInteraction = _ref => {
  let {
    scopes
  } = _ref;
  return scopes.some(scope => scope.type === 'selector');
};
function createStyle(definitions) {
  // If there is only one definition without conditions, return.
  if (definitions.length === 1 && definitions[0].scopes.length === 0) {
    return definitions[0].declarations;
  }

  // Filter definitions that should not be used based on mixins.
  const platformDefinitions = definitions.filter(item => item.scopes.every(scope => {
    if (scope.type !== 'mixin') {
      return true;
    }
    return mixins[scope.name].include(scope);
  }));

  // Create style sheets.
  const styles = reactNative.StyleSheet.create(_objectSpread2({}, platformDefinitions.map(item => item.declarations)));
  const resolve = state => {
    const {
      interaction
    } = state;
    const basicStyles = [];
    const interactionStyles = [];
    Object.values(styles).forEach((style, key) => {
      const active = platformDefinitions[key].scopes.every(scope => {
        if (scope.type === 'selector') {
          if (scope.name === 'hover') {
            return interaction && interaction.hover;
          }
          if (scope.name === 'focus') {
            return interaction && interaction.focus;
          }
          if (scope.name === 'focus-visible') {
            return interaction && interaction.focusVisible;
          }
          if (scope.name === 'active') {
            return interaction && interaction.active;
          }
        }
        if (scope.type === 'mixin') {
          return mixins[scope.name].apply(scope, state);
        }
        throw new Error("Unknown scope type \"".concat(scope.type, "\""));
      });
      if (active) {
        if (hasInteraction(platformDefinitions[key])) {
          interactionStyles.push(style);
        } else {
          basicStyles.push(style);
        }
      }
    });
    return [basicStyles, interactionStyles];
  };
  resolve.$$typeof = BOOTSTRAP_RN_STYLE;
  return resolve;
}

function css() {
  const ast = parse(...arguments);
  const result = (theme, key) => {
    const transformed = transform(ast.children, theme, {
      key
    });
    return createStyle(transformed);
  };
  result.ast = ast;
  return result;
}

function each(source, apply) {
  return Object.entries(source).map(_ref => {
    let [key, value] = _ref;
    const resolve = typeof value === 'function' ? value : () => value;
    return apply(key, resolve);
  }).reduce((carry, item) => Object.assign(carry, item), {});
}
function normalize$1(value) {
  return value.reduce((carry, item) => Object.assign(carry, item), {});
}
function makeProxy(name, keys) {
  return keys.reduce((result, key) => _objectSpread2(_objectSpread2({}, result), {}, {
    [key]: t => t[name][key]
  }), {});
}
function makeArray(length, callback) {
  return Array.from({
    length
  }, (_, i) => callback ? callback(i) : i);
}
function getStyles(styles, keys) {
  return keys.filter(key => !!key).map(key => styles[key]);
}
function concatRefs() {
  for (var _len = arguments.length, refs = new Array(_len), _key = 0; _key < _len; _key++) {
    refs[_key] = arguments[_key];
  }
  return element => {
    refs.forEach(ref => {
      if (typeof ref === 'function') {
        ref(element);
      } else if (ref) {
        // eslint-disable-next-line no-param-reassign
        ref.current = element;
      }
    });
  };
}
function optional(condition, value) {
  return condition ? value : undefined;
}
function getElementId(identifier, name) {
  return "".concat(identifier).concat(name ? "-".concat(name) : '');
}
function transformPlacement$1(placement) {
  switch (placement) {
    case 'left':
      return reactNative.I18nManager.isRTL ? 'end' : 'start';
    case 'right':
      return reactNative.I18nManager.isRTL ? 'start' : 'end';
    default:
      return placement;
  }
}

// These are proxy objects for the Bootstrap Sass maps that provide the map
// keys, but not the resolved values. The values are added later by the used
// theme.

// Color system

makeProxy('grays', ['100', '200', '300', '400', '500', '600', '700', '800', '900']);
makeProxy('colors', ['blue', 'indigo', 'purple', 'pink', 'red', 'orange', 'yellow', 'green', 'teal', 'cyan']);
const THEME_COLORS = makeProxy('theme-colors', ['primary', 'secondary', 'success', 'info', 'warning', 'danger', 'light', 'dark']);
makeProxy('blues', ['blue-100', 'blue-200', 'blue-300', 'blue-400', 'blue-500', 'blue-600', 'blue-700', 'blue-800', 'blue-900']);
makeProxy('indigos', ['indigo-100', 'indigo-200', 'indigo-300', 'indigo-400', 'indigo-500', 'indigo-600', 'indigo-700', 'indigo-800', 'indigo-900']);
makeProxy('purples', ['purple-100', 'purple-200', 'purple-300', 'purple-400', 'purple-500', 'purple-600', 'purple-700', 'purple-800', 'purple-900']);
makeProxy('pinks', ['pink-100', 'pink-200', 'pink-300', 'pink-400', 'pink-500', 'pink-600', 'pink-700', 'pink-800', 'pink-900']);
makeProxy('reds', ['red-100', 'red-200', 'red-300', 'red-400', 'red-500', 'red-600', 'red-700', 'red-800', 'red-900']);
makeProxy('oranges', ['orange-100', 'orange-200', 'orange-300', 'orange-400', 'orange-500', 'orange-600', 'orange-700', 'orange-800', 'orange-900']);
makeProxy('yellows', ['yellow-100', 'yellow-200', 'yellow-300', 'yellow-400', 'yellow-500', 'yellow-600', 'yellow-700', 'yellow-800', 'yellow-900']);
makeProxy('greens', ['green-100', 'green-200', 'green-300', 'green-400', 'green-500', 'green-600', 'green-700', 'green-800', 'green-900']);
makeProxy('teals', ['teal-100', 'teal-200', 'teal-300', 'teal-400', 'teal-500', 'teal-600', 'teal-700', 'teal-800', 'teal-900']);
makeProxy('cyans', ['cyan-100', 'cyan-200', 'cyan-300', 'cyan-400', 'cyan-500', 'cyan-600', 'cyan-700', 'cyan-800', 'cyan-900']);

// Spacing
//
// Control the default styling of most Bootstrap elements by modifying these
// variables. Mostly focused on spacing.
// You can add more entries to the $spacers map, should you need more variation.

const SPACERS = makeProxy('spacers', [0, 1, 2, 3, 4, 5]);

// Position
//
// Define the edge positioning anchors of the position utilities.

const POSITION_VALUES = makeProxy('position-values', [0, 50, 100]);

// Grid breakpoints
//
// Define the minimum dimensions at which your layout will change,
// adapting to different screen sizes, for use in media queries.

const GRID_BREAKPOINTS = makeProxy('grid-breakpoints', ['xs', 'sm', 'md', 'lg', 'xl', 'xxl']);

// Grid containers
//
// Define the maximum width of ".container" for different screen sizes.

const CONTAINER_MAX_WIDTHS = makeProxy('container-max-widths', ['sm', 'md', 'lg', 'xl', 'xxl']);

// Grid columns
//
// Set the number of columns and specify the width of the gutters.

const GRID_COLUMNS = 12;

// Components
//
// Define common padding and border radius sizes and more.

const BORDER_WIDTHS = makeProxy('border-widths', [1, 2, 3, 4, 5]);
makeProxy('aspect-ratios', ['1x1', '4x3', '16x9', '21x9']);

// Typography
//
// Font, line-height, and color for body text, headings, and more.

const FONT_SIZES = makeProxy('font-sizes', [1, 2, 3, 4, 5, 6]);
const DISPLAY_FONT_SIZES = makeProxy('display-font-sizes', [1, 2, 3, 4, 5, 6]);

// Forms

const FORM_VALIDATION_STATES = makeProxy('form-validation-states', ['valid', 'invalid']);

const UTILITIES_COLORS = THEME_COLORS;
const UTILITIES_TEXT_COLORS = _objectSpread2(_objectSpread2({}, UTILITIES_COLORS), {}, {
  black: t => t.black,
  white: t => t.white,
  body: t => t['body-color']
});
const UTILITIES_BG_COLORS = _objectSpread2(_objectSpread2({}, UTILITIES_COLORS), {}, {
  black: t => t.black,
  white: t => t.white,
  body: t => t['body-bg']
});
const NEGATIVE_SPACERS = each(SPACERS, (key, value) => {
  if (key === 0) {
    return null;
  }
  return {
    ["n".concat(key)]: t => "-".concat(value(t))
  };
});

const utilities = {
  align: {
    property: 'text-align-vertical',
    class: 'align',
    values: {
      // baseline: 'baseline',
      top: 'top',
      center: 'center',
      // 'middle',
      bottom: 'bottom'
      // 'text-bottom': 'text-bottom',
      // 'text-top': 'text-top',
    }
  },

  /* float: {
    responsive: true,
    property: 'float',
    values: {
      start: 'left',
      end: 'right',
      none: 'none',
    },
  }, */
  // Opacity utilities
  opacity: {
    property: 'opacity',
    values: {
      0: '0',
      25: '0.25',
      50: '0.5',
      75: '0.75',
      100: '1'
    }
  },
  overflow: {
    property: 'overflow',
    values: {
      // auto: 'auto',
      hidden: 'hidden',
      visible: 'visible',
      scroll: 'scroll'
    }
  },
  display: {
    responsive: true,
    print: true,
    property: 'display',
    class: 'd',
    values: {
      // inline: 'inline',
      // 'inline-block': 'inline-block',
      // block: 'block',
      // grid: 'grid',
      // table: 'table',
      // 'table-row': 'table-row',
      // 'table-cell': 'table-cell',
      flex: 'flex',
      // 'inline-flex': 'inline-flex',
      none: 'none'
    }
  },
  shadow: {
    property: 'box-shadow',
    class: 'shadow',
    values: {
      null: t => t['box-shadow'],
      sm: t => t['box-shadow-sm'],
      lg: t => t['box-shadow-lg'],
      none: 'none'
    }
  },
  position: {
    property: 'position',
    values: {
      // static: 'static',
      relative: 'relative',
      absolute: 'absolute'
      // fixed: 'fixed',
      // sticky: 'sticky',
    }
  },

  top: {
    property: 'top',
    values: POSITION_VALUES
  },
  bottom: {
    property: 'bottom',
    values: POSITION_VALUES
  },
  start: {
    property: 'left',
    class: 'start',
    values: POSITION_VALUES
  },
  end: {
    property: 'right',
    class: 'end',
    values: POSITION_VALUES
  },
  /* translateMiddle: {
    property: 'transform',
    class: 'translate-middle',
    values: {
      null: translate(-50%, -50%),
      x: translateX(-50%),
      y: translateY(-50%),
    },
  }, */
  border: {
    property: 'border',
    values: {
      null: t => "".concat(t['border-width'], " solid ").concat(t['border-color']),
      0: '0'
    }
  },
  // TODO: Find a way to write border-top as border-top-width, ...
  /* borderTop: {
    property: 'border-top',
    values: {
      null: (t) => `${t['border-width']} solid ${t['border-color']}`,
      0: '0',
    },
  }, */
  /* borderRight: {
    property: 'border-right',
    class: 'border-end',
    values: {
      null: (t) => `${t['border-width']} solid ${t['border-color']}`,
      0: '0',
    },
  }, */
  /* borderBottom: {
    property: 'border-bottom',
    values: {
      null: (t) => `${t['border-width']} solid ${t['border-color']}`,
      0: '0',
    },
  }, */
  /* borderLeft: {
    property: 'border-left',
    class: 'border-start',
    values: {
      null: (t) => `${t['border-width']} solid ${t['border-color']}`,
      0: '0',
    },
  }, */
  borderColor: {
    property: 'border-color',
    class: 'border',
    values: _objectSpread2(_objectSpread2({}, THEME_COLORS), {}, {
      white: 'white'
    })
  },
  borderWidth: {
    property: 'border-width',
    class: 'border',
    values: BORDER_WIDTHS
  },
  width: {
    property: 'width',
    class: 'w',
    values: {
      25: '25%',
      50: '50%',
      75: '75%',
      100: '100%',
      auto: 'auto'
    }
  },
  maxWidth: {
    property: 'max-width',
    class: 'mw',
    values: {
      100: '100%'
    }
  },
  viewportWidth: {
    property: 'width',
    class: 'vw',
    values: {
      100: '100vw' // TODO: native support
    }
  },

  minViewportWidth: {
    property: 'min-width',
    class: 'min-vw',
    values: {
      100: '100vw' // TODO: native support
    }
  },

  height: {
    property: 'height',
    class: 'h',
    values: {
      25: '25%',
      50: '50%',
      75: '75%',
      100: '100%',
      auto: 'auto'
    }
  },
  maxHeight: {
    property: 'max-height',
    class: 'mh',
    values: {
      100: '100%'
    }
  },
  viewportHeight: {
    property: 'height',
    class: 'vh',
    values: {
      100: '100vh' // TODO: native support
    }
  },

  minViewportHeight: {
    property: 'min-height',
    class: 'min-vh',
    values: {
      100: '100vh' // TODO: native support
    }
  },

  // Flex utilities
  flex: {
    responsive: true,
    property: 'flex',
    values: {
      fill: '1 1 auto'
    }
  },
  flexDirection: {
    responsive: true,
    property: 'flex-direction',
    class: 'flex',
    values: {
      row: 'row',
      column: 'column',
      'row-reverse': 'row-reverse',
      'column-reverse': 'column-reverse'
    }
  },
  flexGrow: {
    responsive: true,
    property: 'flex-grow',
    class: 'flex',
    values: {
      'grow-0': '0',
      'grow-1': '1'
    }
  },
  flexShrink: {
    responsive: true,
    property: 'flex-shrink',
    class: 'flex',
    values: {
      'shrink-0': '0',
      'shrink-1': '1'
    }
  },
  flexWrap: {
    responsive: true,
    property: 'flex-wrap',
    class: 'flex',
    values: {
      wrap: 'wrap',
      nowrap: 'nowrap',
      'wrap-reverse': 'wrap-reverse'
    }
  },
  /* gap: {
    responsive: true,
    property: 'gap',
    class: 'gap',
    values: SPACERS,
  }, */
  justifyContent: {
    responsive: true,
    property: 'justify-content',
    values: {
      start: 'flex-start',
      end: 'flex-end',
      center: 'center',
      between: 'space-between',
      around: 'space-around'
      // evenly: 'space-evenly', // TODO: For some reason this is converted into "spacNaNvenly"
    }
  },

  alignItems: {
    responsive: true,
    property: 'align-items',
    values: {
      start: 'flex-start',
      end: 'flex-end',
      center: 'center',
      baseline: 'baseline',
      stretch: 'stretch'
    }
  },
  alignContent: {
    responsive: true,
    property: 'align-content',
    values: {
      start: 'flex-start',
      end: 'flex-end',
      center: 'center',
      between: 'space-between',
      around: 'space-around',
      stretch: 'stretch'
    }
  },
  alignSelf: {
    responsive: true,
    property: 'align-self',
    values: {
      auto: 'auto',
      start: 'flex-start',
      end: 'flex-end',
      center: 'center',
      baseline: 'baseline',
      stretch: 'stretch'
    }
  },
  /* order: {
    responsive: true,
    property: 'order',
    values: {
      first: '-1',
      0: '0',
      1: '1',
      2: '2',
      3: '3',
      4: '4',
      5: '5',
      last: '6',
    },
  }, */
  // Margin utilities
  margin: {
    responsive: true,
    property: 'margin',
    class: 'm',
    values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
      auto: 'auto'
    })
  },
  marginX: {
    responsive: true,
    property: 'margin-horizontal',
    class: 'mx',
    values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
      auto: 'auto'
    })
  },
  marginY: {
    responsive: true,
    property: 'margin-vertical',
    class: 'my',
    values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
      auto: 'auto'
    })
  },
  marginTop: {
    responsive: true,
    property: 'margin-top',
    class: 'mt',
    values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
      auto: 'auto'
    })
  },
  marginEnd: {
    responsive: true,
    property: 'margin-right',
    class: 'me',
    values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
      auto: 'auto'
    })
  },
  marginBottom: {
    responsive: true,
    property: 'margin-bottom',
    class: 'mb',
    values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
      auto: 'auto'
    })
  },
  marginStart: {
    responsive: true,
    property: 'margin-left',
    class: 'ms',
    values: _objectSpread2(_objectSpread2({}, SPACERS), {}, {
      auto: 'auto'
    })
  },
  // Negative margin utilities
  negativeMargin: {
    responsive: true,
    property: 'margin',
    class: 'm',
    values: NEGATIVE_SPACERS
  },
  negativeMarginX: {
    responsive: true,
    property: 'margin-horizontal',
    class: 'mx',
    values: NEGATIVE_SPACERS
  },
  negativeMarginY: {
    responsive: true,
    property: 'margin-vertical',
    class: 'my',
    values: NEGATIVE_SPACERS
  },
  negativeMarginTop: {
    responsive: true,
    property: 'margin-top',
    class: 'mt',
    values: NEGATIVE_SPACERS
  },
  negativeMarginEnd: {
    responsive: true,
    property: 'margin-right',
    class: 'me',
    values: NEGATIVE_SPACERS
  },
  negativeMarginBottom: {
    responsive: true,
    property: 'margin-bottom',
    class: 'mb',
    values: NEGATIVE_SPACERS
  },
  negativeMarginStart: {
    responsive: true,
    property: 'margin-left',
    class: 'ms',
    values: NEGATIVE_SPACERS
  },
  // Padding utilities
  padding: {
    responsive: true,
    property: 'padding',
    class: 'p',
    values: SPACERS
  },
  paddingX: {
    responsive: true,
    property: 'padding-horizontal',
    class: 'px',
    values: SPACERS
  },
  paddingY: {
    responsive: true,
    property: 'padding-vertical',
    class: 'py',
    values: SPACERS
  },
  paddingTop: {
    responsive: true,
    property: 'padding-top',
    class: 'pt',
    values: SPACERS
  },
  paddingEnd: {
    responsive: true,
    property: 'padding-right',
    class: 'pe',
    values: SPACERS
  },
  paddingBottom: {
    responsive: true,
    property: 'padding-bottom',
    class: 'pb',
    values: SPACERS
  },
  paddingStart: {
    responsive: true,
    property: 'padding-left',
    class: 'ps',
    values: SPACERS
  },
  // Text
  fontFamily: {
    property: 'font-family',
    class: 'font',
    values: {
      monospace: t => t['font-family-monospace']
    }
  },
  fontSize: {
    rfs: true,
    property: 'font-size',
    class: 'fs',
    values: FONT_SIZES
  },
  fontStyle: {
    property: 'font-style',
    class: 'fst',
    values: {
      italic: 'italic',
      normal: 'normal'
    }
  },
  fontWeight: {
    property: 'font-weight',
    class: 'fw',
    values: {
      light: t => t['font-weight-light'],
      // lighter: (t) => t['font-weight-lighter'],
      normal: t => t['font-weight-normal'],
      bold: t => t['font-weight-bold']
      // bolder: (t) => t['font-weight-bolder'],
    }
  },

  lineHeight: {
    property: 'line-height',
    class: 'lh',
    // Multiply line-height with font-size for react-native support.
    values: {
      1: t => t['font-size-base'],
      sm: t => "".concat(t['font-size-sm'], " * ").concat(t['line-height-sm']),
      base: t => "".concat(t['font-size-base'], " * ").concat(t['line-height-base']),
      lg: t => "".concat(t['font-size-lg'], " * ").concat(t['line-height-lg'])
    }
  },
  textAlign: {
    responsive: true,
    property: 'text-align',
    class: 'text',
    values: {
      start: 'left',
      end: 'right',
      center: 'center'
    }
  },
  textDecoration: {
    property: 'text-decoration',
    class: 'text',
    values: {
      none: 'none',
      underline: 'underline',
      'line-through': 'line-through'
    }
  },
  textTransform: {
    property: 'text-transform',
    class: 'text',
    values: {
      lowercase: 'lowercase',
      uppercase: 'uppercase',
      capitalize: 'capitalize'
    }
  },
  /* whiteSpace: {
    property: 'white-space',
    class: 'text',
    values: {
      wrap: 'normal',
      nowrap: 'nowrap',
    },
  }, */
  /* wordWrap: {
    property: ['word-wrap', 'word-break'],
    class: 'text',
    values: {
      break: 'break-word',
    },
    rtl: false,
  }, */
  color: {
    property: 'color',
    class: 'text',
    // 'local-vars': { 'text-opacity': 1 },
    values: _objectSpread2(_objectSpread2({}, UTILITIES_TEXT_COLORS), {}, {
      muted: t => t['text-muted'],
      'black-50': t => "rgba(".concat(t.black, ", 0.5)"),
      'white-50': t => "rgba(".concat(t.white, ", 0.5)")
    })
  },
  textOpacity: {
    property: 'opacity',
    // 'css-var': true,
    class: 'text-opacity',
    values: {
      25: '0.25',
      50: '0.5',
      75: '0.75',
      100: '1'
    }
  },
  backgroundColor: {
    property: 'background-color',
    class: 'bg',
    // 'local-vars': { 'bg-opacity': 1 },
    values: _objectSpread2(_objectSpread2({}, UTILITIES_BG_COLORS), {}, {
      transparent: 'transparent'
    })
  },
  bgOpacity: {
    property: 'opacity',
    // 'css-var': true,
    class: 'bg-opacity',
    values: {
      10: '0.1',
      25: '0.25',
      50: '0.50',
      75: '0.75',
      100: '1'
    }
  },
  /* gradient: {
    property: 'background-image',
    class: 'bg',
    values: {
      gradient: 'var(--#{$variable-prefix}gradient))',
    },
  }, */
  /* userSelect: {
    property: 'user-select',
    values: {
      all: 'all',
      auto: 'auto',
      none: 'none',
    },
  }, */
  /* pointerEvents: {
    property: 'pointer-events',
    class: 'pe',
    values: {
      none: 'none',
      auto: 'auto',
    },
  }, */
  rounded: {
    property: 'border-radius',
    class: 'rounded',
    values: {
      null: t => t['border-radius'],
      0: '0',
      1: t => t['border-radius-sm'],
      2: t => t['border-radius'],
      3: t => t['border-radius-lg'],
      circle: '500px',
      // TODO: How to implement 50%?
      pill: t => t['border-radius-pill']
    }
  }
  // TODO: Support multiple properties for rounded-* utilities.
  /* roundedTop: {
    property: ['border-top-left-radius', 'border-top-right-radius'],
    class: 'rounded-top',
    values: {
      null: (t) => t['border-radius'],
    },
  }, */
  /* roundedEnd: {
    property: ['border-top-right-radius', 'border-bottom-right-radius'],
    class: 'rounded-end',
    values: {
      null: (t) => t['border-radius'],
    },
  }, */
  /* roundedBottom: {
    property: ['border-bottom-right-radius', 'border-bottom-left-radius'],
    class: 'rounded-bottom',
    values: {
      null: (t) => t['border-radius'],
    },
  }, */
  /* roundedStart: {
    property: ['border-bottom-left-radius', 'border-top-left-radius'],
    class: 'rounded-start',
    values: {
      null: (t) => t['border-radius'],
    },
  }, */
  /* visibility: {
    property: 'visibility',
    class: 'null',
    values: {
      visible: 'visible',
      invisible: 'hidden',
    },
  }, */
};

var _templateObject$1f, _templateObject2$W;
function makeUtility(options) {
  return each(options.values, (key, value) => {
    const name = options.class || options.property;
    const suffix = key === 'null' ? '' : "-".concat(key);
    const styles = {
      ["".concat(name).concat(suffix)]: css(_templateObject$1f || (_templateObject$1f = _taggedTemplateLiteral(["\n        ", ": ", ";\n      "])), options.property, value)
    };
    if (!options.responsive) {
      return styles;
    }
    return _objectSpread2(_objectSpread2({}, styles), each(GRID_BREAKPOINTS, breakpoint => {
      if (breakpoint === 'xs') {
        return null;
      }
      return {
        ["".concat(name, "-").concat(breakpoint).concat(suffix)]: css(_templateObject2$W || (_templateObject2$W = _taggedTemplateLiteral(["\n            @include media-breakpoint-up(", ") {\n              ", ": ", ";\n            }\n          "])), breakpoint, options.property, value)
      };
    }));
  });
}
function makeUtilities(resolve) {
  const customUtilities = typeof resolve === 'function' ? resolve(utilities) : resolve;
  const definitions = Object.values(_objectSpread2(_objectSpread2({}, utilities), customUtilities)).reduce((result, utility) => {
    if (!utility) {
      return result;
    }
    return Object.assign(result, makeUtility(utility));
  }, {});
  return definitions;
}

const fn = handle => function () {
  for (var _len = arguments.length, args = new Array(_len), _key = 0; _key < _len; _key++) {
    args[_key] = arguments[_key];
  }
  return t => {
    const input = args.map(arg => typeof arg === 'function' ? arg(t) : arg);
    return handle(input, t);
  };
};

/* eslint-disable arrow-body-style */

const escapedCharacters = {
  '<': '%3c',
  '>': '%3e',
  '#': '%23',
  '(': '%28',
  ')': '%29'
};
const escapeSvg = string => {
  const strReplace = val => Object.entries(escapedCharacters).reduce((result, _ref) => {
    let [char, encoded] = _ref;
    return result.replace(new RegExp("\\".concat(char), 'g'), encoded);
  }, val);
  return string.startsWith('url(') ? "url(\"".concat(strReplace(string.slice(5, -2)), "\")") : strReplace(string);
};

// Color contrast

// A list of pre-calculated numbers of pow(divide((divide($value, 255) + .055), 1.055), 2.4). (from 0 to 255)
// prettier-ignore
const luminanceList = [0.0008, 0.001, 0.0011, 0.0013, 0.0015, 0.0017, 0.002, 0.0022, 0.0025, 0.0027, 0.003, 0.0033, 0.0037, 0.004, 0.0044, 0.0048, 0.0052, 0.0056, 0.006, 0.0065, 0.007, 0.0075, 0.008, 0.0086, 0.0091, 0.0097, 0.0103, 0.011, 0.0116, 0.0123, 0.013, 0.0137, 0.0144, 0.0152, 0.016, 0.0168, 0.0176, 0.0185, 0.0194, 0.0203, 0.0212, 0.0222, 0.0232, 0.0242, 0.0252, 0.0262, 0.0273, 0.0284, 0.0296, 0.0307, 0.0319, 0.0331, 0.0343, 0.0356, 0.0369, 0.0382, 0.0395, 0.0409, 0.0423, 0.0437, 0.0452, 0.0467, 0.0482, 0.0497, 0.0513, 0.0529, 0.0545, 0.0561, 0.0578, 0.0595, 0.0612, 0.063, 0.0648, 0.0666, 0.0685, 0.0704, 0.0723, 0.0742, 0.0762, 0.0782, 0.0802, 0.0823, 0.0844, 0.0865, 0.0887, 0.0908, 0.0931, 0.0953, 0.0976, 0.0999, 0.1022, 0.1046, 0.107, 0.1095, 0.1119, 0.1144, 0.117, 0.1195, 0.1221, 0.1248, 0.1274, 0.1301, 0.1329, 0.1356, 0.1384, 0.1413, 0.1441, 0.147, 0.15, 0.1529, 0.1559, 0.159, 0.162, 0.1651, 0.1683, 0.1714, 0.1746, 0.1779, 0.1812, 0.1845, 0.1878, 0.1912, 0.1946, 0.1981, 0.2016, 0.2051, 0.2086, 0.2122, 0.2159, 0.2195, 0.2232, 0.227, 0.2307, 0.2346, 0.2384, 0.2423, 0.2462, 0.2502, 0.2542, 0.2582, 0.2623, 0.2664, 0.2705, 0.2747, 0.2789, 0.2831, 0.2874, 0.2918, 0.2961, 0.3005, 0.305, 0.3095, 0.314, 0.3185, 0.3231, 0.3278, 0.3325, 0.3372, 0.3419, 0.3467, 0.3515, 0.3564, 0.3613, 0.3663, 0.3712, 0.3763, 0.3813, 0.3864, 0.3916, 0.3968, 0.402, 0.4072, 0.4125, 0.4179, 0.4233, 0.4287, 0.4342, 0.4397, 0.4452, 0.4508, 0.4564, 0.4621, 0.4678, 0.4735, 0.4793, 0.4851, 0.491, 0.4969, 0.5029, 0.5089, 0.5149, 0.521, 0.5271, 0.5333, 0.5395, 0.5457, 0.552, 0.5583, 0.5647, 0.5711, 0.5776, 0.5841, 0.5906, 0.5972, 0.6038, 0.6105, 0.6172, 0.624, 0.6308, 0.6376, 0.6445, 0.6514, 0.6584, 0.6654, 0.6724, 0.6795, 0.6867, 0.6939, 0.7011, 0.7084, 0.7157, 0.7231, 0.7305, 0.7379, 0.7454, 0.7529, 0.7605, 0.7682, 0.7758, 0.7835, 0.7913, 0.7991, 0.807, 0.8148, 0.8228, 0.8308, 0.8388, 0.8469, 0.855, 0.8632, 0.8714, 0.8796, 0.8879, 0.8963, 0.9047, 0.9131, 0.9216, 0.9301, 0.9387, 0.9473, 0.956, 0.9647, 0.9734, 0.9823, 0.9911, 1];

// Return WCAG2.0 relative luminance
// See https://www.w3.org/WAI/GL/wiki/Relative_luminance
// See https://www.w3.org/TR/WCAG20-TECHS/G17.html#G17-tests
const luminance = color => {
  const rgb = RgbaValue.parse(color).toRgb();
  const [red, green, blue] = rgb.map(value => {
    return value / 255 < 0.04045 ? value / 255 / 12.92 : luminanceList[value];
  });
  return red * 0.2126 + green * 0.7152 + blue * 0.0722;
};

// Return opaque color
// opaque(#fff, rgba(0, 0, 0, .5)) => #808080
const opaque = (background, foreground) => {
  const foregroundRgba = RgbaValue.parse(foreground);
  return mix(rgba$1(foregroundRgba, 1), background, opacity(foregroundRgba));
};
const contrastRatio = (background, foreground) => {
  const l1 = luminance(background);
  const l2 = luminance(opaque(background, foreground));
  return l1 > l2 ? (l1 + 0.05) / (l2 + 0.05) : (l2 + 0.05) / (l1 + 0.05);
};
const colorContrast = fn((_ref2, t) => {
  let [background] = _ref2;
  const foregrounds = [t['color-contrast-light'], t['color-contrast-dark'], t.white, t.black];
  let maxRatio = 0;
  let maxRatioColor = null;
  const result = foregrounds.find(color => {
    const ratio = contrastRatio(background, color);
    if (ratio > t['min-contrast-ratio']) {
      return true;
    }
    if (ratio > maxRatio) {
      maxRatio = ratio;
      maxRatioColor = color;
    }
    return false;
  });
  if (result) {
    return result;
  }

  // eslint-disable-next-line no-console
  console.warn("Found no color leading to ".concat(t['min-contrast-ratio'], ":1 contrast ratio against ").concat(background, "..."));
  return maxRatioColor;
});

// Tint a color: mix a color with white
const tintColor = fn((_ref3, t) => {
  let [color, weight] = _ref3;
  return mix(t.white, color, weight);
});

// Shade a color: mix a color with black
const shadeColor = fn((_ref4, t) => {
  let [color, weight] = _ref4;
  return mix(t.black, color, weight);
});

// Shade the color if the weight is positive, else tint it
const shiftColor = fn((_ref5, t) => {
  let [color, weight] = _ref5;
  const percentage = UnitValue.parse(weight).toNumber();
  const handle = percentage > 0 ? shadeColor(color, percentage) : tintColor(color, -percentage);
  return handle(t);
});
const add = fn(_ref6 => {
  let [value1, value2] = _ref6;
  if (value1 === null) {
    return value2;
  }
  if (value2 === null) {
    return value1;
  }
  return calculate(value1, '+', value2);
});
const subtract = fn(_ref7 => {
  let [value1, value2] = _ref7;
  if (value1 === null && value2 === null) {
    return null;
  }
  if (value1 === null) {
    return "-".concat(value2);
  }
  if (value2 === null) {
    return value1;
  }
  return calculate(value1, '-', value2);
});
const divide = fn(_ref8 => {
  let [dividend, divisor] = _ref8;
  if (Math.abs(parseFloat(dividend)) === 0) {
    return 0;
  }
  if (Math.abs(parseFloat(divisor)) === 0) {
    throw new Error('Cannot divide by 0');
  }
  return calculate(dividend, '/', divisor);
});

/* eslint-enable */

var _templateObject$1e;
const url = val => t => "url(\"".concat(val.replace(/#{\$(.*?)}/g, (_, key) => t[key]), "\")");
const variables = css(_templateObject$1e || (_templateObject$1e = _taggedTemplateLiteral(["\n  // Color system\n\n  $white: #fff;\n  $gray-100: #f8f9fa;\n  $gray-200: #e9ecef;\n  $gray-300: #dee2e6;\n  $gray-400: #ced4da;\n  $gray-500: #adb5bd;\n  $gray-600: #6c757d;\n  $gray-700: #495057;\n  $gray-800: #343a40;\n  $gray-900: #212529;\n  $black: #000;\n\n  $grays: ", ";\n\n  $blue: #0d6efd;\n  $indigo: #6610f2;\n  $purple: #6f42c1;\n  $pink: #d63384;\n  $red: #dc3545;\n  $orange: #fd7e14;\n  $yellow: #ffc107;\n  $green: #198754;\n  $teal: #20c997;\n  $cyan: #0dcaf0;\n\n  $colors: ", ";\n\n  $primary: $blue;\n  $secondary: $gray-600;\n  $success: $green;\n  $info: $cyan;\n  $warning: $yellow;\n  $danger: $red;\n  $light: $gray-100;\n  $dark: $gray-900;\n\n  $theme-colors: ", ";\n\n  // The contrast ratio to reach against white, to determine if color changes from \"light\" to \"dark\". Acceptable values for WCAG 2.0 are 3, 4.5 and 7.\n  // See https://www.w3.org/TR/WCAG20/#visual-audio-contrast-contrast\n  $min-contrast-ratio: 4.5;\n\n  // Customize the light and dark text colors for use in our color contrast function.\n  $color-contrast-dark: $black;\n  $color-contrast-light: $white;\n\n  $blue-100: tint-color($blue, 80%);\n  $blue-200: tint-color($blue, 60%);\n  $blue-300: tint-color($blue, 40%);\n  $blue-400: tint-color($blue, 20%);\n  $blue-500: $blue;\n  $blue-600: shade-color($blue, 20%);\n  $blue-700: shade-color($blue, 40%);\n  $blue-800: shade-color($blue, 60%);\n  $blue-900: shade-color($blue, 80%);\n\n  $indigo-100: tint-color($indigo, 80%);\n  $indigo-200: tint-color($indigo, 60%);\n  $indigo-300: tint-color($indigo, 40%);\n  $indigo-400: tint-color($indigo, 20%);\n  $indigo-500: $indigo;\n  $indigo-600: shade-color($indigo, 20%);\n  $indigo-700: shade-color($indigo, 40%);\n  $indigo-800: shade-color($indigo, 60%);\n  $indigo-900: shade-color($indigo, 80%);\n\n  $purple-100: tint-color($purple, 80%);\n  $purple-200: tint-color($purple, 60%);\n  $purple-300: tint-color($purple, 40%);\n  $purple-400: tint-color($purple, 20%);\n  $purple-500: $purple;\n  $purple-600: shade-color($purple, 20%);\n  $purple-700: shade-color($purple, 40%);\n  $purple-800: shade-color($purple, 60%);\n  $purple-900: shade-color($purple, 80%);\n\n  $pink-100: tint-color($pink, 80%);\n  $pink-200: tint-color($pink, 60%);\n  $pink-300: tint-color($pink, 40%);\n  $pink-400: tint-color($pink, 20%);\n  $pink-500: $pink;\n  $pink-600: shade-color($pink, 20%);\n  $pink-700: shade-color($pink, 40%);\n  $pink-800: shade-color($pink, 60%);\n  $pink-900: shade-color($pink, 80%);\n\n  $red-100: tint-color($red, 80%);\n  $red-200: tint-color($red, 60%);\n  $red-300: tint-color($red, 40%);\n  $red-400: tint-color($red, 20%);\n  $red-500: $red;\n  $red-600: shade-color($red, 20%);\n  $red-700: shade-color($red, 40%);\n  $red-800: shade-color($red, 60%);\n  $red-900: shade-color($red, 80%);\n\n  $orange-100: tint-color($orange, 80%);\n  $orange-200: tint-color($orange, 60%);\n  $orange-300: tint-color($orange, 40%);\n  $orange-400: tint-color($orange, 20%);\n  $orange-500: $orange;\n  $orange-600: shade-color($orange, 20%);\n  $orange-700: shade-color($orange, 40%);\n  $orange-800: shade-color($orange, 60%);\n  $orange-900: shade-color($orange, 80%);\n\n  $yellow-100: tint-color($yellow, 80%);\n  $yellow-200: tint-color($yellow, 60%);\n  $yellow-300: tint-color($yellow, 40%);\n  $yellow-400: tint-color($yellow, 20%);\n  $yellow-500: $yellow;\n  $yellow-600: shade-color($yellow, 20%);\n  $yellow-700: shade-color($yellow, 40%);\n  $yellow-800: shade-color($yellow, 60%);\n  $yellow-900: shade-color($yellow, 80%);\n\n  $green-100: tint-color($green, 80%);\n  $green-200: tint-color($green, 60%);\n  $green-300: tint-color($green, 40%);\n  $green-400: tint-color($green, 20%);\n  $green-500: $green;\n  $green-600: shade-color($green, 20%);\n  $green-700: shade-color($green, 40%);\n  $green-800: shade-color($green, 60%);\n  $green-900: shade-color($green, 80%);\n\n  $teal-100: tint-color($teal, 80%);\n  $teal-200: tint-color($teal, 60%);\n  $teal-300: tint-color($teal, 40%);\n  $teal-400: tint-color($teal, 20%);\n  $teal-500: $teal;\n  $teal-600: shade-color($teal, 20%);\n  $teal-700: shade-color($teal, 40%);\n  $teal-800: shade-color($teal, 60%);\n  $teal-900: shade-color($teal, 80%);\n\n  $cyan-100: tint-color($cyan, 80%);\n  $cyan-200: tint-color($cyan, 60%);\n  $cyan-300: tint-color($cyan, 40%);\n  $cyan-400: tint-color($cyan, 20%);\n  $cyan-500: $cyan;\n  $cyan-600: shade-color($cyan, 20%);\n  $cyan-700: shade-color($cyan, 40%);\n  $cyan-800: shade-color($cyan, 60%);\n  $cyan-900: shade-color($cyan, 80%);\n\n  $blues: ", ";\n\n  $indigos: ", ";\n\n  $purples: ", ";\n\n  $pinks: ", ";\n\n  $reds: ", ";\n\n  $oranges: ", ";\n\n  $yellows: ", ";\n\n  $greens: ", ";\n\n  $teals: ", ";\n\n  $cyans: ", ";\n\n  // Characters which are escaped by the escape-svg function\n  // $escaped characters\n\n  // Options\n  //\n  // Quickly modify global styling by enabling or disabling optional features.\n\n  // NOTE: Handled by JavaScript.\n\n  // Gradient\n  //\n  // The gradient which is added to components if \"$enable-gradients\" is \"true\"\n  // This gradient is also added to elements with \".bg-gradient\"\n  $gradient: linear-gradient(180deg, rgba($white, 0.15), rgba($white, 0));\n\n  // Spacing\n  //\n  // Control the default styling of most Bootstrap elements by modifying these\n  // variables. Mostly focused on spacing.\n  // You can add more entries to the $spacers map, should you need more variation.\n\n  $spacer: 1rem;\n  $spacers: ", ";\n\n  // Position\n  //\n  // Define the edge positioning anchors of the position utilities.\n\n  $position-values: ", ";\n\n  // Placeholder\n\n  $placeholder-opacity-max: 0.5;\n  $placeholder-opacity-min: 0.2;\n\n  // Body\n  //\n  // Settings for the \"<body>\" element.\n\n  $body-bg: $white;\n  $body-color: $gray-900;\n  $body-text-align: null;\n\n  // Links\n  //\n  // Style anchor elements.\n\n  $link-color: $primary;\n  $link-decoration: underline;\n  $link-shade-percentage: 20%;\n  $link-hover-color: ", ";\n  $link-hover-decoration: null;\n\n  $stretched-link-pseudo-element: after;\n  $stretched-link-z-index: 1;\n\n  // Paragraphs\n  //\n  // Style p element.\n\n  $paragraph-margin-bottom: 1rem;\n\n  // Grid breakpoints\n  //\n  // Define the minimum dimensions at which your layout will change,\n  // adapting to different screen sizes, for use in media queries.\n\n  $grid-breakpoints: ", ";\n\n  // Grid containers\n  //\n  // Define the maximum width of \".container\" for different screen sizes.\n\n  $container-max-widths: ", ";\n\n  // Grid columns\n  //\n  // Set the number of columns and specify the width of the gutters.\n\n  // $grid-columns: 12;\n  $grid-gutter-width: 1.5rem;\n  // $grid-row-columns: 6;\n\n  // Container padding\n\n  $container-padding-x: $grid-gutter-width * 0.5;\n\n  // Components\n  //\n  // Define common padding and border radius sizes and more.\n\n  $border-width: 1px;\n  $border-widths: ", ";\n\n  $border-color: $gray-300;\n\n  $border-radius: 0.25rem;\n  $border-radius-sm: 0.2rem;\n  $border-radius-lg: 0.3rem;\n  $border-radius-pill: 50rem;\n\n  $box-shadow: 0 0.5rem 1rem rgba($black, 0.15);\n  $box-shadow-sm: 0 0.125rem 0.25rem rgba($black, 0.075);\n  $box-shadow-lg: 0 1rem 3rem rgba($black, 0.175);\n  $box-shadow-inset: inset 0 1px 2px rgba($black, 0.075);\n\n  $component-active-color: $white;\n  $component-active-bg: $primary;\n\n  $caret-width: 1rem * 0.3; // 0.3em;\n  $caret-vertical-align: $caret-width * 0.85;\n  $caret-spacing: $caret-width * 0.85;\n\n  $transition-base: all 0.2s ease-in-out;\n  $transition-fade: opacity 0.15s linear;\n  $transition-collapse: height 0.35s ease;\n  $transition-collapse-width: width 0.35s ease;\n\n  $aspect-ratios: ", ";\n\n  // Typography\n  //\n  // Font, line-height, and color for body text, headings, and more.\n\n  $font-family-sans-serif: ", ";\n  $font-family-monospace: ", ";\n  $font-family-base: $font-family-sans-serif;\n  $font-family-code: $font-family-monospace;\n\n  // $font-size-root affects the value of \"rem\", which is used for as well font sizes, paddings, and margins\n  // $font-size-base affects the font size of the body text\n  $font-size-root: null;\n  $font-size-base: 1rem; // Assumes the browser default, typically \"16px\"\n  $font-size-sm: $font-size-base * 0.875;\n  $font-size-lg: $font-size-base * 1.25;\n\n  $font-weight-lighter: 300; // lighter;\n  $font-weight-light: 300;\n  $font-weight-normal: 400;\n  $font-weight-bold: 700;\n  $font-weight-bolder: 500; // bolder;\n\n  $font-weight-base: $font-weight-normal;\n\n  $line-height-base: 1.5;\n  $line-height-sm: 1.25;\n  $line-height-lg: 2;\n\n  $h1-font-size: $font-size-base * 2.5;\n  $h2-font-size: $font-size-base * 2;\n  $h3-font-size: $font-size-base * 1.75;\n  $h4-font-size: $font-size-base * 1.5;\n  $h5-font-size: $font-size-base * 1.25;\n  $h6-font-size: $font-size-base;\n\n  $font-sizes: ", ";\n\n  $headings-margin-bottom: $spacer * 0.5;\n  $headings-font-family: null;\n  $headings-font-style: null;\n  $headings-font-weight: 500;\n  $headings-line-height: 1.2;\n  $headings-color: null;\n\n  $display-font-sizes: ", ";\n\n  $display-font-weight: 300;\n  $display-line-height: $headings-line-height;\n\n  $lead-font-size: $font-size-base * 1.25;\n  $lead-font-weight: 300;\n\n  $small-font-size: $font-size-base * 0.875; // 0.875em;\n\n  $sub-sup-font-size: $font-size-base * 0.75; // 0.75em;\n\n  $text-muted: $gray-600;\n\n  $initialism-font-size: $small-font-size;\n\n  $blockquote-margin-y: $spacer;\n  $blockquote-font-size: $font-size-base * 1.25;\n  $blockquote-footer-color: $gray-600;\n  $blockquote-footer-font-size: $small-font-size;\n\n  $hr-margin-y: $spacer;\n  $hr-color: inherit;\n  $hr-bg-color: currentColor;\n  $hr-border-width: 0;\n  $hr-height: $border-width;\n  $hr-opacity: 0.25;\n\n  $legend-margin-bottom: 0.5rem;\n  $legend-font-size: 1.5rem;\n  $legend-font-weight: null;\n\n  $mark-padding: $font-size-base * 0.2; // 0.2em;\n\n  $dt-font-weight: $font-weight-bold;\n\n  $nested-kbd-font-weight: $font-weight-bold;\n\n  $list-inline-padding: 0.5rem;\n\n  $mark-bg: #fcf8e3;\n\n  // ...\n\n  // Buttons + Forms\n  //\n  // Shared variables that are reassigned to \"$input-\" and \"$btn-\" specific variables.\n\n  $input-btn-padding-y: 0.375rem;\n  $input-btn-padding-x: 0.75rem;\n  $input-btn-font-family: null;\n  $input-btn-font-size: $font-size-base;\n  $input-btn-line-height: $line-height-base;\n\n  $input-btn-focus-width: 0.25rem;\n  $input-btn-focus-color-opacity: 0.25;\n  $input-btn-focus-color: rgba(\n    $component-active-bg,\n    $input-btn-focus-color-opacity\n  );\n  $input-btn-focus-blur: 0;\n  $input-btn-focus-box-shadow: 0 0 $input-btn-focus-blur $input-btn-focus-width\n    $input-btn-focus-color;\n\n  $input-btn-padding-y-sm: 0.25rem;\n  $input-btn-padding-x-sm: 0.5rem;\n  $input-btn-font-size-sm: $font-size-sm;\n\n  $input-btn-padding-y-lg: 0.5rem;\n  $input-btn-padding-x-lg: 1rem;\n  $input-btn-font-size-lg: $font-size-lg;\n\n  $input-btn-border-width: $border-width;\n\n  // Buttons\n  //\n  // For each of Bootstrap's buttons, define text, background, and border color.\n\n  $btn-padding-y: $input-btn-padding-y;\n  $btn-padding-x: $input-btn-padding-x;\n  $btn-font-family: $input-btn-font-family;\n  $btn-font-size: $input-btn-font-size;\n  $btn-line-height: $input-btn-line-height;\n  $btn-white-space: null; // Set to \"nowrap\" to prevent text wrapping\n\n  $btn-padding-y-sm: $input-btn-padding-y-sm;\n  $btn-padding-x-sm: $input-btn-padding-x-sm;\n  $btn-font-size-sm: $input-btn-font-size-sm;\n\n  $btn-padding-y-lg: $input-btn-padding-y-lg;\n  $btn-padding-x-lg: $input-btn-padding-x-lg;\n  $btn-font-size-lg: $input-btn-font-size-lg;\n\n  $btn-border-width: $input-btn-border-width;\n\n  $btn-font-weight: $font-weight-normal;\n  $btn-box-shadow: inset 0 1px 0 rgba($white, 0.15),\n    0 1px 1px rgba($black, 0.075);\n  $btn-focus-width: $input-btn-focus-width;\n  $btn-focus-box-shadow: $input-btn-focus-box-shadow;\n  $btn-disabled-opacity: 0.65;\n  $btn-active-box-shadow: inset 0 3px 5px rgba($black, 0.125);\n\n  $btn-link-color: $link-color;\n  $btn-link-hover-color: $link-hover-color;\n  $btn-link-disabled-color: $gray-600;\n\n  // Allows for customizing button radius independently from global border radius\n  $btn-border-radius: $border-radius;\n  $btn-border-radius-sm: $border-radius-sm;\n  $btn-border-radius-lg: $border-radius-lg;\n\n  $btn-transition: color 0.15s ease-in-out, background-color 0.15s ease-in-out,\n    border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n\n  $btn-hover-bg-shade-amount: 15%;\n  $btn-hover-bg-tint-amount: 15%;\n  $btn-hover-border-shade-amount: 20%;\n  $btn-hover-border-tint-amount: 10%;\n  $btn-active-bg-shade-amount: 20%;\n  $btn-active-bg-tint-amount: 20%;\n  $btn-active-border-shade-amount: 25%;\n  $btn-active-border-tint-amount: 10%;\n\n  // Breadcrumb\n\n  $breadcrumb-font-size: $font-size-base; // null;\n  $breadcrumb-padding-y: 0;\n  $breadcrumb-padding-x: 0;\n  $breadcrumb-item-padding-x: 0.5rem;\n  $breadcrumb-margin-bottom: 1rem;\n  $breadcrumb-bg: null;\n  $breadcrumb-divider-color: $gray-600;\n  $breadcrumb-active-color: $gray-600;\n  $breadcrumb-divider: ", "; // quote('/');\n  $breadcrumb-divider-flipped: $breadcrumb-divider;\n  $breadcrumb-border-radius: null;\n\n  // Forms\n\n  $form-text-margin-top: 0.25rem;\n  $form-text-font-size: $small-font-size;\n  $form-text-font-style: null;\n  $form-text-font-weight: null;\n  $form-text-color: $text-muted;\n\n  $form-label-margin-bottom: 0.5rem;\n  $form-label-font-size: $font-size-base; // null;\n  $form-label-font-style: null;\n  $form-label-font-weight: null;\n  $form-label-color: null;\n\n  $input-padding-y: $input-btn-padding-y;\n  $input-padding-x: $input-btn-padding-x;\n  $input-font-family: $input-btn-font-family;\n  $input-font-size: $input-btn-font-size;\n  $input-font-weight: $font-weight-base;\n  $input-line-height: $input-btn-line-height;\n\n  $input-padding-y-sm: $input-btn-padding-y-sm;\n  $input-padding-x-sm: $input-btn-padding-x-sm;\n  $input-font-size-sm: $input-btn-font-size-sm;\n\n  $input-padding-y-lg: $input-btn-padding-y-lg;\n  $input-padding-x-lg: $input-btn-padding-x-lg;\n  $input-font-size-lg: $input-btn-font-size-lg;\n\n  $input-bg: $body-bg;\n  $input-disabled-bg: $gray-200;\n  $input-disabled-border-color: null;\n\n  $input-color: $body-color;\n  $input-border-color: $gray-400;\n  $input-border-width: $input-btn-border-width;\n  $input-box-shadow: $box-shadow-inset;\n\n  $input-border-radius: $border-radius;\n  $input-border-radius-sm: $border-radius-sm;\n  $input-border-radius-lg: $border-radius-lg;\n\n  $input-focus-bg: $input-bg;\n  $input-focus-border-color: ", ";\n  $input-focus-color: $input-color;\n  $input-focus-width: $input-btn-focus-width;\n  $input-focus-box-shadow: $input-btn-focus-box-shadow;\n\n  $input-placeholder-color: $gray-600;\n  $input-plaintext-color: $body-color;\n\n  $input-height-border: $input-border-width * 2;\n\n  $input-height-inner: ", ";\n  $input-height-inner-half: ", ";\n  $input-height-inner-quarter: ", ";\n\n  $input-height: ", ";\n  $input-height-sm: ", ";\n  $input-height-lg: ", ";\n\n  $input-transition: border-color 0.15s ease-in-out,\n    box-shadow 0.15s ease-in-out;\n\n  $form-color-width: 3rem;\n\n  $form-check-input-width: $font-size-base * 1; // 1em;\n  $form-check-min-height: $font-size-base * $line-height-base;\n  $form-check-padding-start: $form-check-input-width + 0.5rem; // 0.5em;\n  $form-check-margin-bottom: 0.125rem;\n  $form-check-label-color: null;\n  $form-check-label-cursor: null;\n  $form-check-transition: null;\n\n  $form-check-input-active-filter: brightness(90%);\n\n  $form-check-input-bg: $input-bg;\n  $form-check-input-border: 1px solid rgba($black, 0.25);\n  $form-check-input-border-radius: $font-size-base * 0.25; // 0.25em;\n  $form-check-radio-border-radius: 50%;\n  $form-check-input-focus-border: $input-focus-border-color;\n  $form-check-input-focus-box-shadow: $input-btn-focus-box-shadow;\n\n  $form-check-input-checked-color: $component-active-color;\n  $form-check-input-checked-bg-color: $component-active-bg;\n  $form-check-input-checked-border-color: $form-check-input-checked-bg-color;\n  $form-check-input-checked-bg-image: ", ";\n  $form-check-radio-checked-bg-image: ", ";\n\n  $form-check-input-indeterminate-color: $component-active-color;\n  $form-check-input-indeterminate-bg-color: $component-active-bg;\n  $form-check-input-indeterminate-border-color: $form-check-input-indeterminate-bg-color;\n  $form-check-input-indeterminate-bg-image: ", ";\n\n  $form-check-input-disabled-opacity: 0.5;\n  $form-check-label-disabled-opacity: $form-check-input-disabled-opacity;\n  $form-check-btn-check-disabled-opacity: $btn-disabled-opacity;\n\n  $form-check-inline-margin-end: 1rem;\n\n  $form-switch-color: rgba($black, 0.25);\n  $form-switch-width: 2rem;\n  $form-switch-padding-start: $form-switch-width + 0.5rem;\n  $form-switch-bg-image: ", ";\n  $form-switch-border-radius: $form-switch-width;\n  $form-switch-transition: background-position 0.15s ease-in-out;\n\n  $form-switch-focus-color: $input-focus-border-color;\n  $form-switch-focus-bg-image: ", ";\n\n  $form-switch-checked-color: $component-active-color;\n  $form-switch-checked-bg-image: ", ";\n  $form-switch-checked-bg-position: right center;\n\n  $input-group-addon-padding-y: $input-padding-y;\n  $input-group-addon-padding-x: $input-padding-x;\n  $input-group-addon-font-weight: $input-font-weight;\n  $input-group-addon-color: $input-color;\n  $input-group-addon-bg: $gray-200;\n  $input-group-addon-border-color: $input-border-color;\n\n  $form-select-padding-y: $input-padding-y;\n  $form-select-padding-x: $input-padding-x;\n  $form-select-font-family: $input-font-family;\n  $form-select-font-size: $input-font-size;\n  $form-select-indicator-padding: $form-select-padding-x * 3; // Extra padding for background-image\n  $form-select-font-weight: $input-font-weight;\n  $form-select-line-height: $input-line-height;\n  $form-select-color: $input-color;\n  $form-select-bg: $input-bg;\n  $form-select-disabled-color: null;\n  $form-select-disabled-bg: $gray-200;\n  $form-select-disabled-border-color: $input-disabled-border-color;\n  $form-select-bg-position: right $form-select-padding-x center;\n  $form-select-bg-size: 16px 12px; // In pixels because image dimensions\n  $form-select-indicator-color: $gray-800;\n  $form-select-indicator: ", ";\n\n  $form-select-feedback-icon-padding-end: $form-select-padding-x * 2.5 +\n    $form-select-indicator-padding;\n  $form-select-feedback-icon-position: center right\n    $form-select-indicator-padding;\n  $form-select-feedback-icon-size: $input-height-inner-half\n    $input-height-inner-half;\n\n  $form-select-border-width: $input-border-width;\n  $form-select-border-color: $input-border-color;\n  $form-select-border-radius: $input-border-radius;\n  $form-select-box-shadow: $box-shadow-inset;\n\n  $form-select-focus-border-color: $input-focus-border-color;\n  $form-select-focus-width: $input-focus-width;\n  $form-select-focus-box-shadow: 0 0 0 $form-select-focus-width\n    $input-btn-focus-color;\n\n  $form-select-padding-y-sm: $input-padding-y-sm;\n  $form-select-padding-x-sm: $input-padding-x-sm;\n  $form-select-font-size-sm: $input-font-size-sm;\n  $form-select-border-radius-sm: $input-border-radius-sm;\n\n  $form-select-padding-y-lg: $input-padding-y-lg;\n  $form-select-padding-x-lg: $input-padding-x-lg;\n  $form-select-font-size-lg: $input-font-size-lg;\n  $form-select-border-radius-lg: $input-border-radius-lg;\n\n  $form-select-transition: $input-transition;\n\n  $form-range-track-width: 100%;\n  $form-range-track-height: 0.5rem;\n  $form-range-track-cursor: pointer;\n  $form-range-track-bg: $gray-300;\n  $form-range-track-border-radius: 1rem;\n  $form-range-track-box-shadow: $box-shadow-inset;\n\n  $form-range-thumb-width: 1rem;\n  $form-range-thumb-height: $form-range-thumb-width;\n  $form-range-thumb-bg: $component-active-bg;\n  $form-range-thumb-border: 0;\n  $form-range-thumb-border-radius: 1rem;\n  $form-range-thumb-box-shadow: 0 0.1rem 0.25rem rgba($black, 0.1);\n  $form-range-thumb-focus-box-shadow: 0 0 0 1px $body-bg,\n    $input-focus-box-shadow;\n  $form-range-thumb-focus-box-shadow-width: $input-focus-width; // For focus box shadow issue in Edge\n  $form-range-thumb-active-bg: tint-color($component-active-bg, 70%);\n  $form-range-thumb-disabled-bg: $gray-500;\n  $form-range-thumb-transition: background-color 0.15s ease-in-out,\n    border-color 0.15s ease-in-out, box-shadow 0.15s ease-in-out;\n\n  $form-file-button-color: $input-color;\n  $form-file-button-bg: $input-group-addon-bg;\n  $form-file-button-hover-bg: shade-color($form-file-button-bg, 5%);\n\n  $form-floating-height: ", ";\n  $form-floating-line-height: 1.25;\n  $form-floating-padding-x: $input-padding-x;\n  $form-floating-padding-y: 1rem;\n  $form-floating-input-padding-t: 1.625rem;\n  $form-floating-input-padding-b: 0.625rem;\n  $form-floating-label-opacity: 0.65;\n  $form-floating-label-transform: scale(0.85) translateY(-0.5rem)\n    translateX(0.15rem);\n  $form-floating-transition: opacity 0.1s ease-in-out,\n    transform 0.1s ease-in-out;\n\n  // Form validation\n\n  $form-feedback-margin-top: $form-text-margin-top;\n  $form-feedback-font-size: $form-text-font-size;\n  $form-feedback-font-style: $form-text-font-style;\n  $form-feedback-valid-color: $success;\n  $form-feedback-invalid-color: $danger;\n\n  $form-feedback-icon-valid-color: $form-feedback-valid-color;\n  $form-feedback-icon-valid: ", ";\n  $form-feedback-icon-invalid-color: $form-feedback-invalid-color;\n  $form-feedback-icon-invalid: ", ";\n\n  $form-validation-states: ", ";\n\n  // Z-index master list\n  //\n  // Warning: Avoid customizing these values. They're used for a bird's eye view\n  // of components dependent on the z-axis and are designed to all work together.\n\n  $zindex-dropdown: 1000;\n  $zindex-sticky: 1020;\n  $zindex-fixed: 1030;\n  $zindex-offcanvas-backdrop: 1040;\n  $zindex-offcanvas: 1045;\n  $zindex-modal-backdrop: 1050;\n  $zindex-modal: 1055;\n  $zindex-popover: 1070;\n  $zindex-tooltip: 1080;\n\n  // Navs\n\n  $nav-link-padding-y: 0.5rem;\n  $nav-link-padding-x: 1rem;\n  $nav-link-font-size: null;\n  $nav-link-font-weight: null;\n  $nav-link-color: $link-color;\n  $nav-link-hover-color: $link-hover-color;\n  $nav-link-transition: color 0.15s ease-in-out,\n    background-color 0.15s ease-in-out, border-color 0.15s ease-in-out;\n  $nav-link-disabled-color: $gray-600;\n\n  $nav-tabs-border-color: $gray-300;\n  $nav-tabs-border-width: $border-width;\n  $nav-tabs-border-radius: $border-radius;\n  $nav-tabs-link-hover-border-color: $gray-200 $gray-200 $nav-tabs-border-color;\n  $nav-tabs-link-active-color: $gray-700;\n  $nav-tabs-link-active-bg: $body-bg;\n  $nav-tabs-link-active-border-color: $gray-300 $gray-300\n    $nav-tabs-link-active-bg;\n\n  $nav-pills-border-radius: $border-radius;\n  $nav-pills-link-active-color: $component-active-color;\n  $nav-pills-link-active-bg: $component-active-bg;\n\n  // Navbar\n\n  $navbar-padding-y: $spacer * 0.5;\n  $navbar-padding-x: null;\n\n  $navbar-nav-link-padding-x: 0.5rem;\n\n  $navbar-brand-font-size: $font-size-lg;\n\n  $nav-link-height: $font-size-base * $line-height-base + $nav-link-padding-y *\n    2;\n  $navbar-brand-height: $navbar-brand-font-size * $line-height-base;\n  $navbar-brand-padding-y-intermediate-result: $nav-link-height -\n    $navbar-brand-height;\n  $navbar-brand-padding-y: $navbar-brand-padding-y-intermediate-result * 0.5;\n  $navbar-brand-margin-end: 1rem;\n\n  $navbar-toggler-padding-y: 0.25rem;\n  $navbar-toggler-padding-x: 0.75rem;\n  $navbar-toggler-font-size: $font-size-lg;\n  $navbar-toggler-border-radius: $btn-border-radius;\n  $navbar-toggler-focus-width: $btn-focus-width;\n  $navbar-toggler-transition: box-shadow 0.15s ease-in-out;\n\n  $navbar-dark-color: rgba($white, 0.55);\n  $navbar-dark-hover-color: rgba($white, 0.75);\n  $navbar-dark-active-color: $white;\n  $navbar-dark-disabled-color: rgba($white, 0.25);\n  $navbar-dark-toggler-icon-bg: ", ";\n  $navbar-dark-toggler-border-color: rgba($white, 0.1);\n\n  $navbar-light-color: rgba($black, 0.55);\n  $navbar-light-hover-color: rgba($black, 0.7);\n  $navbar-light-active-color: rgba($black, 0.9);\n  $navbar-light-disabled-color: rgba($black, 0.3);\n  $navbar-light-toggler-icon-bg: ", ";\n  $navbar-light-toggler-border-color: rgba($black, 0.1);\n\n  $navbar-light-brand-color: $navbar-light-active-color;\n  $navbar-light-brand-hover-color: $navbar-light-active-color;\n  $navbar-dark-brand-color: $navbar-dark-active-color;\n  $navbar-dark-brand-hover-color: $navbar-dark-active-color;\n\n  // Dropdowns\n  //\n  // Dropdown menu container and contents.\n\n  $dropdown-min-width: 10rem;\n  $dropdown-padding-x: 0;\n  $dropdown-padding-y: 0.5rem;\n  $dropdown-spacer: 0.125rem;\n  $dropdown-font-size: $font-size-base;\n  $dropdown-color: $body-color;\n  $dropdown-bg: $white;\n  $dropdown-border-color: rgba($black, 0.15);\n  $dropdown-border-radius: $border-radius;\n  $dropdown-border-width: $border-width;\n  $dropdown-inner-border-radius: ", ";\n  $dropdown-divider-bg: $dropdown-border-color;\n  $dropdown-divider-margin-y: $spacer * 0.5;\n  $dropdown-box-shadow: $box-shadow;\n\n  $dropdown-link-color: $gray-900;\n\n  $dropdown-link-hover-color: ", ";\n  $dropdown-link-hover-bg: $gray-200;\n\n  $dropdown-link-active-color: $component-active-color;\n  $dropdown-link-active-bg: $component-active-bg;\n\n  $dropdown-link-disabled-color: $gray-500;\n\n  $dropdown-item-padding-y: $spacer * 0.25;\n  $dropdown-item-padding-x: $spacer;\n\n  $dropdown-header-color: $gray-600;\n  $dropdown-header-padding: $dropdown-padding-y $dropdown-item-padding-x;\n\n  $dropdown-dark-color: $gray-300;\n  $dropdown-dark-bg: $gray-800;\n  $dropdown-dark-border-color: $dropdown-border-color;\n  $dropdown-dark-divider-bg: $dropdown-divider-bg;\n  $dropdown-dark-box-shadow: null;\n  $dropdown-dark-link-color: $dropdown-dark-color;\n  $dropdown-dark-link-hover-color: $white;\n  $dropdown-dark-link-hover-bg: rgba($white, 0.15);\n  $dropdown-dark-link-active-color: $dropdown-link-active-color;\n  $dropdown-dark-link-active-bg: $dropdown-link-active-bg;\n  $dropdown-dark-link-disabled-color: $gray-500;\n  $dropdown-dark-header-color: $gray-500;\n\n  // ...\n\n  // Cards\n\n  $card-spacer-y: $spacer;\n  $card-spacer-x: $spacer;\n  $card-title-spacer-y: $spacer * 0.5;\n  $card-border-width: $border-width;\n  $card-border-color: rgba($black, 0.125);\n  $card-border-radius: $border-radius;\n  $card-box-shadow: null;\n  $card-inner-border-radius: ", ";\n  $card-cap-padding-y: $card-spacer-y * 0.5;\n  $card-cap-padding-x: $card-spacer-x;\n  $card-cap-bg: rgba($black, 0.03);\n  $card-cap-color: null;\n  $card-height: null;\n  $card-color: null;\n  $card-bg: $white;\n  $card-img-overlay-padding: $spacer;\n  $card-group-margin: $grid-gutter-width * 0.5;\n\n  // ...\n\n  // Tooltips\n\n  $tooltip-font-size: $font-size-sm;\n  $tooltip-max-width: 200px;\n  $tooltip-color: $white;\n  $tooltip-bg: $black;\n  $tooltip-border-radius: $border-radius;\n  $tooltip-opacity: 0.9;\n  $tooltip-padding-y: $spacer * 0.25;\n  $tooltip-padding-x: $spacer * 0.5;\n  $tooltip-margin: 0;\n\n  $tooltip-arrow-width: 0.8rem;\n  $tooltip-arrow-height: 0.4rem;\n  $tooltip-arrow-color: $tooltip-bg;\n\n  // Popovers\n\n  $popover-font-size: $font-size-sm;\n  $popover-bg: $white;\n  $popover-max-width: 276px;\n  $popover-border-width: $border-width;\n  $popover-border-color: rgba($black, 0.2);\n  $popover-border-radius: $border-radius-lg;\n  $popover-inner-border-radius: ", ";\n  $popover-box-shadow: $box-shadow;\n\n  $popover-header-bg: ", ";\n  $popover-header-color: $headings-color;\n  $popover-header-padding-y: 0.5rem;\n  $popover-header-padding-x: $spacer;\n\n  $popover-body-color: $body-color;\n  $popover-body-padding-y: $spacer;\n  $popover-body-padding-x: $spacer;\n\n  $popover-arrow-width: 1rem;\n  $popover-arrow-height: 0.5rem;\n  $popover-arrow-color: $popover-bg;\n\n  $popover-arrow-outer-color: $popover-border-color;\n\n  // Toasts\n\n  $toast-max-width: 350px;\n  $toast-padding-x: 0.75rem;\n  $toast-padding-y: 0.5rem;\n  $toast-font-size: 0.875rem;\n  $toast-color: null;\n  $toast-background-color: rgba($white, 0.85);\n  $toast-border-width: 1px;\n  $toast-border-color: rgba($black, 0.1);\n  $toast-border-radius: $border-radius;\n  $toast-box-shadow: $box-shadow;\n  $toast-spacing: $container-padding-x;\n\n  $toast-header-color: $gray-600;\n  $toast-header-background-color: rgba($white, 0.85);\n  $toast-header-border-color: rgba($black, 0.05);\n\n  // Badges\n\n  $badge-font-size: $font-size-base * 0.75; // 0.75em;\n  $badge-font-weight: $font-weight-bold;\n  $badge-color: $white;\n  $badge-padding-y: $badge-font-size * 0.35; // 0.35em;\n  $badge-padding-x: $badge-font-size * 0.65; // 0.65em;\n  $badge-border-radius: $border-radius;\n\n  // Modals\n\n  $modal-inner-padding: $spacer;\n\n  $modal-footer-margin-between: 0.5rem;\n\n  $modal-dialog-margin: 0.5rem;\n  $modal-dialog-margin-y-sm-up: 1.75rem;\n\n  $modal-title-line-height: $line-height-base;\n\n  $modal-content-color: null;\n  $modal-content-bg: $white;\n  $modal-content-border-color: rgba($black, 0.65); // rgba($black, 0.2);\n  $modal-content-border-width: $border-width;\n  $modal-content-border-radius: $border-radius-lg;\n  $modal-content-inner-border-radius: ", ";\n  $modal-content-box-shadow-xs: $box-shadow-sm;\n  $modal-content-box-shadow-sm-up: $box-shadow;\n\n  $modal-backdrop-bg: $black;\n  $modal-backdrop-opacity: 0.5;\n  $modal-header-border-color: $border-color;\n  $modal-footer-border-color: $modal-header-border-color;\n  $modal-header-border-width: $modal-content-border-width;\n  $modal-footer-border-width: $modal-header-border-width;\n  $modal-header-padding-y: $modal-inner-padding;\n  $modal-header-padding-x: $modal-inner-padding;\n  $modal-header-padding: $modal-header-padding-y $modal-header-padding-x; // Keep this for backwards compatibility\n\n  $modal-sm: 300px;\n  $modal-md: 500px;\n  $modal-lg: 800px;\n  $modal-xl: 1140px;\n\n  $modal-fade-transform: translate(0, -50px);\n  $modal-show-transform: none;\n  $modal-transition: transform 0.3s ease-out;\n  $modal-scale-transform: scale(1.02);\n\n  // ...\n\n  // Alerts\n  //\n  // Define alert colors, border radius, and padding.\n\n  $alert-padding-y: $spacer;\n  $alert-padding-x: $spacer;\n  $alert-margin-bottom: 1rem;\n  $alert-border-radius: $border-radius;\n  $alert-link-font-weight: $font-weight-bold;\n  $alert-border-width: $border-width;\n  $alert-bg-scale: -80%;\n  $alert-border-scale: -70%;\n  $alert-color-scale: 40%;\n  $alert-dismissible-padding-r: $alert-padding-x * 3; // 3x covers width of x plus default padding on either side\n\n  // Pagination\n\n  $pagination-padding-y: 0.375rem;\n  $pagination-padding-x: 0.75rem;\n  $pagination-padding-y-sm: 0.25rem;\n  $pagination-padding-x-sm: 0.5rem;\n  $pagination-padding-y-lg: 0.75rem;\n  $pagination-padding-x-lg: 1.5rem;\n\n  $pagination-color: $link-color;\n  $pagination-bg: $white;\n  $pagination-border-width: $border-width;\n  $pagination-border-radius: $border-radius;\n  $pagination-margin-start: -$pagination-border-width;\n  $pagination-border-color: $gray-300;\n\n  $pagination-focus-color: $link-hover-color;\n  $pagination-focus-bg: $gray-200;\n  $pagination-focus-box-shadow: $input-btn-focus-box-shadow;\n  $pagination-focus-outline: 0;\n\n  $pagination-hover-color: $link-hover-color;\n  $pagination-hover-bg: $gray-200;\n  $pagination-hover-border-color: $gray-300;\n\n  $pagination-active-color: $component-active-color;\n  $pagination-active-bg: $component-active-bg;\n  $pagination-active-border-color: $pagination-active-bg;\n\n  $pagination-disabled-color: $gray-600;\n  $pagination-disabled-bg: $white;\n  $pagination-disabled-border-color: $gray-300;\n\n  $pagination-transition: color 0.15s ease-in-out,\n    background-color 0.15s ease-in-out, border-color 0.15s ease-in-out,\n    box-shadow 0.15s ease-in-out;\n\n  $pagination-border-radius-sm: $border-radius-sm;\n  $pagination-border-radius-lg: $border-radius-lg;\n\n  // Progress bars\n\n  $progress-height: 1rem;\n  $progress-font-size: $font-size-base * 0.75;\n  $progress-bg: $gray-200;\n  $progress-border-radius: $border-radius;\n  $progress-box-shadow: $box-shadow-inset;\n  $progress-bar-color: $white;\n  $progress-bar-bg: $primary;\n  $progress-bar-animation-timing: 1s linear infinite;\n  $progress-bar-transition: width 0.6s ease;\n\n  // List group\n\n  $list-group-color: $gray-900;\n  $list-group-bg: $white;\n  $list-group-border-color: rgba($black, 0.125);\n  $list-group-border-width: $border-width;\n  $list-group-border-radius: $border-radius;\n\n  $list-group-item-padding-y: $spacer * 0.5;\n  $list-group-item-padding-x: $spacer;\n  $list-group-item-bg-scale: -80%;\n  $list-group-item-color-scale: 40%;\n\n  $list-group-hover-bg: $gray-100;\n  $list-group-active-color: $component-active-color;\n  $list-group-active-bg: $component-active-bg;\n  $list-group-active-border-color: $list-group-active-bg;\n\n  $list-group-disabled-color: $gray-600;\n  $list-group-disabled-bg: $list-group-bg;\n\n  $list-group-action-color: $gray-700;\n  $list-group-action-hover-color: $list-group-action-color;\n\n  $list-group-action-active-color: $body-color;\n  $list-group-action-active-bg: $gray-200;\n\n  // ...\n\n  // Spinners\n\n  $spinner-width: 2rem;\n  $spinner-height: $spinner-width;\n  $spinner-vertical-align: $font-size-base * -0.125; // -.125em;\n  $spinner-border-width: $font-size-base * 0.25; // .25em;\n  $spinner-animation-speed: 0.75s;\n\n  $spinner-width-sm: 1rem;\n  $spinner-height-sm: $spinner-width-sm;\n  $spinner-border-width-sm: $font-size-base * 0.2; // .2em;\n\n  // Close\n\n  $btn-close-width: $font-size-base * 1; // 1em;\n  $btn-close-height: $btn-close-width;\n  $btn-close-padding-x: $font-size-base * 0.25; // .25em;\n  $btn-close-padding-y: $btn-close-padding-x;\n  $btn-close-color: $black;\n  $btn-close-bg: ", ";\n  $btn-close-focus-shadow: $input-btn-focus-box-shadow;\n  $btn-close-opacity: 0.5;\n  $btn-close-hover-opacity: 0.75;\n  $btn-close-focus-opacity: 1;\n  $btn-close-disabled-opacity: 0.25;\n  // $btn-close-white-filter: invert(1) grayscale(100%) brightness(200%);\n\n  // Offcanvas\n\n  $offcanvas-padding-y: $modal-inner-padding;\n  $offcanvas-padding-x: $modal-inner-padding;\n  $offcanvas-horizontal-width: 400px;\n  $offcanvas-vertical-height: 200px; // 30vh;\n  $offcanvas-transition-duration: 0.3s;\n  $offcanvas-border-color: $modal-content-border-color;\n  $offcanvas-border-width: $modal-content-border-width;\n  $offcanvas-title-line-height: $modal-title-line-height;\n  $offcanvas-bg-color: $modal-content-bg;\n  $offcanvas-color: $modal-content-color;\n  $offcanvas-box-shadow: $modal-content-box-shadow-xs;\n  $offcanvas-backdrop-bg: $modal-backdrop-bg;\n  $offcanvas-backdrop-opacity: $modal-backdrop-opacity;\n\n  // Code\n\n  $code-font-size: $small-font-size;\n  $code-color: $pink;\n\n  $kbd-padding-y: 0.2rem;\n  $kbd-padding-x: 0.4rem;\n  $kbd-font-size: $code-font-size;\n  $kbd-color: $white;\n  $kbd-bg: $gray-900;\n\n  $pre-color: null;\n"])), t => ({
  100: t['gray-100'],
  200: t['gray-200'],
  300: t['gray-300'],
  400: t['gray-400'],
  500: t['gray-500'],
  600: t['gray-600'],
  700: t['gray-700'],
  800: t['gray-800'],
  900: t['gray-900']
}), t => ({
  blue: t.blue,
  indigo: t.indigo,
  purple: t.purple,
  pink: t.pink,
  red: t.red,
  orange: t.orange,
  yellow: t.yellow,
  green: t.green,
  teal: t.teal,
  cyan: t.cyan
}), t => ({
  primary: t.primary,
  secondary: t.secondary,
  success: t.success,
  info: t.info,
  warning: t.warning,
  danger: t.danger,
  light: t.light,
  dark: t.dark
}), t => ({
  'blue-100': t['blue-100'],
  'blue-200': t['blue-200'],
  'blue-300': t['blue-300'],
  'blue-400': t['blue-400'],
  'blue-500': t['blue-500'],
  'blue-600': t['blue-600'],
  'blue-700': t['blue-700'],
  'blue-800': t['blue-800'],
  'blue-900': t['blue-900']
}), t => ({
  'indigo-100': t['indigo-100'],
  'indigo-200': t['indigo-200'],
  'indigo-300': t['indigo-300'],
  'indigo-400': t['indigo-400'],
  'indigo-500': t['indigo-500'],
  'indigo-600': t['indigo-600'],
  'indigo-700': t['indigo-700'],
  'indigo-800': t['indigo-800'],
  'indigo-900': t['indigo-900']
}), t => ({
  'purple-100': t['purple-100'],
  'purple-200': t['purple-200'],
  'purple-300': t['purple-300'],
  'purple-400': t['purple-400'],
  'purple-500': t['purple-500'],
  'purple-600': t['purple-600'],
  'purple-700': t['purple-700'],
  'purple-800': t['purple-800'],
  'purple-900': t['purple-900']
}), t => ({
  'pink-100': t['pink-100'],
  'pink-200': t['pink-200'],
  'pink-300': t['pink-300'],
  'pink-400': t['pink-400'],
  'pink-500': t['pink-500'],
  'pink-600': t['pink-600'],
  'pink-700': t['pink-700'],
  'pink-800': t['pink-800'],
  'pink-900': t['pink-900']
}), t => ({
  'red-100': t['red-100'],
  'red-200': t['red-200'],
  'red-300': t['red-300'],
  'red-400': t['red-400'],
  'red-500': t['red-500'],
  'red-600': t['red-600'],
  'red-700': t['red-700'],
  'red-800': t['red-800'],
  'red-900': t['red-900']
}), t => ({
  'orange-100': t['orange-100'],
  'orange-200': t['orange-200'],
  'orange-300': t['orange-300'],
  'orange-400': t['orange-400'],
  'orange-500': t['orange-500'],
  'orange-600': t['orange-600'],
  'orange-700': t['orange-700'],
  'orange-800': t['orange-800'],
  'orange-900': t['orange-900']
}), t => ({
  'yellow-100': t['yellow-100'],
  'yellow-200': t['yellow-200'],
  'yellow-300': t['yellow-300'],
  'yellow-400': t['yellow-400'],
  'yellow-500': t['yellow-500'],
  'yellow-600': t['yellow-600'],
  'yellow-700': t['yellow-700'],
  'yellow-800': t['yellow-800'],
  'yellow-900': t['yellow-900']
}), t => ({
  'green-100': t['green-100'],
  'green-200': t['green-200'],
  'green-300': t['green-300'],
  'green-400': t['green-400'],
  'green-500': t['green-500'],
  'green-600': t['green-600'],
  'green-700': t['green-700'],
  'green-800': t['green-800'],
  'green-900': t['green-900']
}), t => ({
  'teal-100': t['teal-100'],
  'teal-200': t['teal-200'],
  'teal-300': t['teal-300'],
  'teal-400': t['teal-400'],
  'teal-500': t['teal-500'],
  'teal-600': t['teal-600'],
  'teal-700': t['teal-700'],
  'teal-800': t['teal-800'],
  'teal-900': t['teal-900']
}), t => ({
  'cyan-100': t['cyan-100'],
  'cyan-200': t['cyan-200'],
  'cyan-300': t['cyan-300'],
  'cyan-400': t['cyan-400'],
  'cyan-500': t['cyan-500'],
  'cyan-600': t['cyan-600'],
  'cyan-700': t['cyan-700'],
  'cyan-800': t['cyan-800'],
  'cyan-900': t['cyan-900']
}), t => ({
  0: '0px',
  1: "".concat(t.spacer, " * 0.25"),
  2: "".concat(t.spacer, " * 0.5"),
  3: t.spacer,
  4: "".concat(t.spacer, " * 1.5"),
  5: "".concat(t.spacer, " * 3")
}), () => ({
  0: '0px',
  50: '50%',
  100: '100%'
}), shiftColor(t => t['link-color'], t => t['link-shade-percentage']), () => ({
  xs: 0,
  sm: 576,
  md: 768,
  lg: 992,
  xl: 1200,
  xxl: 1400
}), () => ({
  sm: '540px',
  md: '720px',
  lg: '960px',
  xl: '1140px',
  xxl: '1320px'
}), () => ({
  1: '1px',
  2: '2px',
  3: '3px',
  4: '4px',
  5: '5px'
}), () => ({
  '1x1': '100%',
  '4x3': 'calc(3 / 4 * 100%)',
  '16x9': 'calc(9 / 16 * 100%)',
  '21x9': 'calc(9 / 21 * 100%)'
}), () => reactNative.Platform.select({
  native: 'System',
  default: "\"system-ui, -apple-system, 'Segoe UI', Roboto, 'Helvetica Neue', Arial, 'Noto Sans', 'Liberation Sans', sans-serif, 'Apple Color Emoji', 'Segoe UI Emoji', 'Segoe UI Symbol', 'Noto Color Emoji'\""
}), () => reactNative.Platform.select({
  android: 'monospace',
  ios: 'Courier New',
  default: "\"SFMono-Regular, Menlo, Monaco, Consolas, 'Liberation Mono', 'Courier New', monospace\""
}), t => ({
  1: t['h1-font-size'],
  2: t['h2-font-size'],
  3: t['h3-font-size'],
  4: t['h4-font-size'],
  5: t['h5-font-size'],
  6: t['h6-font-size']
}), () => ({
  1: '5rem',
  2: '4.5rem',
  3: '4rem',
  4: '3.5rem',
  5: '3rem',
  6: '2.5rem'
}), () => '/', tintColor(t => t['component-active-bg'], 0.5), add(t => calculate(t['input-line-height'], '*', 1), t => calculate(t['input-padding-y'], '*', 2)), add(t => calculate(t['input-line-height'], '*', 0.5), t => t['input-padding-y']), add(t => calculate(t['input-line-height'], '*', 0.25), t => calculate(t['input-padding-y'], '*', 0.5)), add(t => calculate(t['input-line-height'], '*', t['input-font-size']),
// 1em
add(t => calculate(t['input-padding-y'], '*', 2), t => t['input-height-border'])), add(t => calculate(t['input-line-height'], '*', t['input-font-size-sm']),
// 1em
add(t => calculate(t['input-padding-y-sm'], '*', 2), t => t['input-height-border'])), add(t => calculate(t['input-line-height'], '*', t['input-font-size-lg']),
// 1em
add(t => calculate(t['input-padding-y-lg'], '*', 2), t => t['input-height-border'])), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 20 20'><path fill='none' stroke='#{$form-check-input-checked-color}' stroke-linecap='round' stroke-linejoin='round' stroke-width='3' d='m6 10 3 3 6-6'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'><circle r='2' fill='#{$form-check-input-checked-color}'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 20 20'><path fill='none' stroke='#{$form-check-input-indeterminate-color}' stroke-linecap='round' stroke-linejoin='round' stroke-width='3' d='M6 10h8'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'><circle r='3' fill='#{$form-switch-color}'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'><circle r='3' fill='#{$form-switch-focus-color}'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='-4 -4 8 8'><circle r='3' fill='#{$form-switch-checked-color}'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16'><path fill='none' stroke='#{$form-select-indicator-color}' stroke-linecap='round' stroke-linejoin='round' stroke-width='2' d='m2 5 6 6 6-6'/></svg>"), add('3.5rem', t => t['input-height-border']), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 8 8'><path fill='#{$form-feedback-icon-valid-color}' d='M2.3 6.73.6 4.53c-.4-1.04.46-1.4 1.1-.8l1.1 1.4 3.4-3.8c.6-.63 1.6-.27 1.2.7l-4 4.6c-.43.5-.8.4-1.1.1z'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 12 12' width='12' height='12' fill='none' stroke='#{$form-feedback-icon-invalid-color}'><circle cx='6' cy='6' r='4.5'/><path stroke-linejoin='round' d='M5.8 3.6h.4L6 6.5z'/><circle cx='6' cy='8.2' r='.6' fill='#{$form-feedback-icon-invalid-color}' stroke='none'/></svg>"), t => ({
  valid: {
    color: t['form-feedback-valid-color'],
    icon: t['form-feedback-icon-valid']
  },
  invalid: {
    color: t['form-feedback-invalid-color'],
    icon: t['form-feedback-icon-invalid']
  }
}), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'><path stroke='#{$navbar-dark-color}' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/></svg>"), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 30 30'><path stroke='#{$navbar-light-color}' stroke-linecap='round' stroke-miterlimit='10' stroke-width='2' d='M4 7h22M4 15h22M4 23h22'/></svg>"), subtract(t => t['dropdown-border-radius'], t => t['dropdown-border-width']), shadeColor(t => t['dropdown-link-color'], 0.1), subtract(t => t['card-border-radius'], t => t['card-border-width']), subtract(t => t['popover-border-radius'], t => t['popover-border-width']), shadeColor(t => t['popover-bg'], 0.06), subtract(t => t['modal-content-border-radius'], t => t['modal-content-border-width']), url("data:image/svg+xml,<svg xmlns='http://www.w3.org/2000/svg' viewBox='0 0 16 16' fill='#{$btn-close-color}'><path d='M.293.293a1 1 0 0 1 1.414 0L8 6.586 14.293.293a1 1 0 1 1 1.414 1.414L9.414 8l6.293 6.293a1 1 0 0 1-1.414 1.414L8 9.414l-6.293 6.293a1 1 0 0 1-1.414-1.414L6.586 8 .293 1.707a1 1 0 0 1 0-1.414z'/></svg>"));

const extractVariables = function (source) {
  let baseVariables = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {};
  let options = arguments.length > 2 ? arguments[2] : undefined;
  if (typeof source !== 'function') {
    // TODO: Resolve t => ... functions on source object.
    return _objectSpread2(_objectSpread2({}, source), baseVariables);
  }
  const result = transform(source.ast.children, baseVariables, options);
  return _objectSpread2(_objectSpread2({}, result[0].variables), baseVariables);
};
function makeTheme(customVariables) {
  const customTheme = extractVariables(customVariables);
  return extractVariables(variables, customTheme, {
    preferTheme: true
  });
}

let activeKey = null;
const themes = {};
const sheets = [];
const createSheet = sheet => {
  const theme = themes[activeKey];
  const statelessSource = {};
  const statefulSource = {};

  // Apply theme to themeable styles.
  Object.entries(sheet.source).forEach(_ref => {
    let [key, style] = _ref;
    // Resolve theme.
    const value = typeof style === 'function' ? style(theme, activeKey) : style;
    if (typeof value === 'function') {
      statefulSource[key] = value;
    } else {
      statelessSource[key] = value;
    }
  });

  // Wrap stateful and stateless in a proxy, so that we can update the styles on theme change.
  // For using Object.assign below we need some additional methods on the proxy that are mentioned here:
  // https://stackoverflow.com/questions/43185453/object-assign-and-proxies
  return new Proxy({
    keys: Object.keys(sheet.source),
    stateless: reactNative.StyleSheet.create(statelessSource),
    stateful: statefulSource
  }, {
    get(target, prop) {
      return target.stateless[prop] || target.stateful[prop] || undefined;
    },
    ownKeys: target => target.keys,
    getOwnPropertyDescriptor(target, name) {
      const proxy = this;
      return {
        get value() {
          return proxy.get(target, name);
        },
        configurable: true,
        enumerable: true
      };
    },
    has: (target, name) => target.keys.indexOf(name) >= 0
  });
};
const {
  absoluteFill,
  absoluteFillObject,
  hairlineWidth
} = reactNative.StyleSheet;
const StyleSheet = {
  create(source) {
    // Create sheet object.
    const sheet = {
      source,
      cache: {},
      active: null
    };

    // If initialized, set active sheet based by active theme.
    if (activeKey !== null) {
      sheet.cache[activeKey] = createSheet(sheet);
      sheet.active = sheet.cache[activeKey];
    } else {
      // Placeholder until build method is called.
      sheet.active = {};
    }
    sheets.push(sheet);
    return sheet.active;
  },
  build(theme) {
    let key = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : 'default';
    if (!themes[key]) {
      themes[key] = theme;
    }

    // If theme is already set, we don't need to do anything.
    if (key === activeKey) {
      return;
    }

    // Set new theme active.
    activeKey = key;

    // Update style sheets.
    sheets.forEach((_, i) => {
      // If there is no result for the active theme, we'll create a themed
      // style sheet.
      if (!sheets[i].cache[key]) {
        sheets[i].cache[key] = createSheet(sheets[i]);
      }

      // Assign active object, which is also returned from the create
      // function, so style changes will be applied on next rerender in
      // the components as well.
      Object.assign(sheets[i].active, sheets[i].cache[key]);
    });
  },
  value(key) {
    if (activeKey === null) {
      throw new Error('Use of StyleSheet.value() before initializing.');
    }
    const theme = themes[activeKey];
    return theme[key];
  },
  // Add default styles from StyleSheet
  absoluteFill,
  absoluteFillObject,
  hairlineWidth
};

const Context = /*#__PURE__*/React__default["default"].createContext();
Context.displayName = 'BootstrapRNContext';

const calculateViewport = (breakpoints, width) => {
  if (width < breakpoints.sm) {
    return 'xs';
  }
  if (width < breakpoints.md) {
    return 'sm';
  }
  if (width < breakpoints.lg) {
    return 'md';
  }
  if (width < breakpoints.xl) {
    return 'lg';
  }
  if (width < breakpoints.xxl) {
    return 'xl';
  }
  return 'xxl';
};
const getWidth = dimensions => {
  // Use web api on web because of issue #38:
  // https://github.com/examunity/bootstrap-rn/issues/38
  if (reactNative.Platform.OS === 'web') {
    return Math.max(document.documentElement.clientWidth || 0, window.innerWidth || 0);
  }
  return dimensions.window.width;
};
function useViewport(initialViewport) {
  const [viewport, setViewport] = React.useState(initialViewport);
  const breakpoints = StyleSheet.value('grid-breakpoints');
  const handleChange = dimensions => {
    const width = getWidth(dimensions);
    const nextViewport = calculateViewport(breakpoints, width);
    setViewport(nextViewport);
  };

  // Initially determine viewport after mounting.
  React.useEffect(() => {
    handleChange({
      window: reactNative.Dimensions.get('window')
    });
    const subscription = reactNative.Dimensions.addEventListener('change', handleChange);
    return () => {
      subscription.remove();
    };
  }, []);
  return viewport;
}

const propTypes$1A = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types,
  utilities: PropTypes__default["default"].object,
  // eslint-disable-next-line react/forbid-prop-types,
  modifiers: PropTypes__default["default"].object,
  ssrViewport: PropTypes__default["default"].string
};
function Provider(props) {
  const {
    children,
    utilities = {},
    modifiers = {},
    ssrViewport
  } = props;
  const viewport = useViewport(ssrViewport);
  const fixed = React.useMemo(() => [], []);
  const counter = React.useRef(0);
  const context = {
    utilities,
    modifiers,
    fixed,
    getViewport() {
      return viewport;
    },
    addFixedElement(ref) {
      fixed.push(ref);
      return {
        remove() {
          const index = fixed.findIndex(item => item === ref);
          fixed.splice(index, 1);
        }
      };
    },
    generateKey(prefix) {
      counter.current += 1;
      return "ui-".concat(prefix, "-").concat(counter.current);
    }
  };
  return /*#__PURE__*/React__default["default"].createElement(Context.Provider, {
    value: context
  }, /*#__PURE__*/React__default["default"].createElement(overlays.OverlayProvider, null, children));
}
Provider.propTypes = propTypes$1A;

const TextStyleContext = /*#__PURE__*/React__default["default"].createContext();
TextStyleContext.displayName = 'TextStyleContext';

function useMedia() {
  const context = React.useContext(Context);
  const viewport = context.getViewport();
  const breakpoints = StyleSheet.value('grid-breakpoints');
  const breakpointKeys = Object.keys(breakpoints);
  return {
    up(point) {
      return breakpointKeys.indexOf(viewport) >= breakpointKeys.indexOf(point);
    },
    down(point) {
      return breakpointKeys.indexOf(viewport) <= breakpointKeys.indexOf(point);
    },
    only(point) {
      return viewport === point;
    },
    between(lower, upper) {
      return this.up(lower) && this.down(upper);
    }
  };
}

const normalize = style => {
  if (!Array.isArray(style)) {
    return [style];
  }
  return style.filter(val => !!val).reduce((res, val) => [...res, ...normalize(val)], []);
};
function useStyle(style, styleName) {
  const {
    utilities: utilitiesStyles
  } = React.useContext(Context);
  const utilities = React.useMemo(() => {
    if (!styleName) {
      return null;
    }
    const names = styleName.split(' ');
    return names.map(name => {
      if (!utilitiesStyles[name]) {
        // eslint-disable-next-line no-console
        console.warn("Unknown utility style \"".concat(name, "\"."));
        return null;
      }
      return utilitiesStyles[name];
    });
  }, [styleName]);
  const styles = normalize(utilities ? [style, ...utilities] : style);
  return state => {
    const basicStyles = [];
    const interactionStyles = [];
    styles.forEach(value => {
      if (value && value.$$typeof === BOOTSTRAP_RN_STYLE) {
        // Style is a bootstrap style that contains basic and interaction styles.
        const [resolvedBasicStyles, resolvedInteractionStyles] = value(state);
        basicStyles.push(...resolvedBasicStyles);
        interactionStyles.push(...resolvedInteractionStyles);
      } else if (typeof value === 'function') {
        // Style is some other custom function type style.
        basicStyles.push(value(state));
      } else {
        // Style is basic object style.
        basicStyles.push(value);
      }
    });

    // Put basic styles first, then interaction styles for hover, focus, pressed.
    return [...basicStyles, ...interactionStyles];
  };
}

const _excluded$1y = ["children", "style", "textStyle", "styleName"];
const propTypes$1z = {
  children: PropTypes__default["default"].node,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
const View = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle,
      styleName
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1y);
  const media = useMedia();
  const context = React.useContext(TextStyleContext);
  const resolveStyle = useStyle(style, styleName);
  const resolveTextStyle = useStyle([context && context.style, textStyle]);
  const hasTextStyle = context && context.style || textStyle;
  return /*#__PURE__*/React__default["default"].createElement(reactNative.View, _extends({}, elementProps, {
    ref: ref,
    style: resolveStyle({
      media
    })
  }), hasTextStyle ? /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
    value: {
      style: resolveTextStyle({
        media
      }),
      hasAncestor: context && context.hasTextAncestor
    }
  }, children) : children);
});
View.displayName = 'View';
View.propTypes = propTypes$1z;

const _excluded$1x = ["children", "color", "dismissible", "style", "textStyle"];
var _templateObject$1d, _templateObject2$V, _templateObject3$t;
const propTypes$1y = {
  children: PropTypes__default["default"].node.isRequired,
  color: PropTypes__default["default"].oneOf(Object.keys(THEME_COLORS)),
  dismissible: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$1f = StyleSheet.create(_objectSpread2(_objectSpread2({
  '.alert': css(_templateObject$1d || (_templateObject$1d = _taggedTemplateLiteral(["\n    position: relative;\n    padding: $alert-padding-y $alert-padding-x;\n    margin-bottom: $alert-margin-bottom;\n    background-color: transparent;\n    border: $alert-border-width solid transparent;\n    border-radius: $alert-border-radius;\n  "])))
}, each(THEME_COLORS, (state, value) => ({
  [".alert-".concat(state)]: css(_templateObject2$V || (_templateObject2$V = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n    "])), shiftColor(value, t => t['alert-bg-scale']), shiftColor(value, t => t['alert-border-scale'])),
  [".alert-".concat(state, " --text")]: css(_templateObject3$t || (_templateObject3$t = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), shiftColor(value, t => t['alert-color-scale']))
}))), {}, {
  '.alert-dismissible': {
    // TODO
  }
}));
const Alert = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      color = 'primary',
      dismissible = false,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1x);
  const classes = getStyles(styles$1f, ['.alert', ".alert-".concat(color), dismissible && '.alert-dismissible']);
  const textClasses = getStyles(styles$1f, [".alert-".concat(color, " --text")]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: "alert",
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
Alert.displayName = 'Alert';
Alert.propTypes = propTypes$1y;

const _excluded$1w = ["color", "bold", "italic", "mark", "small", "style", "styleName"];
var _templateObject$1c, _templateObject2$U, _templateObject3$s, _templateObject4$o, _templateObject5$l;
const propTypes$1x = {
  color: PropTypes__default["default"].oneOf([...Object.keys(THEME_COLORS), 'muted', 'black-50', 'white-50']),
  small: PropTypes__default["default"].bool,
  mark: PropTypes__default["default"].bool,
  bold: PropTypes__default["default"].bool,
  italic: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
const styles$1e = StyleSheet.create({
  text: css(_templateObject$1c || (_templateObject$1c = _taggedTemplateLiteral(["\n    font-family: $font-family-base;\n    font-size: $font-size-base;\n    font-weight: $font-weight-base;\n    line-height: $font-size-base * $line-height-base;\n  "]))),
  strong: css(_templateObject2$U || (_templateObject2$U = _taggedTemplateLiteral(["\n    font-weight: $font-weight-bolder;\n  "]))),
  italic: css(_templateObject3$s || (_templateObject3$s = _taggedTemplateLiteral(["\n    font-style: italic;\n  "]))),
  small: css(_templateObject4$o || (_templateObject4$o = _taggedTemplateLiteral(["\n    font-size: $small-font-size;\n    line-height: $small-font-size * $line-height-base;\n  "]))),
  mark: css(_templateObject5$l || (_templateObject5$l = _taggedTemplateLiteral(["\n    padding: $mark-padding;\n    background-color: $mark-bg;\n  "])))
});
const getStyleName = (styleName, color) => {
  if (!color) {
    return styleName;
  }
  return styleName ? "text-".concat(color, " ").concat(styleName) : "text-".concat(color);
};
const Text = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      color,
      // will be deprecated soon
      bold = false,
      italic = false,
      mark = false,
      small = false,
      style,
      styleName
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1w);
  const media = useMedia();
  const context = React.useContext(TextStyleContext);
  const classes = getStyles(styles$1e, [bold && 'strong', italic && 'italic', small && 'small', mark && 'mark']);
  const resolveStyle = useStyle([
  // eslint-disable-next-line react/destructuring-assignment
  (!context || !context.hasTextAncestor) && styles$1e.text,
  // eslint-disable-next-line react/destructuring-assignment
  context && context.style, classes, style], getStyleName(styleName, color));
  const element = /*#__PURE__*/React__default["default"].createElement(reactNative.Text, _extends({}, elementProps, {
    ref: ref,
    style: resolveStyle({
      media
    })
  }));

  // eslint-disable-next-line react/destructuring-assignment
  if (context && context.hasTextAncestor && !context.style) {
    return element;
  }

  // If we are not in an ancestor context yet, we need to set hasTextAncestor
  // to true for nested text components. Furthermore we need to reset the
  // context style, because we only need to apply the style once.
  return /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
    value: {
      style: null,
      hasTextAncestor: true
    }
  }, element);
});
Text.displayName = 'Text';
Text.propTypes = propTypes$1x;

const _excluded$1v = ["children", "style", "textStyle"];
var _templateObject$1b, _templateObject2$T;
const propTypes$1w = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$1d = StyleSheet.create({
  '.badge': css(_templateObject$1b || (_templateObject$1b = _taggedTemplateLiteral(["\n    // display: inline-block;\n    padding: $badge-padding-y $badge-padding-x;\n    border-radius: $badge-border-radius;\n    // @include gradient-bg();\n  "]))),
  '.badge --text': css(_templateObject2$T || (_templateObject2$T = _taggedTemplateLiteral(["\n    font-size: $badge-font-size;\n    font-weight: $badge-font-weight;\n    line-height: $badge-font-size * 1;\n    color: $badge-color;\n    text-align: center;\n    // white-space: nowrap;\n    // vertical-align: baseline;\n  "])))
});
const Badge = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1v);
  const classes = getStyles(styles$1d, ['.badge']);
  const textClasses = getStyles(styles$1d, ['.badge --text']);

  // composite component
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(Text, {
    style: [textClasses, textStyle]
  }, children));
});
Badge.displayName = 'Badge';
Badge.propTypes = propTypes$1w;

const ListContext = /*#__PURE__*/React__default["default"].createContext();
ListContext.displayName = 'ListContext';

const wrapChildren = (children, cache) => React__default["default"].Children.map(children, child => {
  if (child === null) {
    return null;
  }
  if (child.type === React__default["default"].Fragment) {
    return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, {
      key: child.key
    }, wrapChildren(child.props.children, cache));
  }
  if ( /*#__PURE__*/React__default["default"].isValidElement(child) && typeof child === 'object') {
    // eslint-disable-next-line no-param-reassign
    cache.count += 1;
    const pos = cache.count;
    return /*#__PURE__*/React__default["default"].createElement(ListContext.Provider, {
      value: {
        nth(value) {
          return pos === value;
        },
        get first() {
          return pos === 1;
        },
        get last() {
          return pos === cache.count;
        },
        get length() {
          return cache.count;
        }
      },
      key: child.key
    }, child);
  }
  return null;
});
function useList(children) {
  return wrapChildren(children, {
    count: 0
  });
}

function useForcedContext(Context) {
  const context = React.useContext(Context);
  invariant__default["default"](context, "Failed to get context \"".concat(Context.displayName, "\"."));
  return context;
}

const _excluded$1u = ["children", "active", "style", "dividerStyle", "textStyle"];
var _templateObject$1a, _templateObject2$S, _templateObject3$r;
const propTypes$1v = {
  children: PropTypes__default["default"].node.isRequired,
  active: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  dividerStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$1c = StyleSheet.create({
  '.breadcrumb-item + .breadcrumb-item': css(_templateObject$1a || (_templateObject$1a = _taggedTemplateLiteral(["\n    flex-direction: row; // added for bootstrap-rn\n    padding-left: $breadcrumb-item-padding-x;\n  "]))),
  '.breadcrumb-item + .breadcrumb-item::before': css(_templateObject2$S || (_templateObject2$S = _taggedTemplateLiteral(["\n    // float: left; // Suppress inline spacings and underlining of the separator\n    padding-right: $breadcrumb-item-padding-x;\n    color: $breadcrumb-divider-color;\n  "]))),
  '.breadcrumb-item.active --text': css(_templateObject3$r || (_templateObject3$r = _taggedTemplateLiteral(["\n    color: $breadcrumb-active-color;\n  "])))
});
const BreadcrumbItem = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      active = false,
      style,
      dividerStyle,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1u);
  const {
    first
  } = useForcedContext(ListContext);
  const classes = getStyles(styles$1c, [!first && '.breadcrumb-item + .breadcrumb-item']);
  const textClasses = getStyles(styles$1c, [active && '.breadcrumb-item.active --text']);
  const dividerClasses = getStyles(styles$1c, ['.breadcrumb-item + .breadcrumb-item::before']);
  const role = reactNative.Platform.OS === 'web' ? 'listitem' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role
  }, optional(active, {
    accessibilityCurrent: 'page'
  }), {
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), !first && /*#__PURE__*/React__default["default"].createElement(Text, {
    selectable: false,
    style: [dividerClasses, dividerStyle]
  }, reactNative.I18nManager.isRTL ? StyleSheet.value('breadcrumb-divider-flipped') : StyleSheet.value('breadcrumb-divider')), children);
});
BreadcrumbItem.displayName = 'BreadcrumbItem';
BreadcrumbItem.propTypes = propTypes$1v;

const _excluded$1t = ["children", "style", "textStyle"];
var _templateObject$19, _templateObject2$R;
const propTypes$1u = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$1b = StyleSheet.create({
  '.breadcrumb': css(_templateObject$19 || (_templateObject$19 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    padding: $breadcrumb-padding-y $breadcrumb-padding-x;\n    margin-bottom: $breadcrumb-margin-bottom;\n    // list-style: none;\n    background-color: $breadcrumb-bg;\n    border-radius: $breadcrumb-border-radius;\n  "]))),
  '.breadcrumb --text': css(_templateObject2$R || (_templateObject2$R = _taggedTemplateLiteral(["\n    font-size: $breadcrumb-font-size;\n    line-height: $breadcrumb-font-size * $line-height-base; // added for bootstrap-rn\n  "])))
});
const Breadcrumb = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1t);
  const list = useList(children);
  const classes = getStyles(styles$1b, ['.breadcrumb']);
  const textClasses = getStyles(styles$1b, ['.breadcrumb --text']);
  const role = reactNative.Platform.OS === 'web' ? 'list' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), list);
});
Breadcrumb.displayName = 'Breadcrumb';
Breadcrumb.propTypes = propTypes$1u;
Breadcrumb.Item = BreadcrumbItem;

const ButtonGroupContext = /*#__PURE__*/React__default["default"].createContext();
ButtonGroupContext.displayName = 'ButtonGroupContext';

const _excluded$1s = ["children", "size", "style"];
var _templateObject$18;
const propTypes$1t = {
  children: PropTypes__default["default"].node.isRequired,
  size: PropTypes__default["default"].oneOf(['lg', 'sm']),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$1a = StyleSheet.create({
  '.btn-group': css(_templateObject$18 || (_templateObject$18 = _taggedTemplateLiteral(["\n    flex-direction: row; // added for bootstrap-rn\n    border-radius: $btn-border-radius;\n  "])))
});
const ButtonGroup = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      size,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1s);
  const list = useList(children);
  const classes = getStyles(styles$1a, ['.btn-group']);

  // Accessiblity role tabpanel is only supported on web.
  const role = reactNative.Platform.OS === 'web' ? 'group' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(ButtonGroupContext.Provider, {
    value: {
      size
    }
  }, list));
});
ButtonGroup.displayName = 'ButtonGroup';
ButtonGroup.propTypes = propTypes$1t;

const _excluded$1r = ["children", "style"];
var _templateObject$17;
const propTypes$1s = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$19 = StyleSheet.create({
  '.btn-toolbar': css(_templateObject$17 || (_templateObject$17 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    justify-content: flex-start;\n  "])))
});
const ButtonToolbar = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1r);
  const classes = getStyles(styles$19, ['.btn-toolbar']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: "toolbar",
    style: [classes, style]
  }), children);
});
ButtonToolbar.displayName = 'ButtonToolbar';
ButtonToolbar.propTypes = propTypes$1s;

const _excluded$1q = ["ref"];
function useModifier(name, props, ref) {
  const context = useForcedContext(Context);
  const useModifierHook = context.modifiers[name];
  if (!useModifier) {
    return [props, ref];
  }
  const _useModifierHook = useModifierHook(props),
    {
      ref: modifierRef
    } = _useModifierHook,
    modifierProps = _objectWithoutProperties(_useModifierHook, _excluded$1q);
  return [modifierProps, concatRefs(modifierRef, ref)];
}

const _excluded$1p = ["toggle", "dismiss"],
  _excluded2$3 = ["ref"];
const getActionHook = (toggle, dismiss) => {
  if (toggle) {
    return toggle.useToggle || toggle;
  }
  if (dismiss) {
    return dismiss.useDismiss || dismiss;
  }
  return null;
};
function useAction(props, ref) {
  const {
      toggle,
      dismiss
    } = props,
    restProps = _objectWithoutProperties(props, _excluded$1p);
  const useActionHook = getActionHook(toggle, dismiss);
  if (!useActionHook) {
    return [props, ref];
  }
  if (typeof useActionHook !== 'function') {
    throw new Error('Action hook must be of type function.');
  }
  const _useActionHook = useActionHook(restProps),
    {
      ref: actionRef
    } = _useActionHook,
    actionProps = _objectWithoutProperties(_useActionHook, _excluded2$3);
  return [actionProps, concatRefs(actionRef, ref)];
}

function useInteractionState(_ref) {
  let {
    onFocus = () => {},
    onBlur = () => {},
    onHoverIn = () => {},
    onHoverOut = () => {},
    onPressIn = () => {},
    onPressOut = () => {},
    autoFocus
  } = _ref;
  const [active, setActive] = React.useState(false);
  const [hover, setHovered] = React.useState(false);
  const {
    isFocused: focus$1,
    isFocusVisible: focusVisible,
    focusProps
  } = focus.useFocusRing({
    autoFocus
  });
  const interactionProps = React.useMemo(() => ({
    onHoverIn(event) {
      setHovered(true);
      onHoverIn(event);
    },
    onHoverOut(event) {
      setHovered(false);
      onHoverOut(event);
    },
    onFocus(event) {
      focusProps.onFocus(event);
      onFocus(event);
    },
    onBlur(event) {
      focusProps.onBlur(event);
      onBlur(event);
    },
    onPressIn(event) {
      setActive(true);
      onPressIn(event);
    },
    onPressOut(event) {
      setActive(false);
      onPressOut(event);
    }
  }), [onFocus, onBlur, onHoverIn, onHoverOut, onPressIn, onPressOut]);
  const interaction = {
    hover,
    focus: focus$1,
    focusVisible,
    active
  };
  return {
    interaction,
    interactionProps
  };
}

const _excluded$1o = ["color", "direction", "style"];
var _templateObject$16, _templateObject2$Q, _templateObject3$q, _templateObject4$n, _templateObject5$k;
const DIRECTIONS$2 = ['up', 'down', 'start', 'end'];
const propTypes$1r = {
  color: PropTypes__default["default"].string,
  direction: PropTypes__default["default"].oneOf(DIRECTIONS$2),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const getColor = context => {
  if (context && context.style) {
    const flattenedStyle = reactNative.StyleSheet.flatten(context.style);
    if (flattenedStyle.color) {
      return flattenedStyle.color;
    }
  }
  return StyleSheet.value('body-color');
};
const getBorderColorStyle = (color, direction) => {
  switch (direction) {
    case 'down':
      return {
        borderTopColor: color
      };
    case 'up':
      return {
        borderBottomColor: color
      };
    case 'end':
      return reactNative.I18nManager.isRTL ? {
        borderRightColor: color
      } : {
        borderLeftColor: color
      };
    case 'start':
      return reactNative.I18nManager.isRTL ? {
        borderLeftColor: color
      } : {
        borderRightColor: color
      };
    default:
      throw new Error('Unknown direction.');
  }
};
const styles$18 = StyleSheet.create({
  caret: css(_templateObject$16 || (_templateObject$16 = _taggedTemplateLiteral(["\n    // &::after styles\n    // display: inline-block;\n    margin-left: $caret-spacing;\n    // vertical-align: $caret-vertical-align;\n    align-self: center; // added for bootstrap-rn\n    // content: \"\";\n  "]))),
  'caret-down': css(_templateObject2$Q || (_templateObject2$Q = _taggedTemplateLiteral(["\n    // &::after styles\n    border-top-width: $caret-width;\n    border-right-width: $caret-width;\n    border-right-color: transparent;\n    border-bottom-width: 0;\n    border-left-width: $caret-width;\n    border-left-color: transparent;\n  "]))),
  'caret-up': css(_templateObject3$q || (_templateObject3$q = _taggedTemplateLiteral(["\n    // &::after styles\n    border-top-width: 0;\n    border-right-width: $caret-width;\n    border-right-color: transparent;\n    border-bottom-width: $caret-width;\n    border-left-width: $caret-width;\n    border-left-color: transparent;\n  "]))),
  'caret-end': css(_templateObject4$n || (_templateObject4$n = _taggedTemplateLiteral(["\n    // &::after styles\n    border-top-width: $caret-width;\n    border-top-color: transparent;\n    border-right-width: 0;\n    border-bottom-width: $caret-width;\n    border-bottom-color: transparent;\n    border-left-width: $caret-width;\n  "]))),
  'caret-start': css(_templateObject5$k || (_templateObject5$k = _taggedTemplateLiteral(["\n    // &::after styles\n    // display: none;\n\n    // &::before styles\n    // display: inline-block;\n    margin-left: 0; // added for bootstrap-rn\n    margin-right: $caret-spacing;\n    // vertical-align: $vertical-align;\n    // content: \"\";\n    border-top-width: $caret-width;\n    border-top-color: transparent;\n    border-right-width: $caret-width;\n    border-bottom-width: $caret-width;\n    border-bottom-color: transparent;\n  "])))
});
const Caret = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      color,
      direction = 'down',
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1o);
  const context = React.useContext(TextStyleContext);
  const classes = getStyles(styles$18, ['caret', "caret-".concat(direction)]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, getBorderColorStyle(color || getColor(context), direction), style]
  }));
});
Caret.displayName = 'Caret';
Caret.propTypes = propTypes$1r;

const _excluded$1n = ["children", "caret", "active", "style", "activeStyle", "textStyle", "activeTextStyle", "styleName"];
const DIRECTIONS$1 = ['up', 'down', 'start', 'end'];
const propTypes$1q = {
  children: PropTypes__default["default"].node,
  caret: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].shape({
    direction: PropTypes__default["default"].oneOf(DIRECTIONS$1),
    color: PropTypes__default["default"].string
  })]),
  active: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  activeStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  activeTextStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};

// One of the following should be set for aria support:
// 1) accessibilityRole
// 2) accessibilityLabel + accessibilityHint
// 3) accessibilityActions + onAccessibilityAction
const getRole$2 = props => {
  const {
    accessibilityRole,
    accessibilityLabel,
    accessibilityActions
  } = props;
  if (accessibilityRole) {
    return accessibilityRole;
  }
  if (accessibilityLabel || accessibilityActions) {
    return null;
  }
  return 'button';
};
const applyCaret = (children, caret) => {
  if (!caret) {
    return children;
  }
  const options = caret === true ? {} : caret;
  const element = /*#__PURE__*/React__default["default"].createElement(Caret, {
    color: options.color,
    direction: options.direction
  });
  const space = /*#__PURE__*/React__default["default"].createElement(reactNative.Text, null, " ");
  const isLeftCaret = options.direction === (reactNative.I18nManager.isRTL ? 'end' : 'start');
  if (isLeftCaret) {
    return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, element, space, children);
  }
  return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, children, space, element);
};
const Pressable = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useActionable', props, ref);
  const [actionProps, actionRef] = useAction(modifierProps, modifierRef);
  const {
      children,
      caret = false,
      active = false,
      style,
      activeStyle,
      textStyle,
      activeTextStyle,
      styleName
    } = actionProps,
    elementProps = _objectWithoutProperties(actionProps, _excluded$1n);
  const media = useMedia();
  const context = React.useContext(TextStyleContext);
  const resolveStyle = useStyle(style, styleName);
  const resolveActiveStyle = useStyle(active && activeStyle);
  const resolveTextStyle = useStyle([context && context.style, textStyle]);
  const resolveActiveTextStyle = useStyle(active && activeTextStyle);
  const {
    interaction,
    interactionProps
  } = useInteractionState(elementProps);
  const hasTextStyle = context && context.style || textStyle;
  const wrappedChildren = applyCaret(children, caret);
  return /*#__PURE__*/React__default["default"].createElement(reactNative.Pressable, _extends({}, elementProps, interactionProps, {
    ref: actionRef,
    accessibilityRole: getRole$2(actionProps),
    style: [resolveStyle({
      media,
      interaction
    }), resolveActiveStyle({
      media,
      interaction
    })]
  }), hasTextStyle ? /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
    value: {
      style: [resolveTextStyle({
        media,
        interaction
      }), resolveActiveTextStyle({
        media,
        interaction
      })],
      hasAncestor: context && context.hasTextAncestor
    }
  }, wrappedChildren) : wrappedChildren);
});
Pressable.displayName = 'Pressable';
Pressable.propTypes = propTypes$1q;

const _excluded$1m = ["active", "handlePress"];
function useToggleButton(props) {
  const {
      active,
      handlePress
    } = props,
    restProps = _objectWithoutProperties(props, _excluded$1m);
  const [pressed, setPressed] = React.useState(active);
  return _objectSpread2(_objectSpread2({}, restProps), {}, {
    active: pressed,
    onPress: event => {
      if (handlePress) handlePress(event);
      setPressed(value => !value);
    },
    accessibilityPressed: pressed
  });
}

const _excluded$1l = ["children", "color", "size", "outline", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];
var _templateObject$15, _templateObject2$P, _templateObject3$p, _templateObject4$m, _templateObject5$j, _templateObject6$g, _templateObject7$b, _templateObject8$b, _templateObject9$a, _templateObject10$a, _templateObject11$7, _templateObject12$5, _templateObject13$5, _templateObject14$4, _templateObject15$4, _templateObject16$1, _templateObject17$1, _templateObject18$1, _templateObject19$1, _templateObject20$1, _templateObject21, _templateObject22, _templateObject23;
const propTypes$1p = {
  children: PropTypes__default["default"].node.isRequired,
  color: PropTypes__default["default"].oneOf([...Object.keys(THEME_COLORS), 'link']),
  size: PropTypes__default["default"].oneOf(['lg', 'sm']),
  outline: PropTypes__default["default"].bool,
  active: PropTypes__default["default"].bool,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  activeStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  activeTextStyle: PropTypes__default["default"].any
};
const styles$17 = StyleSheet.create(_objectSpread2(_objectSpread2({
  '.btn': css(_templateObject$15 || (_templateObject$15 = _taggedTemplateLiteral(["\n    flex-direction: row; // added for bootstrap-rn\n    justify-content: center; // added for bootstrap-rn\n    // display: inline-block;\n    @include platform(web) {\n      // cursor: if($enable-button-pointers, pointer, null);\n      user-select: none;\n    }\n    background-color: transparent;\n    border: $btn-border-width solid transparent;\n    padding: $btn-padding-y $btn-padding-x;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius;\n    // @include transition($btn-transition);\n\n    &:focus-visible {\n      // outline: 0;\n      // box-shadow: $btn-focus-box-shadow;\n    }\n\n    &:active {\n      // @include box-shadow($btn-active-box-shadow);\n\n      &:focus-visible {\n        // @include box-shadow($btn-focus-box-shadow, $btn-active-box-shadow);\n      }\n    }\n  "]))),
  '.btn --text': css(_templateObject2$P || (_templateObject2$P = _taggedTemplateLiteral(["\n    font-family: $btn-font-family;\n    font-weight: $btn-font-weight;\n    line-height: $btn-font-size * $btn-line-height;\n    color: $body-color;\n    text-align: center;\n    text-decoration: none; // if($link-decoration == none, null, none);\n    white-space: $btn-white-space;\n    // vertical-align: middle;\n    font-size: $btn-font-size;\n\n    &:hover {\n      color: $body-color;\n      text-decoration: none; // if($link-decoration == none, null, none);\n    }\n  "]))),
  '.btn.disabled': css(_templateObject3$p || (_templateObject3$p = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    opacity: $btn-disabled-opacity;\n    // @include box-shadow(none);\n  "])))
}, each(THEME_COLORS, (color, value) => ({
  [".btn-".concat(color)]: css(_templateObject4$m || (_templateObject4$m = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n      // @include box-shadow($btn-box-shadow);\n\n      &:hover {\n        background-color: ", ";\n        border-color: ", ";\n      }\n\n      &:focus-visible {\n        background-color: ", ";\n        border-color: ", ";\n        /* @if $enable-shadows {\n          @include box-shadow($btn-box-shadow, 0 0 0 $btn-focus-width rgba(mix($color, $border, 15%), .5));\n        } @else {\n          // Avoid using mixin so we can pass custom focus shadow properly\n          box-shadow: 0 0 0 $btn-focus-width rgba(mix($color, $border, 15%), .5);\n        } */\n      }\n\n      &:active {\n        background-color: ", ";\n        // Remove CSS gradients if they're enabled\n        // background-image: if($enable-gradients, none, null);\n        border-color: ", ";\n      }\n    "])), value, value, shadeColor(value, t => t['btn-hover-bg-shade-amount']), shadeColor(value, t => t['btn-hover-border-shade-amount']), shadeColor(value, t => t['btn-hover-bg-shade-amount']), shadeColor(value, t => t['btn-hover-border-shade-amount']), shadeColor(value, t => t['btn-active-bg-shade-amount']), shadeColor(value, t => t['btn-active-border-shade-amount'])),
  [".btn-".concat(color, " --text")]: css(_templateObject5$j || (_templateObject5$j = _taggedTemplateLiteral(["\n      color: ", ";\n\n      &:hover {\n        color: ", ";\n      }\n\n      &:focus-visible {\n        color: ", ";\n      }\n\n      &:active {\n        color: ", ";\n      }\n    "])), colorContrast(value), colorContrast(value), colorContrast(value), colorContrast(value)),
  [".btn-".concat(color, ".active")]: css(_templateObject6$g || (_templateObject6$g = _taggedTemplateLiteral(["\n      background-color: ", ";\n      // Remove CSS gradients if they're enabled\n      // background-image: if($enable-gradients, none, null);\n      border-color: ", ";\n    "])), shadeColor(value, t => t['btn-active-bg-shade-amount']), shadeColor(value, t => t['btn-active-border-shade-amount'])),
  [".btn-".concat(color, ".active --text")]: css(_templateObject7$b || (_templateObject7$b = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), colorContrast(value)),
  [".btn-".concat(color, ".disabled")]: css(_templateObject8$b || (_templateObject8$b = _taggedTemplateLiteral(["\n      $disabled-background: ", ";\n      $disabled-border: ", ";\n\n      background-color: $disabled-background;\n      // Remove CSS gradients if they're enabled\n      // background-image: if($enable-gradients, none, null);\n      border-color: $disabled-border;\n    "])), value, value),
  [".btn-".concat(color, ".disabled --text")]: css(_templateObject9$a || (_templateObject9$a = _taggedTemplateLiteral(["\n      $disabled-color: ", ";\n\n      color: $disabled-color;\n    "])), colorContrast(value)),
  [".btn-outline-".concat(color)]: css(_templateObject10$a || (_templateObject10$a = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:hover {\n        background-color: ", ";\n        border-color: ", ";\n      }\n\n      &:focus-visible {\n        // box-shadow: 0 0 0 $btn-focus-width rgba($color, .5);\n      }\n\n      &:active {\n        background-color: ", ";\n        border-color: ", ";\n\n        /* &:focus {\n          @if $enable-shadows {\n            @include box-shadow(\n              $btn-active-box-shadow,\n              0 0 0 $btn-focus-width rgba($color, 0.5)\n            );\n          } @else {\n            // Avoid using mixin so we can pass custom focus shadow properly\n            box-shadow: 0 0 0 $btn-focus-width rgba($color, 0.5);\n          }\n        } */\n      }\n    "])), value, value, value, value, value),
  [".btn-outline-".concat(color, " --text")]: css(_templateObject11$7 || (_templateObject11$7 = _taggedTemplateLiteral(["\n      color: ", ";\n\n      &:hover {\n        color: ", ";\n      }\n\n      &:active {\n        color: ", ";\n      }\n    "])), value, colorContrast(value), colorContrast(value)),
  [".btn-outline-".concat(color, ".disabled")]: css(_templateObject12$5 || (_templateObject12$5 = _taggedTemplateLiteral(["\n      background-color: transparent;\n    "]))),
  [".btn-outline-".concat(color, ".disabled --text")]: css(_templateObject13$5 || (_templateObject13$5 = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), value)
}))), {}, {
  '.btn-link --text': css(_templateObject14$4 || (_templateObject14$4 = _taggedTemplateLiteral(["\n    font-weight: $font-weight-normal;\n    color: $btn-link-color;\n    text-decoration-color: $btn-link-color; // added for bootstrap-rn\n    text-decoration-line: $link-decoration;\n\n    &:hover {\n      color: $btn-link-hover-color;\n      text-decoration-color: $btn-link-hover-color; // added for bootstrap-rn\n      text-decoration-line: $link-hover-decoration;\n    }\n\n    &:focus-visible {\n      text-decoration-line: $link-hover-decoration;\n    }\n\n    // No need for an active state here\n  "]))),
  '.btn-link.disabled --text': css(_templateObject15$4 || (_templateObject15$4 = _taggedTemplateLiteral(["\n    color: $btn-link-disabled-color;\n  "]))),
  '.btn-lg': css(_templateObject16$1 || (_templateObject16$1 = _taggedTemplateLiteral(["\n    padding: $btn-padding-y-lg $btn-padding-x-lg;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius-lg;\n  "]))),
  '.btn-lg --text': css(_templateObject17$1 || (_templateObject17$1 = _taggedTemplateLiteral(["\n    line-height: $btn-font-size-lg * $btn-line-height;\n    font-size: $btn-font-size-lg;\n  "]))),
  '.btn-sm': css(_templateObject18$1 || (_templateObject18$1 = _taggedTemplateLiteral(["\n    padding: $btn-padding-y-sm $btn-padding-x-sm;\n    // Manually declare to provide an override to the browser default\n    border-radius: $btn-border-radius-sm;\n  "]))),
  '.btn-sm --text': css(_templateObject19$1 || (_templateObject19$1 = _taggedTemplateLiteral(["\n    line-height: $btn-font-size-sm * $btn-line-height;\n    font-size: $btn-font-size-sm;\n  "]))),
  '.btn-group > .btn': css(_templateObject20$1 || (_templateObject20$1 = _taggedTemplateLiteral(["\n    position: relative;\n    // flex: 1 1 auto;\n\n    &:hover {\n      z-index: 1;\n    }\n    &:focus-visible {\n      z-index: 1;\n    }\n    &:active {\n      z-index: 1;\n    }\n  "]))),
  '.btn-group > .btn.active': css(_templateObject21 || (_templateObject21 = _taggedTemplateLiteral(["\n    z-index: 2; // 1;\n  "]))),
  '.btn-group > .btn:not(:first-child)': css(_templateObject22 || (_templateObject22 = _taggedTemplateLiteral(["\n    margin-left: -$btn-border-width;\n    border-top-left-radius: 0;\n    border-bottom-left-radius: 0;\n  "]))),
  '.btn-group > .btn:not(:last-child)': css(_templateObject23 || (_templateObject23 = _taggedTemplateLiteral(["\n    border-top-right-radius: 0;\n    border-bottom-right-radius: 0;\n  "])))
}));
const getVariant = (color, outline) => {
  if (color === 'link') {
    return null;
  }
  if (outline) {
    return ".btn-outline-".concat(color);
  }
  return ".btn-".concat(color);
};
const hasSize = (size, group, value) => {
  if (size !== undefined || !group) {
    return size === value;
  }
  return group.size === value;
};
const Button = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      color = 'primary',
      size,
      outline = false,
      active = false,
      disabled = false,
      style,
      activeStyle,
      textStyle,
      activeTextStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1l);
  invariant__default["default"](color !== 'link' || !outline, 'Button link variant is only available as non outline style.');
  const listItem = React.useContext(ListContext);
  const group = React.useContext(ButtonGroupContext);
  const classes = getStyles(styles$17, ['.btn', getVariant(color, outline), disabled && '.btn.disabled', disabled && "".concat(getVariant(color, outline), ".disabled"), hasSize(size, group, 'lg') && '.btn-lg', hasSize(size, group, 'sm') && '.btn-sm', group && '.btn-group > .btn', group && active && '.btn-group > .btn.active', group && !listItem.first && '.btn-group > .btn:not(:first-child)', group && !listItem.last && '.btn-group > .btn:not(:last-child)']);
  const activeClasses = getStyles(styles$17, ["".concat(getVariant(color, outline), ".active")]);
  const textClasses = getStyles(styles$17, ['.btn --text', "".concat(getVariant(color, outline), " --text"), color === 'link' && '.btn-link --text', disabled && "".concat(getVariant(color, outline), ".disabled --text"), disabled && color === 'link' && '.btn-link.disabled --text', hasSize(size, group, 'lg') && '.btn-lg --text', hasSize(size, group, 'sm') && '.btn-sm --text']);
  const activeTextClasses = getStyles(styles$17, ["".concat(getVariant(color, outline), ".active --text")]);
  return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends({}, elementProps, {
    ref: ref,
    active: active,
    disabled: disabled,
    style: [...classes, style],
    activeStyle: [...activeClasses, activeStyle],
    textStyle: [...textClasses, textStyle],
    activeTextStyle: [...activeTextClasses, activeTextStyle]
  }), children);
});
Button.displayName = 'Button';
Button.propTypes = propTypes$1p;
Button.useToggle = useToggleButton;

const _excluded$1k = ["children", "style", "textStyle"];
var _templateObject$14, _templateObject2$O;
const propTypes$1o = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$16 = StyleSheet.create({
  blockquote: css(_templateObject$14 || (_templateObject$14 = _taggedTemplateLiteral(["\n    margin-bottom: $blockquote-margin-y;\n  "]))),
  'blockquote --text': css(_templateObject2$O || (_templateObject2$O = _taggedTemplateLiteral(["\n    font-size: $blockquote-font-size;\n  "])))
});
const Blockquote = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1k);
  const classes = getStyles(styles$16, ['blockquote']);
  const textClasses = getStyles(styles$16, ['blockquote --text']);

  // Accessiblity role blockquote is only supported on web.
  const role = reactNative.Platform.OS === 'web' ? 'blockquote' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
Blockquote.displayName = 'Blockquote';
Blockquote.propTypes = propTypes$1o;

const _excluded$1j = ["children", "style", "textStyle", "styleName"];
var _templateObject$13, _templateObject2$N;
const propTypes$1n = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
const styles$15 = StyleSheet.create({
  body: css(_templateObject$13 || (_templateObject$13 = _taggedTemplateLiteral(["\n    background-color: $body-bg;\n    flex-grow: 1; // added for bootstrap-rn\n    flex-shrink: 1; // added for bootstrap-rn\n  "]))),
  'body --text': css(_templateObject2$N || (_templateObject2$N = _taggedTemplateLiteral(["\n    color: $body-color;\n    text-align: $body-text-align;\n  "])))
});
const Body = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle,
      styleName
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1j);
  const classes = getStyles(styles$15, ['body']);
  const textClasses = getStyles(styles$15, ['body --text']);
  const media = useMedia();
  const resolveStyle = useStyle([classes, style], styleName);
  const resolveTextStyle = useStyle([textClasses, textStyle]);
  return /*#__PURE__*/React__default["default"].createElement(reactNative.SafeAreaView, _extends({}, elementProps, {
    ref: ref,
    style: resolveStyle({
      media
    })
  }), /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
    value: {
      style: resolveTextStyle({
        media
      })
    }
  }, children));
});
Body.displayName = 'Body';
Body.propTypes = propTypes$1n;

const _excluded$1i = ["children", "style", "textStyle"];
var _templateObject$12, _templateObject2$M;
const propTypes$1m = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$14 = StyleSheet.create({
  '.card-body': css(_templateObject$12 || (_templateObject$12 = _taggedTemplateLiteral(["\n    // flex: 1 1 auto;\n    padding: $card-spacer-y $card-spacer-x;\n  "]))),
  '.card-body --text': css(_templateObject2$M || (_templateObject2$M = _taggedTemplateLiteral(["\n    color: $card-color;\n  "])))
});
const CardBody = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1i);
  const classes = getStyles(styles$14, ['.card-body']);
  const textClasses = getStyles(styles$14, [".card-body --text"]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
CardBody.displayName = 'CardBody';
CardBody.propTypes = propTypes$1m;

const _excluded$1h = ["children", "style", "textStyle"];
var _templateObject$11, _templateObject2$L;
const propTypes$1l = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$13 = StyleSheet.create({
  '.card-header': css(_templateObject$11 || (_templateObject$11 = _taggedTemplateLiteral(["\n    padding: $card-cap-padding-y $card-cap-padding-x;\n    background-color: $card-cap-bg;\n    border-bottom-width: $card-border-width;\n    border-style: solid;\n    border-color: $card-border-color;\n    border-radius: $card-inner-border-radius $card-inner-border-radius 0 0;\n  "]))),
  '.card-header --text': css(_templateObject2$L || (_templateObject2$L = _taggedTemplateLiteral(["\n    margin-bottom: 0; // Removes the default margin-bottom of <hN>\n    color: $card-cap-color;\n  "])))
});
const CardHeader = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1h);
  const classes = getStyles(styles$13, ['.card-header']);
  const textClasses = getStyles(styles$13, ['.card-header --text']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
CardHeader.displayName = 'CardHeader';
CardHeader.propTypes = propTypes$1l;

const _excluded$1g = ["children", "style", "textStyle"];
var _templateObject$10, _templateObject2$K;
const propTypes$1k = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$12 = StyleSheet.create({
  '.card-footer': css(_templateObject$10 || (_templateObject$10 = _taggedTemplateLiteral(["\n    padding: $card-cap-padding-y $card-cap-padding-x;\n    background-color: $card-cap-bg;\n    border-top-width: $card-border-width;\n    border-style: solid;\n    border-color: $card-border-color;\n    border-radius: 0 0 $card-inner-border-radius $card-inner-border-radius;\n  "]))),
  '.card-footer --text': css(_templateObject2$K || (_templateObject2$K = _taggedTemplateLiteral(["\n    color: $card-cap-color;\n  "])))
});
const CardFooter = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1g);
  const classes = getStyles(styles$12, ['.card-footer']);
  const textClasses = getStyles(styles$12, ['.card-footer --text']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
CardFooter.displayName = 'CardFooter';
CardFooter.propTypes = propTypes$1k;

const _excluded$1f = ["children", "style"];
var _templateObject$$;
const propTypes$1j = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$11 = StyleSheet.create({
  '.card': css(_templateObject$$ || (_templateObject$$ = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-direction: column;\n    min-width: 0;\n    height: $card-height;\n    // word-wrap: break-word;\n    background-color: $card-bg;\n    // background-clip: border-box;\n    border: $card-border-width solid $card-border-color;\n    border-radius: $card-border-radius;\n    // @include box-shadow($card-box-shadow);\n  "])))
});
const Card = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1f);
  const classes = getStyles(styles$11, ['.card']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
Card.displayName = 'Card';
Card.propTypes = propTypes$1j;
Card.Header = CardHeader;
Card.Body = CardBody;
Card.Footer = CardFooter;

const ModalContext = /*#__PURE__*/React__default["default"].createContext();
ModalContext.displayName = 'ModalContext';

const OffcanvasContext = /*#__PURE__*/React__default["default"].createContext();
OffcanvasContext.displayName = 'OffcanvasContext';

const styles$10 = reactNative.StyleSheet.create({
  reset: {
    // Background repeat is not supported on native yet.
    backgroundRepeat: 'no-repeat'
  }
});
const normalizeValue = value => typeof value === 'number' && value !== 0 ? "".concat(value, "px") : value;
const resolveBackgroundSize = style => {
  const {
    backgroundSize
  } = style;
  if (typeof backgroundSize !== 'object') {
    return backgroundSize;
  }
  const {
    width = 'auto',
    height = 'auto'
  } = backgroundSize;
  return "".concat(normalizeValue(width), " ").concat(normalizeValue(height));
};
const resolveBackgroundPosition = style => {
  const {
    backgroundPosition,
    backgroundPositionX,
    backgroundPositionY
  } = style;
  if (!backgroundPosition && !backgroundPositionX && !backgroundPositionY) {
    return null;
  }
  const value = {
    positionX: backgroundPosition || 'left',
    offsetX: 0,
    positionY: backgroundPosition || 'top',
    offsetY: 0
  };
  if (backgroundPositionX) {
    const {
      position: positionX = 'left',
      offset: offsetX = 0
    } = typeof backgroundPositionX === 'object' ? backgroundPositionX : {
      position: backgroundPositionX
    };
    value.positionX = positionX;
    value.offsetX = normalizeValue(offsetX);
  }
  if (backgroundPositionY) {
    const {
      position: positionY = 'top',
      offset: offsetY = 0
    } = typeof backgroundPositionY === 'object' ? backgroundPositionY : {
      position: backgroundPositionY
    };
    value.positionY = positionY;
    value.offsetY = normalizeValue(offsetY);
  }
  const valueX = value.offsetX ? "".concat(value.positionX, " ").concat(value.offsetX) : value.positionX;
  const valueY = value.offsetY ? "".concat(value.positionY, " ").concat(value.offsetY) : value.positionY;
  return "".concat(valueX, " ").concat(valueY);
};
function useBackgroundWeb(style) {
  const flattenedStyle = reactNative.StyleSheet.flatten(style);
  return {
    style: [flattenedStyle, styles$10.reset, {
      // Transform background size
      backgroundSize: resolveBackgroundSize(flattenedStyle),
      // Workaround, because some browsers do not support two-value syntax:
      // https://developer.mozilla.org/en-US/docs/Web/CSS/background-position-x#browser_compatibility
      backgroundPositionX: null,
      backgroundPositionY: null,
      backgroundPosition: resolveBackgroundPosition(flattenedStyle)
    }],
    element: null
  };
}

const styles$$ = reactNative.StyleSheet.create({
  container: {
    overflow: 'hidden'
  },
  object: {
    aspectRatio: 1
  }
});
const horizontalPositions = {
  left: function () {
    let offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    return {
      alignItems: reactNative.I18nManager.isRTL ? 'flex-end' : 'flex-start',
      paddingLeft: offset
    };
  },
  right: function () {
    let offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    return {
      alignItems: reactNative.I18nManager.isRTL ? 'flex-start' : 'flex-end',
      paddingRight: offset
    };
  },
  center: offset => {
    if (offset !== undefined) {
      return null;
    }
    return {
      alignItems: 'center'
    };
  }
};
const verticalPositions = {
  top: function () {
    let offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    return {
      justifyContent: 'flex-start',
      paddingTop: offset
    };
  },
  bottom: function () {
    let offset = arguments.length > 0 && arguments[0] !== undefined ? arguments[0] : 0;
    return {
      justifyContent: 'flex-end',
      paddingBottom: offset
    };
  },
  center: offset => {
    if (offset !== undefined) {
      return null;
    }
    return {
      justifyContent: 'center'
    };
  }
};
const getXml = value => {
  const match = value.match(/^url\("data:image\/svg\+xml,(.*?)"\)$/);
  if (!match) {
    return null;
  }
  return decodeURIComponent(match[1]);
};
const transforms = {
  backgroundSize(value) {
    if (value === 'cover') {
      return {
        width: '100%'
        // TODO: Support cover for views with height > width.
        // height: '100%',
      };
    }

    if (value === 'contain') {
      return {
        width: '100%',
        height: '100%'
      };
    }
    const {
      width,
      height = width
    } = value;
    return {
      width,
      height
    };
  },
  backgroundPosition(value) {
    if (value === 'center') {
      return {
        alignItems: 'center',
        justifyContent: 'center'
      };
    }
    if (horizontalPositions[value]) {
      return _objectSpread2(_objectSpread2({}, horizontalPositions[value]()), {}, {
        justifyContent: 'center'
      });
    }
    if (verticalPositions[value]) {
      return _objectSpread2({
        alignItems: 'center'
      }, verticalPositions[value]());
    }
    return null;
  },
  backgroundPositionX(value) {
    const {
      position = 'left',
      offset
    } = typeof value === 'object' ? value : {
      position: value
    };
    if (!horizontalPositions[position]) {
      return null;
    }
    return horizontalPositions[position](offset);
  },
  backgroundPositionY(value) {
    const {
      position = 'top',
      offset
    } = typeof value === 'object' ? value : {
      position: value
    };
    if (!verticalPositions[position]) {
      return null;
    }
    return verticalPositions[position](offset);
  }
};
function useBackgroundNative(style) {
  const flattenedStyle = reactNative.StyleSheet.flatten(style);
  const background = {
    containerStyle: {},
    objectStyle: {},
    xml: null
  };
  Object.entries(flattenedStyle).forEach(_ref => {
    let [key, value] = _ref;
    if (!value) {
      return;
    }
    if (key === 'backgroundImage') {
      background.xml = getXml(value);
    } else if (key === 'backgroundSize') {
      Object.assign(background.objectStyle, transforms[key](value));
    } else if (key === 'backgroundPosition' || key === 'backgroundPositionX' || key === 'backgroundPositionY') {
      Object.assign(background.containerStyle, transforms[key](value));
    }
  });
  return {
    style: flattenedStyle,
    element: /*#__PURE__*/React__default["default"].createElement(reactNative.View, {
      style: [reactNative.StyleSheet.absoluteFill, styles$$.container, background.containerStyle]
    }, /*#__PURE__*/React__default["default"].createElement(reactNative.View, {
      style: [styles$$.object, background.objectStyle]
    }, background.xml && /*#__PURE__*/React__default["default"].createElement(reactNativeSvg.SvgXml, {
      xml: background.xml
    })))
  };
}

// The assumed background styles are typed as followed:
//
// type Position = 'center' | 'left' | 'right' | 'top' | 'bottom';
// type PositionX = 'center' | 'left' | 'right';
// type PositionY = 'center' | 'top' | 'bottom';
//
// type BackgroundStyles = {
//   backgroundImage: string,
//   backgroundSize: 'contain' | 'cover' | string | number,
//   backgroundPosition: Position,
//   backgroundPositionX:
//     | PositionX
//     | { position: PositionX, offset: string | number },
//   backgroundPositionY:
//     | PositionY
//     | { position: PositionY, offset: string | number },
// };

function useBackground(style, styleName) {
  // TODO: Use *.web.js / *.native.js file endings to select platforms, but
  // before we need to make sure that the published bundles are all functional.
  const useBackgroundForPlatform = reactNative.Platform.select({
    web: useBackgroundWeb,
    default: useBackgroundNative
  });
  return useBackgroundForPlatform(style, styleName);
}

const _excluded$1e = ["children", "disabled", "style", "textStyle", "styleName"];
var _templateObject$_, _templateObject2$J, _templateObject3$o, _templateObject4$l, _templateObject5$i;
const propTypes$1i = {
  children: PropTypes__default["default"].node,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
const styles$_ = StyleSheet.create({
  '.btn-close': css(_templateObject$_ || (_templateObject$_ = _taggedTemplateLiteral(["\n    // Workaround for missing box-sizing in react native.\n    $additional-width: $btn-close-padding-x * 2;\n    $additional-height: $btn-close-padding-y * 2;\n\n    // box-sizing: content-box;\n    width: $btn-close-width + $additional-width;\n    height: $btn-close-height + $additional-height;\n    padding: $btn-close-padding-y $btn-close-padding-x;\n    background-color: transparent; // include transparent for button elements\n    background-image: ", ";\n    background-position: center;\n    background-size: $btn-close-width auto;\n    background-repeat: no-repeat;\n    border-width: 0; // for button elements\n    // @include border-radius();\n    opacity: $btn-close-opacity;\n\n    &:hover {\n      opacity: $btn-close-hover-opacity;\n    }\n\n    &:focus {\n      // outline: 0;\n      // box-shadow: $btn-close-focus-shadow;\n      opacity: $btn-close-focus-opacity;\n    }\n  "])), t => escapeSvg(t['btn-close-bg'])),
  '.btn-close --text': css(_templateObject2$J || (_templateObject2$J = _taggedTemplateLiteral(["\n    color: $btn-close-color;\n\n    // Override <a>'s hover style\n    &:hover {\n      color: $btn-close-color;\n      text-decoration: none;\n    }\n  "]))),
  '.btn-close.disabled': css(_templateObject3$o || (_templateObject3$o = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    // user-select: none;\n    opacity: $btn-close-disabled-opacity;\n  "]))),
  // Modal styles
  '.modal-header .btn-close': css(_templateObject4$l || (_templateObject4$l = _taggedTemplateLiteral(["\n    padding: $modal-header-padding-y * 0.5 $modal-header-padding-x * 0.5;\n    margin: -0.5 * $modal-header-padding-y -0.5 * $modal-header-padding-x -0.5 *\n      $modal-header-padding-y auto;\n\n    // Workaround for missing box-sizing in react native.\n    width: $btn-close-width + $modal-header-padding-x;\n    height: $btn-close-height + $modal-header-padding-y;\n  "]))),
  // Offcanvas styles
  '.offcanvas-header .btn-close': css(_templateObject5$i || (_templateObject5$i = _taggedTemplateLiteral(["\n    padding: $offcanvas-padding-y * 0.5 $offcanvas-padding-x * 0.5;\n    margin-top: -0.5 * $offcanvas-padding-y;\n    margin-right: -0.5 * $offcanvas-padding-x;\n    margin-bottom: -0.5 * $offcanvas-padding-y;\n\n    // Workaround for missing box-sizing in react native.\n    width: $btn-close-width + $offcanvas-padding-x;\n    height: $btn-close-height + $offcanvas-padding-y;\n  "])))
});
const CloseButton = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      disabled = false,
      style,
      textStyle,
      styleName
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1e);
  const media = useMedia();
  const modal = React.useContext(ModalContext);
  const offcanvas = React.useContext(OffcanvasContext);
  const classes = getStyles(styles$_, ['.btn-close', disabled && '.btn-close.disabled',
  // Modal styles
  modal && '.modal-header .btn-close',
  // Offcanvas styles
  offcanvas && '.offcanvas-header .btn-close']);
  const textClasses = getStyles(styles$_, ['.btn-close --text']);
  const resolveStyle = useStyle([classes, style], styleName);
  const {
    interaction,
    interactionProps
  } = useInteractionState(elementProps);
  const background = useBackground(resolveStyle({
    media,
    interaction
  }));
  return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends({}, elementProps, interactionProps, {
    component: Pressable,
    ref: ref,
    disabled: disabled,
    style: background.style,
    textStyle: [textClasses, textStyle]
  }), background.element);
});
CloseButton.displayName = 'CloseButton';
CloseButton.propTypes = propTypes$1i;

const CollapseContext = /*#__PURE__*/React__default["default"].createContext();
CollapseContext.displayName = 'CollapseContext';

function useIdentifier(prefix) {
  const context = React.useContext(Context);
  const ref = React.useRef();
  if (!ref.current) {
    ref.current = context.generateKey(prefix);
  }
  return ref.current;
}

function useControlledState(defaultValue, controlledValue) {
  let handleChange = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : () => {};
  const [stateValue, setStateValue] = React.useState(defaultValue);
  const isControlled = controlledValue !== undefined && controlledValue !== null;
  const value = isControlled ? controlledValue : stateValue;
  const setValue = next => {
    const nextValue = typeof next === 'function' ? next(value) : next;
    if (value === nextValue) {
      return;
    }
    if (!isControlled) {
      setStateValue(next);
    }
    handleChange(nextValue);
  };
  return [value, setValue];
}

function useCollapse(defaultVisible, controlledVisible, onToggle) {
  const identifier = useIdentifier('collapse');
  const [visible, setVisible] = useControlledState(defaultVisible, controlledVisible, onToggle);
  return React.useMemo(() => ({
    identifier,
    visible,
    setVisible
  }), [visible]);
}

const propTypes$1h = {
  children: PropTypes__default["default"].node.isRequired,
  defaultVisible: PropTypes__default["default"].bool,
  visible: PropTypes__default["default"].bool,
  onToggle: PropTypes__default["default"].func
};
const CollapseProvider = props => {
  const {
    children,
    defaultVisible = false,
    visible,
    onToggle
  } = props;
  const collapse = useCollapse(defaultVisible, visible, onToggle);
  return /*#__PURE__*/React__default["default"].createElement(CollapseContext.Provider, {
    value: collapse
  }, children);
};
CollapseProvider.displayName = 'CollapseProvider';
CollapseProvider.propTypes = propTypes$1h;

const _excluded$1d = ["onPress"];
function useToggleCollapse(props) {
  const context = useForcedContext(CollapseContext);
  const {
      onPress: handlePress
    } = props,
    restProps = _objectWithoutProperties(props, _excluded$1d);
  return _objectSpread2(_objectSpread2({}, restProps), {}, {
    onPress: event => {
      if (handlePress) handlePress(event);
      context.setVisible(value => !value);
    },
    accessibilityExpanded: context.visible,
    accessibilityControls: context.identifier
  });
}

const _excluded$1c = ["children"];
const propTypes$1g = {
  children: PropTypes__default["default"].node
};
const Collapse = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1c);
  const {
    identifier,
    visible
  } = useForcedContext(CollapseContext);
  if (!visible) {
    return null;
  }
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    nativeID: identifier
  }), children);
});
Collapse.displayName = 'Collapse';
Collapse.propTypes = propTypes$1g;
Collapse.Provider = CollapseProvider;
Collapse.useToggle = useToggleCollapse;

function next(name) {
  const names = Object.keys(GRID_BREAKPOINTS);
  const n = names.indexOf(name);
  if (n === -1) {
    throw new Error("Breakpoint ".concat(name, " not found."));
  }
  return n < names.length ? names[n + 1] : '';
}
function infix(breakpoint) {
  if (!breakpoint || breakpoint === 'xs') {
    return '';
  }
  return "-".concat(breakpoint);
}

const NavbarContext = /*#__PURE__*/React__default["default"].createContext();
NavbarContext.displayName = 'NavbarContext';

const _excluded$1b = ["fluid", "style"];
var _templateObject$Z, _templateObject2$I, _templateObject3$n, _templateObject4$k, _templateObject5$h, _templateObject6$f, _templateObject7$a, _templateObject8$a;
const propTypes$1f = {
  children: PropTypes__default["default"].node.isRequired,
  fluid: PropTypes__default["default"].oneOf([true, ...Object.keys(CONTAINER_MAX_WIDTHS)]),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$Z = StyleSheet.create(_objectSpread2({
  '.container': css(_templateObject$Z || (_templateObject$Z = _taggedTemplateLiteral(["\n    width: 100%;\n    padding-right: $container-padding-x;\n    padding-left: $container-padding-x;\n    margin-right: auto;\n    margin-left: auto;\n  "]))),
  '.container-sm': css(_templateObject2$I || (_templateObject2$I = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(sm) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(md) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), t => t['container-max-widths'].sm, t => t['container-max-widths'].md, t => t['container-max-widths'].lg, t => t['container-max-widths'].xl, t => t['container-max-widths'].xxl),
  '.container-md': css(_templateObject3$n || (_templateObject3$n = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(md) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), t => t['container-max-widths'].md, t => t['container-max-widths'].lg, t => t['container-max-widths'].xl, t => t['container-max-widths'].xxl),
  '.container-lg': css(_templateObject4$k || (_templateObject4$k = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(lg) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), t => t['container-max-widths'].lg, t => t['container-max-widths'].xl, t => t['container-max-widths'].xxl),
  '.container-xl': css(_templateObject5$h || (_templateObject5$h = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(xl) {\n      max-width: ", ";\n    }\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), t => t['container-max-widths'].xl, t => t['container-max-widths'].xxl),
  '.container-xxl': css(_templateObject6$f || (_templateObject6$f = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(xxl) {\n      max-width: ", ";\n    }\n  "])), t => t['container-max-widths'].xxl),
  // Navbar styles
  '.navbar .container': css(_templateObject7$a || (_templateObject7$a = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    align-items: center;\n    justify-content: space-between;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .container")]: css(_templateObject8$a || (_templateObject8$a = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-wrap: nowrap;\n      }\n    "])), next(breakpoint))
}))));
const Container = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      fluid = 'sm',
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1b);
  const navbar = React.useContext(NavbarContext);
  const classes = getStyles(styles$Z, ['.container',
  // Hint: Bootstrap's .container class is identical with .container-sm.
  fluid !== true && ".container-".concat(fluid),
  // Navbar styles
  navbar && '.navbar .container', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .container")]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }));
});
Container.displayName = 'Container';
Container.propTypes = propTypes$1f;

const FormCheckContext = /*#__PURE__*/React__default["default"].createContext();
FormCheckContext.displayName = 'FormCheckContext';

const _excluded$1a = ["style"];
const propTypes$1e = {
  type: PropTypes__default["default"].oneOf(['checkbox', 'radio', 'switch']).isRequired,
  value: PropTypes__default["default"].bool.isRequired,
  onValueChange: PropTypes__default["default"].func,
  onFocus: PropTypes__default["default"].func,
  onBlur: PropTypes__default["default"].func,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  nativeID: PropTypes__default["default"].any
};
const styles$Y = reactNative.StyleSheet.create({
  reboot: {
    flexShrink: 0,
    margin: 0
  }
});

// eslint-disable-next-line react/prop-types
const Input$1 = /*#__PURE__*/React__default["default"].forwardRef((_ref, ref) => {
  let {
      style
    } = _ref,
    props = _objectWithoutProperties(_ref, _excluded$1a);
  return reactNative.unstable_createElement('input', _objectSpread2(_objectSpread2({}, props), {}, {
    ref,
    style: [styles$Y.reboot, style]
  }));
});
const FormCheckInputWeb = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
    type,
    value,
    onValueChange: handleValueChange,
    onFocus = () => {},
    onBlur = () => {},
    disabled = false,
    style,
    nativeID
  } = props;
  const inputBackground = useBackground(style);
  return /*#__PURE__*/React__default["default"].createElement(Input$1, {
    ref: ref,
    type: type === 'switch' ? 'checkbox' : type,
    checked: value,
    onChange: () => {
      handleValueChange(!value);
    },
    onFocus: onFocus,
    onBlur: onBlur,
    disabled: disabled,
    style: inputBackground.style,
    nativeID: nativeID
  });
});
FormCheckInputWeb.displayName = 'FormCheckInputWeb';
FormCheckInputWeb.propTypes = propTypes$1e;

const propTypes$1d = {
  type: PropTypes__default["default"].oneOf(['checkbox', 'radio', 'switch']).isRequired,
  value: PropTypes__default["default"].bool.isRequired,
  onValueChange: PropTypes__default["default"].func,
  onFocus: PropTypes__default["default"].func,
  onBlur: PropTypes__default["default"].func,
  hitSlop: PropTypes__default["default"].number,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  nativeID: PropTypes__default["default"].any
};
const FormCheckInputNative = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
    type,
    value,
    onValueChange: handleValueChange,
    onFocus = () => {},
    onBlur = () => {},
    hitSlop = 8,
    disabled = false,
    style,
    nativeID
  } = props;
  const inputBackground = useBackground(style);
  return /*#__PURE__*/React__default["default"].createElement(Pressable, {
    ref: ref,
    accessibilityRole: type,
    accessibilityChecked: value,
    onPress: () => {
      handleValueChange(!value);
    },
    onFocus: onFocus,
    onBlur: onBlur,
    hitSlop: hitSlop,
    disabled: disabled,
    style: inputBackground.style,
    nativeID: nativeID
  }, inputBackground.element);
});
FormCheckInputNative.displayName = 'FormCheckInputNative';
FormCheckInputNative.propTypes = propTypes$1d;

const _excluded$19 = ["type", "value", "onFocus", "onBlur", "disabled", "valid", "invalid", "useNativeComponent", "autoFocus", "style"];
var _templateObject$Y, _templateObject2$H, _templateObject3$m, _templateObject4$j, _templateObject5$g, _templateObject6$e, _templateObject7$9, _templateObject8$9, _templateObject9$9, _templateObject10$9, _templateObject11$6, _templateObject12$4, _templateObject13$4, _templateObject14$3, _templateObject15$3;

/* eslint-disable react/no-unused-prop-types */
const propTypes$1c = {
  type: PropTypes__default["default"].oneOf(['checkbox', 'radio', 'switch']).isRequired,
  value: PropTypes__default["default"].bool.isRequired,
  onFocus: PropTypes__default["default"].func,
  onBlur: PropTypes__default["default"].func,
  disabled: PropTypes__default["default"].bool,
  valid: PropTypes__default["default"].bool,
  invalid: PropTypes__default["default"].bool,
  useNativeComponent: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
  // eslint-disable-next-line react/forbid-prop-types
};
/* eslint-enable */

const styles$X = StyleSheet.create(_objectSpread2(_objectSpread2({
  '.form-check .form-check-input': css(_templateObject$Y || (_templateObject$Y = _taggedTemplateLiteral(["\n    $margin-top-double: $line-height-base - $form-check-input-width;\n\n    // float: left;\n    // margin-left: $form-check-padding-start * -1;\n    margin-top: $margin-top-double * 0.5; // added for bootstrap-rn\n    margin-right: $form-check-padding-start - $form-check-input-width; // added for bootstrap-rn\n  "]))),
  '.form-check-reverse .form-check-input': css(_templateObject2$H || (_templateObject2$H = _taggedTemplateLiteral(["\n    // float: right;\n    // margin-right: $form-check-padding-start * -1;\n    margin-right: 0; // added for bootstrap-rn\n    // margin-left: 0;\n    margin-left: $form-check-padding-start - $form-check-input-width; // added for bootstrap-rn\n  "]))),
  '.form-check-input': css(_templateObject3$m || (_templateObject3$m = _taggedTemplateLiteral(["\n    width: $form-check-input-width;\n    height: $form-check-input-width;\n    // margin-top: ($line-height-base - $form-check-input-width) * 0.5; // line-height minus check height\n    // vertical-align: top;\n    background-color: $form-check-input-bg;\n    background-repeat: no-repeat;\n    background-position: center;\n    background-size: contain;\n    border: $form-check-input-border;\n    @include platform(web) {\n      appearance: none;\n      user-select: none; // added for bootstrap-rn\n      color-adjust: exact; // Keep themed appearance for print\n    }\n    // @include transition($form-check-transition);\n\n    &:active {\n      // filter: $form-check-input-active-filter;\n    }\n\n    &:focus {\n      border-color: $form-check-input-focus-border;\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n        box-shadow: $form-check-input-focus-box-shadow;\n      }\n    }\n  "]))),
  '.form-check-input[type="checkbox"]': css(_templateObject4$j || (_templateObject4$j = _taggedTemplateLiteral(["\n    border-radius: $form-check-input-border-radius;\n  "]))),
  '.form-check-input[type="radio"]': css(_templateObject5$g || (_templateObject5$g = _taggedTemplateLiteral(["\n    border-radius: $form-check-radio-border-radius;\n  "]))),
  '.form-check-input:checked': css(_templateObject6$e || (_templateObject6$e = _taggedTemplateLiteral(["\n    background-color: $form-check-input-checked-bg-color;\n    border-color: $form-check-input-checked-border-color;\n  "]))),
  '.form-check-input[type="checkbox"]:checked': css(_templateObject7$9 || (_templateObject7$9 = _taggedTemplateLiteral(["\n    // @if $enable-gradients {\n    //   background-image: escape-svg($form-check-input-checked-bg-image), var(--#{$variable-prefix}gradient);\n    // } @else {\n    background-image: ", ";\n    // }\n  "])), t => escapeSvg(t['form-check-input-checked-bg-image'])),
  '.form-check-input[type="radio"]:checked': css(_templateObject8$9 || (_templateObject8$9 = _taggedTemplateLiteral(["\n    // @if $enable-gradients {\n    //   background-image: escape-svg($form-check-radio-checked-bg-image), var(--#{$variable-prefix}gradient);\n    // } @else {\n    background-image: ", ";\n    // }\n  "])), t => escapeSvg(t['form-check-radio-checked-bg-image'])),
  '.form-check-input:disabled': css(_templateObject9$9 || (_templateObject9$9 = _taggedTemplateLiteral(["\n    @include platform(web) {\n      pointer-events: none;\n      filter: none;\n    }\n    opacity: $form-check-label-disabled-opacity;\n  "])))
}, each(FORM_VALIDATION_STATES, (state, data) => ({
  [".form-check-input:".concat(state)]: css(_templateObject10$9 || (_templateObject10$9 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:focus {\n        border-color: ", "; // added for bootstrap-rn\n        @include platform(web) {\n          box-shadow: 0 0 $input-btn-focus-blur $input-focus-width\n            rgba(", ", $input-btn-focus-color-opacity);\n        }\n      }\n    "])), t => data(t).color, t => data(t).color, t => data(t).color),
  [".form-check-input:".concat(state, ":checked")]: css(_templateObject11$6 || (_templateObject11$6 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), t => data(t).color)
}))), {}, {
  '.form-switch.form-check .form-check-input': css(_templateObject12$4 || (_templateObject12$4 = _taggedTemplateLiteral(["\n    // float: left;\n    // margin-left: $form-switch-padding-start * -1;\n    margin-right: $form-switch-padding-start - $form-switch-width; // added for bootstrap-rn\n  "]))),
  '.form-switch.form-check-reverse .form-check-input': css(_templateObject13$4 || (_templateObject13$4 = _taggedTemplateLiteral(["\n    // margin-right: $form-switch-padding-start * -1;\n    margin-right: 0; // added for bootstrap-rn\n    // margin-left: 0;\n    margin-left: $form-switch-padding-start - $form-switch-width; // added for bootstrap-rn\n  "]))),
  '.form-switch .form-check-input': css(_templateObject14$3 || (_templateObject14$3 = _taggedTemplateLiteral(["\n    width: $form-switch-width;\n    background-image: ", ";\n    background-position: left center;\n    border-radius: $form-switch-border-radius;\n    // @include transition($form-switch-transition);\n\n    &:focus {\n      background-image: ", ";\n    }\n  "])), t => escapeSvg(t['form-switch-bg-image']), t => escapeSvg(t['form-switch-focus-bg-image'])),
  '.form-switch .form-check-input:checked': css(_templateObject15$3 || (_templateObject15$3 = _taggedTemplateLiteral(["\n    background-position: $form-switch-checked-bg-position;\n\n    // @if $enable-gradients {\n    //   background-image: escape-svg($form-switch-checked-bg-image), var(--#{$prefix}gradient);\n    // } @else {\n    background-image: ", ";\n    // }\n\n    &:focus {\n      background-image: ", "; // added for bootstrap-rn\n    }\n  "])), t => escapeSvg(t['form-switch-checked-bg-image']), t => escapeSvg(t['form-switch-checked-bg-image']))
}));
const FormCheckInput = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useFormField', props, ref);
  const context = React.useContext(FormCheckContext);
  const {
      type,
      value,
      onFocus = () => {},
      onBlur = () => {},
      disabled = context ? context.disabled : false,
      valid = context ? context.valid : false,
      invalid = context ? context.invalid : false,
      useNativeComponent = false,
      autoFocus = false,
      style
    } = modifierProps,
    elementProps = _objectWithoutProperties(modifierProps, _excluded$19);
  const media = useMedia();
  const [focused, setFocused] = React.useState(autoFocus);
  const classes = getStyles(styles$X, [context && '.form-check .form-check-input', (context === null || context === void 0 ? void 0 : context.reverse) && '.form-check-reverse .form-check-input', '.form-check-input', type === 'checkbox' && '.form-check-input[type="checkbox"]', type === 'radio' && '.form-check-input[type="radio"]', value && '.form-check-input:checked', type === 'checkbox' && value && '.form-check-input[type="checkbox"]:checked', type === 'radio' && value && '.form-check-input[type="radio"]:checked', disabled && '.form-check-input:disabled',
  // validation
  valid && '.form-check-input:valid', valid && value && '.form-check-input:valid:checked', invalid && '.form-check-input:invalid', invalid && value && '.form-check-input:invalid:checked',
  // switch
  context && type === 'switch' && '.form-switch.form-check .form-check-input', (context === null || context === void 0 ? void 0 : context.reverse) && type === 'switch' && '.form-switch.form-check-reverse .form-check-input', type === 'switch' && '.form-switch .form-check-input', type === 'switch' && value && '.form-switch .form-check-input:checked']);
  const resolveStyle = useStyle([classes, style]);
  const BaseFormCheckInput = reactNative.Platform.OS === 'web' && !useNativeComponent ? FormCheckInputWeb : FormCheckInputNative;
  return /*#__PURE__*/React__default["default"].createElement(BaseFormCheckInput, _extends({}, elementProps, {
    ref: modifierRef,
    type: type,
    value: value,
    onFocus: () => {
      setFocused(true);
      onFocus();
    },
    onBlur: () => {
      setFocused(false);
      onBlur();
    },
    disabled: disabled,
    autoFocus: autoFocus,
    style: resolveStyle({
      media,
      interaction: {
        focus: focused,
        focusVisible: focused
      }
    })
  }));
});
FormCheckInput.displayName = 'FormCheckInput';
FormCheckInput.propTypes = propTypes$1c;

const Checkbox = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const elementProps = _extends({}, (_objectDestructuringEmpty(props), props));
  return /*#__PURE__*/React__default["default"].createElement(FormCheckInput, _extends({}, elementProps, {
    ref: ref,
    type: "checkbox"
  }));
});
Checkbox.displayName = 'Checkbox';

const _excluded$18 = ["children", "size", "sizeSm", "sizeMd", "sizeLg", "sizeXl", "style"];
var _templateObject$X, _templateObject2$G, _templateObject3$l, _templateObject4$i, _templateObject5$f;
const sizes = makeArray(GRID_COLUMNS).map(v => v + 1);
const propTypes$1b = {
  children: PropTypes__default["default"].node.isRequired,
  size: PropTypes__default["default"].oneOf(['auto', ...sizes]),
  sizeSm: PropTypes__default["default"].oneOf(['auto', ...sizes]),
  sizeMd: PropTypes__default["default"].oneOf(['auto', ...sizes]),
  sizeLg: PropTypes__default["default"].oneOf(['auto', ...sizes]),
  sizeXl: PropTypes__default["default"].oneOf(['auto', ...sizes]),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$W = StyleSheet.create(_objectSpread2({
  '*': css(_templateObject$X || (_templateObject$X = _taggedTemplateLiteral(["\n    // Add box sizing if only the grid is loaded\n    /* box-sizing: if(\n      variable-exists(include-column-box-sizing) and $include-column-box-sizing,\n      border-box,\n      null\n    ); */\n    // Prevent columns from becoming too narrow when at smaller grid tiers by\n    // always setting \"width: 100%;\". This works because we set the width\n    // later on to override this initial width.\n    flex-shrink: 0;\n    width: 100%;\n    @include platform(web) {\n      max-width: 100%; // Prevent \".col-auto\", \".col\" (& responsive variants) from breaking out the grid\n    }\n    padding-right: $grid-gutter-width * 0.5;\n    padding-left: $grid-gutter-width * 0.5;\n    margin-top: 0;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => _objectSpread2({
  [".col".concat(infix(breakpoint))]: css(_templateObject2$G || (_templateObject2$G = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex: 1 0 0%; // Flexbugs #4: https://github.com/philipwalton/flexbugs#flexbug-4\n      }\n    "])), breakpoint),
  [".col".concat(infix(breakpoint), "-auto")]: css(_templateObject3$l || (_templateObject3$l = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex: 0 0 auto;\n        width: auto;\n      }\n    "])), breakpoint)
}, normalize$1(makeArray(GRID_COLUMNS - 1, i => ({
  [".col".concat(infix(breakpoint), "-").concat(i + 1)]: css(_templateObject4$i || (_templateObject4$i = _taggedTemplateLiteral(["\n          @include media-breakpoint-up(", ") {\n            flex: 0 0 auto;\n            width: ", "%;\n          }\n        "])), breakpoint, (i + 1) / GRID_COLUMNS * 100),
  [".offset".concat(infix(breakpoint), "-").concat(i)]: css(_templateObject5$f || (_templateObject5$f = _taggedTemplateLiteral(["\n          @include media-breakpoint-up(", ") {\n            margin-left: ", "%;\n          }\n        "])), breakpoint, i / GRID_COLUMNS * 100)
})))))));
const Col = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      size,
      sizeSm,
      sizeMd,
      sizeLg,
      sizeXl,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$18);
  const classes = getStyles(styles$W, ['*', ".col-".concat(size.toString()), sizeSm && ".col-sm-".concat(sizeSm.toString()), sizeMd && ".col-md-".concat(sizeMd.toString()), sizeLg && ".col-lg-".concat(sizeLg.toString()), sizeXl && ".col-xl-".concat(sizeXl.toString())]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
Col.displayName = 'Col';
Col.propTypes = propTypes$1b;

const _excluded$17 = ["children", "style"];
var _templateObject$W;
const propTypes$1a = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$V = StyleSheet.create({
  code: css(_templateObject$W || (_templateObject$W = _taggedTemplateLiteral(["\n    font-family: $font-family-code;\n    font-size: $code-font-size;\n    color: $code-color;\n    @include platform(web) {\n      word-wrap: break-word;\n    }\n  "])))
});
const Code = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$17);
  const classes = getStyles(styles$V, ['code']);

  // Accessiblity role code is only supported on web.
  const role = reactNative.Platform.OS === 'web' ? 'code' : null;
  return /*#__PURE__*/React__default["default"].createElement(Text, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style]
  }), children);
});
Code.displayName = 'Code';
Code.propTypes = propTypes$1a;

const DropdownContext = /*#__PURE__*/React__default["default"].createContext();
DropdownContext.displayName = 'DropdownContext';

const _excluded$16 = ["onPress", "caret"];
function useToggleDropdown(props) {
  const context = useForcedContext(DropdownContext);
  const {
      onPress: handlePress,
      caret
    } = props,
    restProps = _objectWithoutProperties(props, _excluded$16);
  return _objectSpread2(_objectSpread2({}, restProps), {}, {
    nativeID: context.identifier,
    ref: context.toggleRef,
    onPress: event => {
      if (handlePress) handlePress(event);
      context.setVisible(value => !value);
    },
    accessibilityHasPopup: true,
    accessibilityExpanded: context.visible,
    caret: caret === undefined ? {
      direction: context.direction
    } : caret
  });
}

const propTypes$19 = {
  children: PropTypes__default["default"].func.isRequired
};
const DropdownToggle = props => {
  const {
    children
  } = props;
  return children(useToggleDropdown({}));
};
DropdownToggle.displayName = 'DropdownToggle';
DropdownToggle.propTypes = propTypes$19;

const propTypes$18 = {
  children: PropTypes__default["default"].func.isRequired,
  placement: PropTypes__default["default"].string.isRequired,
  targetRef: PropTypes__default["default"].oneOfType([PropTypes__default["default"].func, PropTypes__default["default"].object]),
  offset: PropTypes__default["default"].number,
  arrowOffset: PropTypes__default["default"].number,
  visible: PropTypes__default["default"].bool.isRequired
};
const Overlay = props => {
  const {
    children,
    targetRef,
    placement,
    offset,
    arrowOffset = 0,
    visible
  } = props;
  const overlayRef = React.useRef();
  const overlay = overlays.useOverlayPosition({
    placement,
    targetRef,
    overlayRef,
    offset,
    isOpen: visible
  });

  // Remove unnecessary arrow styles and adjust arrow offset.
  if (placement === 'top' || placement === 'bottom') {
    delete overlay.arrowProps.style.top;
    if (typeof overlay.arrowProps.style.left === 'number') {
      overlay.arrowProps.style.left -= arrowOffset;
    }
  }
  if (placement === 'left' || placement === 'right') {
    delete overlay.arrowProps.style.left;
    if (typeof overlay.arrowProps.style.top === 'number') {
      overlay.arrowProps.style.top -= arrowOffset;
    }
  }

  // Adjust top value by status bar height on Android
  if (reactNative.Platform.OS === 'android' && reactNative.StatusBar.currentHeight) {
    if (typeof overlay.overlayProps.style.top === 'number') {
      overlay.overlayProps.style.top -= reactNative.StatusBar.currentHeight;
    }
    if (typeof overlay.arrowProps.style.top === 'number') {
      overlay.arrowProps.style.top -= reactNative.StatusBar.currentHeight;
    }
  }
  return children(overlay, overlayRef);
};
Overlay.displayName = 'Overlay';
Overlay.propTypes = propTypes$18;

var _templateObject$V;
const propTypes$17 = {
  toggleRef: PropTypes__default["default"].oneOfType([PropTypes__default["default"].func, PropTypes__default["default"].object]),
  dialogRef: PropTypes__default["default"].oneOfType([PropTypes__default["default"].func, PropTypes__default["default"].object]),
  onClose: PropTypes__default["default"].func,
  autoClose: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].oneOf(['inside', 'outside'])]),
  backdrop: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].oneOf(['static'])])
};
const styles$U = StyleSheet.create({
  handler: css(_templateObject$V || (_templateObject$V = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0;\n    left: 0;\n    right: 0;\n    position: absolute;\n    flex-grow: 1;\n  "])))
});
const initialState = {
  waitingForMouseUp: false,
  ignoreBackdropClick: false
};
const BackdropHandler = props => {
  const {
    toggleRef,
    dialogRef,
    onClose: handleClose,
    backdrop = true,
    autoClose = 'outside'
  } = props;
  if (reactNative.Platform.OS === 'web') {
    const state = React.useMemo(() => initialState, []);
    React.useEffect(() => {
      const toggle = toggleRef ? reactNative.findNodeHandle(toggleRef.current) : undefined;
      const dialog = reactNative.findNodeHandle(dialogRef.current);
      const handleDialogMouseDown = () => {
        state.waitingForMouseUp = true;
      };

      // Workaround for chrome, because chrome does not fire onMouseDown event
      // for dialog when clicking on the <select> menu.
      const handleDialogMouseUp = () => {
        state.ignoreBackdropClick = true;
      };
      const handleDocumentClick = _ref => {
        let {
          target
        } = _ref;
        const isDialogClick = state.ignoreBackdropClick || dialog.contains(target);
        if (backdrop === 'static' || autoClose === false) {
          return;
        }

        // Click outside -> return if autoClose is inside.
        if (!isDialogClick && autoClose === 'inside') {
          return;
        }

        // Click inside / on dialog -> return if autoClose is outside.
        if (isDialogClick) {
          state.ignoreBackdropClick = false;
          if (autoClose === 'outside') {
            return;
          }
        }

        // Click on toggle -> return always.
        if (toggle && (target === toggle || toggle.contains(target))) {
          return;
        }
        handleClose();
      };
      const handleDocumentMouseUp = () => {
        if (state.waitingForMouseUp) {
          state.ignoreBackdropClick = true;
        }
        state.waitingForMouseUp = false;
      };
      dialog.addEventListener('mousedown', handleDialogMouseDown);
      dialog.addEventListener('mouseup', handleDialogMouseUp);
      // See https://github.com/necolas/react-native-web/issues/2115
      document.addEventListener('click', handleDocumentClick, true);
      document.addEventListener('mouseup', handleDocumentMouseUp, true);
      return () => {
        dialog.addEventListener('mousedown', handleDialogMouseDown);
        dialog.addEventListener('mouseup', handleDialogMouseUp);
        document.removeEventListener('click', handleDocumentClick, true);
        document.removeEventListener('mouseup', handleDocumentMouseUp, true);
      };
    }, [backdrop, autoClose]);
    return null;
  }
  if (backdrop !== true) {
    return null;
  }
  return /*#__PURE__*/React__default["default"].createElement(Pressable, {
    style: styles$U.handler,
    onPress: () => {
      handleClose();
    },
    accessible: false,
    importantForAccessibility: "no"
  });
};
BackdropHandler.displayName = 'BackdropHandler';
BackdropHandler.propTypes = propTypes$17;

const _excluded$15 = ["children", "start", "right", "end", "style", "textStyle"];
var _templateObject$U, _templateObject2$F, _templateObject3$k, _templateObject4$h, _templateObject5$e, _templateObject6$d, _templateObject7$8, _templateObject8$8, _templateObject9$8, _templateObject10$8;
const ALIGNMENT_BREAKPOINTS = [true, 'sm', 'md', 'lg', 'xl', 'xxl'];
const propTypes$16 = {
  children: PropTypes__default["default"].node.isRequired,
  start: PropTypes__default["default"].oneOf(ALIGNMENT_BREAKPOINTS),
  right: PropTypes__default["default"].oneOf(ALIGNMENT_BREAKPOINTS),
  end: PropTypes__default["default"].oneOf(ALIGNMENT_BREAKPOINTS),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$T = StyleSheet.create(_objectSpread2(_objectSpread2(_objectSpread2({
  '.dropdown-menu': css(_templateObject$U || (_templateObject$U = _taggedTemplateLiteral(["\n    position: absolute;\n    z-index: $zindex-dropdown;\n    // display: none; // none by default, but block on \"open\" of the menu\n    min-width: $dropdown-min-width;\n    padding: $dropdown-padding-y $dropdown-padding-x;\n    margin: 0; // Override default margin of ul\n    // list-style: none;\n    background-color: $dropdown-bg;\n    // background-clip: padding-box;\n    border: $dropdown-border-width solid $dropdown-border-color;\n    border-radius: $dropdown-border-radius;\n    // @include box-shadow($dropdown-box-shadow);\n  "]))),
  '.dropdown-menu[data-bs-popper]': css(_templateObject2$F || (_templateObject2$F = _taggedTemplateLiteral(["\n    top: 100%;\n    left: 0;\n    margin-top: $dropdown-spacer;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".dropdown-menu".concat(infix(breakpoint), "-start[data-bs-popper]")]: css(_templateObject3$k || (_templateObject3$k = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        right: auto;\n        left: 0;\n      }\n    "])), breakpoint),
  [".dropdown-menu".concat(infix(breakpoint), "-end[data-bs-popper]")]: css(_templateObject4$h || (_templateObject4$h = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        right: 0;\n        left: auto;\n      }\n    "])), breakpoint)
}))), {}, {
  '.dropup .dropdown-menu[data-bs-popper]': css(_templateObject5$e || (_templateObject5$e = _taggedTemplateLiteral(["\n    top: auto;\n    bottom: 100%;\n    margin-top: 0;\n    margin-bottom: $dropdown-spacer;\n  "]))),
  '.dropend .dropdown-menu[data-bs-popper]': css(_templateObject6$d || (_templateObject6$d = _taggedTemplateLiteral(["\n    top: 0;\n    right: auto;\n    left: 100%;\n    margin-top: 0;\n    margin-left: $dropdown-spacer;\n  "]))),
  '.dropstart .dropdown-menu[data-bs-popper]': css(_templateObject7$8 || (_templateObject7$8 = _taggedTemplateLiteral(["\n    top: 0;\n    right: 100%;\n    left: auto;\n    margin-top: 0;\n    margin-right: $dropdown-spacer;\n  "]))),
  '.navbar-nav .dropdown-menu': css(_templateObject8$8 || (_templateObject8$8 = _taggedTemplateLiteral(["\n    position: relative; // static;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav .dropdown-menu")]: css(_templateObject9$8 || (_templateObject9$8 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        position: absolute;\n      }\n    "])), next(breakpoint))
}))), {}, {
  '.dropdown-menu --text': css(_templateObject10$8 || (_templateObject10$8 = _taggedTemplateLiteral(["\n    font-size: $dropdown-font-size;\n    color: $dropdown-color;\n    text-align: left; // Ensures proper alignment if parent has it changed (e.g., modal footer)\n  "])))
}));
const getAlignment = (media, center, start, end) => {
  if (center) {
    return 'center';
  }
  const alignStart = typeof start === 'boolean' ? start : media.up(start);
  const alignEnd = typeof end === 'boolean' ? end : media.up(end);
  if (!alignEnd) {
    return 'start';
  }
  if (!alignStart) {
    return 'end';
  }
  const startIndex = ALIGNMENT_BREAKPOINTS.indexOf(start);
  const endIndex = ALIGNMENT_BREAKPOINTS.indexOf(end);
  return startIndex > endIndex ? 'start' : 'end';
};
const transformPlacement = (media, direction, center, start, end) => {
  if (direction === 'up') {
    return "top ".concat(getAlignment(media, center, start, end));
  }
  if (direction === 'down') {
    return "bottom ".concat(getAlignment(media, center, start, end));
  }
  return "".concat(direction, " top");
};
const DropdownMenu = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      start = true,
      right,
      end = false,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$15);
  if (right !== undefined) {
    // eslint-disable-next-line no-console
    console.warn('Prop "right" is deprecated, please use "end" instead.');
  }
  const navbar = React.useContext(NavbarContext);
  const media = useMedia();
  const dialogRef = React.useRef();
  const dropdown = useForcedContext(DropdownContext);
  const {
    identifier,
    toggleRef,
    visible,
    setVisible,
    direction,
    center,
    display,
    autoClose
  } = dropdown;
  if (!visible) {
    return null;
  }
  const isStatic = reactNative.Platform.OS === 'web' && display === 'static';
  const isCollapsedNavbar = navbar && !(navbar.expand && (navbar.expand === true || media.up(navbar.expand)));
  const hasStaticStyle = isStatic && !isCollapsedNavbar;
  const classes = getStyles(styles$T, ['.dropdown-menu',
  // Non-Popper styles
  hasStaticStyle && '.dropdown-menu[data-bs-popper]', hasStaticStyle && start && ".dropdown-menu".concat(start === true ? '' : "-".concat(start), "-start[data-bs-popper]"), hasStaticStyle && end && ".dropdown-menu".concat(end === true ? '' : "-".concat(end), "-end[data-bs-popper]"), hasStaticStyle && direction === 'up' && '.dropup .dropdown-menu[data-bs-popper]', hasStaticStyle && direction === 'end' && '.dropend .dropdown-menu[data-bs-popper]', hasStaticStyle && direction === 'start' && '.dropstart .dropdown-menu[data-bs-popper]',
  // Navbar styles
  navbar && '.navbar-nav .dropdown-menu', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav .dropdown-menu")]);
  const textClasses = getStyles(styles$T, ['.dropdown-menu --text']);
  if (isStatic || isCollapsedNavbar) {
    return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, !isCollapsedNavbar && /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
      toggleRef: toggleRef,
      dialogRef: dialogRef,
      onClose: () => {
        setVisible(false);
      },
      autoClose: autoClose
    }), /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
      ref: concatRefs(dialogRef, ref),
      accessibilityLabelledBy: identifier,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children));
  }
  return /*#__PURE__*/React__default["default"].createElement(overlays.OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
    placement: transformPlacement(media, direction, center, start, end),
    targetRef: toggleRef,
    offset: normalizeNumber(StyleSheet.value('dropdown-spacer')),
    visible: visible
  }, (overlay, overlayRef) => /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
    toggleRef: toggleRef,
    dialogRef: overlayRef,
    onClose: () => {
      setVisible(false);
    },
    autoClose: autoClose
  }), /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: concatRefs(overlayRef, ref),
    accessibilityLabelledBy: identifier,
    style: [classes, overlay.overlayProps.style, {
      maxHeight: 'auto',
      opacity: overlay.rendered ? 1 : 0
    }, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/React__default["default"].createElement(DropdownContext.Provider, {
    value: dropdown
  }, children)))));
});
DropdownMenu.displayName = 'DropdownMenu';
DropdownMenu.propTypes = propTypes$16;

const _excluded$14 = ["children", "size", "style"];
var _templateObject$T, _templateObject2$E;
const propTypes$15 = {
  children: PropTypes__default["default"].node.isRequired,
  size: PropTypes__default["default"].oneOf(Object.keys(FONT_SIZES).map(k => Number(k))).isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$S = StyleSheet.create(_objectSpread2({
  heading: css(_templateObject$T || (_templateObject$T = _taggedTemplateLiteral(["\n    margin-top: 0; // 1\n    margin-bottom: $headings-margin-bottom;\n    font-family: $headings-font-family;\n    font-style: $headings-font-style;\n    font-weight: $headings-font-weight;\n    color: $headings-color;\n  "])))
}, each(FONT_SIZES, (size, value) => ({
  [".h".concat(size)]: css(_templateObject2$E || (_templateObject2$E = _taggedTemplateLiteral(["\n      font-size: ", ";\n      line-height: ", " * $headings-line-height;\n    "])), value, value)
}))));
const Heading$1 = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      size,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$14);
  const classes = getStyles(styles$S, ['heading', ".h".concat(size)]);
  return /*#__PURE__*/React__default["default"].createElement(Text, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: "header",
    accessibilityLevel: size,
    style: [classes, style]
  }), children);
});
Heading$1.displayName = 'Heading';
Heading$1.propTypes = propTypes$15;

const _excluded$13 = ["children", "style", "textStyle"];
var _templateObject$S, _templateObject2$D;
const propTypes$14 = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$R = StyleSheet.create({
  '.dropdown-header': css(_templateObject$S || (_templateObject$S = _taggedTemplateLiteral(["\n    // display: block;\n    padding: $dropdown-header-padding;\n  "]))),
  '.dropdown-header --text': css(_templateObject2$D || (_templateObject2$D = _taggedTemplateLiteral(["\n    margin-bottom: 0; // for use with heading elements\n    font-size: $font-size-sm;\n    color: $dropdown-header-color;\n    // white-space: nowrap; // as with > li > a\n  "])))
});
const DropdownHeader = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$13);
  const classes = getStyles(styles$R, ['.dropdown-header']);
  const textClasses = getStyles(styles$R, ['.dropdown-header --text']);

  // composite component
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(Heading$1, {
    size: 6,
    style: [textClasses, textStyle]
  }, children));
});
DropdownHeader.displayName = 'DropdownHeader';
DropdownHeader.propTypes = propTypes$14;

const _excluded$12 = ["children", "onPress", "active", "disabled", "style", "textStyle"];
var _templateObject$R, _templateObject2$C, _templateObject3$j, _templateObject4$g, _templateObject5$d, _templateObject6$c;
const propTypes$13 = {
  children: PropTypes__default["default"].node.isRequired,
  onPress: PropTypes__default["default"].func,
  active: PropTypes__default["default"].bool,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$Q = StyleSheet.create({
  '.dropdown-item': css(_templateObject$R || (_templateObject$R = _taggedTemplateLiteral(["\n    width: 100%;\n    padding: $dropdown-item-padding-y $dropdown-item-padding-x;\n    // clear: both;\n    background-color: transparent;\n    border: 0;\n\n    &:hover {\n      // @include gradient-bg($dropdown-link-hover-bg);\n      background-color: $dropdown-link-hover-bg;\n    }\n    &:focus {\n      // @include gradient-bg($dropdown-link-hover-bg);\n      background-color: $dropdown-link-hover-bg;\n    }\n  "]))),
  '.dropdown-item --text': css(_templateObject2$C || (_templateObject2$C = _taggedTemplateLiteral(["\n    font-weight: $font-weight-normal;\n    color: $dropdown-link-color;\n    // text-align: inherit;\n    text-decoration: none; // if($link-decoration == none, null, none);\n    // white-space: nowrap;\n\n    &:hover {\n      color: $dropdown-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      color: $dropdown-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
  '.dropdown-item.active': css(_templateObject3$j || (_templateObject3$j = _taggedTemplateLiteral(["\n    // @include gradient-bg($dropdown-link-active-bg);\n    background-color: $dropdown-link-active-bg;\n\n    &:hover {\n      background-color: $dropdown-link-active-bg;\n    }\n    &:focus {\n      background-color: $dropdown-link-active-bg;\n    }\n  "]))),
  '.dropdown-item.active --text': css(_templateObject4$g || (_templateObject4$g = _taggedTemplateLiteral(["\n    color: $dropdown-link-active-color;\n    text-decoration: none;\n\n    &:hover {\n      color: $dropdown-link-active-color;\n    }\n    &:focus {\n      color: $dropdown-link-active-color;\n    }\n  "]))),
  '.dropdown-item.disabled': css(_templateObject5$d || (_templateObject5$d = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    background-color: transparent;\n    // Remove CSS gradients if they're enabled\n    // background-image: if($enable-gradients, none, null);\n\n    &:hover {\n      background-color: transparent;\n    }\n    &:focus {\n      background-color: transparent;\n    }\n  "]))),
  '.dropdown-item.disabled --text': css(_templateObject6$c || (_templateObject6$c = _taggedTemplateLiteral(["\n    color: $dropdown-link-disabled-color;\n\n    &:hover {\n      color: $dropdown-link-disabled-color;\n    }\n    &:focus {\n      color: $dropdown-link-disabled-color;\n    }\n  "])))
});
const DropdownItem = props => {
  const {
      children,
      onPress: handlePress,
      active = false,
      disabled = false,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$12);
  const dropdown = useForcedContext(DropdownContext);
  const classes = getStyles(styles$Q, ['.dropdown-item', active && '.dropdown-item.active', disabled && '.dropdown-item.disabled']);
  const textClasses = getStyles(styles$Q, ['.dropdown-item --text', active && '.dropdown-item.active --text', disabled && '.dropdown-item.disabled --text']);
  return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends({}, elementProps, {
    onPress: event => {
      if (handlePress) handlePress(event);
      if (event.defaultPrevented) {
        return;
      }
      dropdown.setVisible(false);
    },
    disabled: disabled,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
};
DropdownItem.displayName = 'DropdownItem';
DropdownItem.propTypes = propTypes$13;

const _excluded$11 = ["children", "style", "textStyle"];
var _templateObject$Q, _templateObject2$B;
const propTypes$12 = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$P = StyleSheet.create({
  '.dropdown-item-text': css(_templateObject$Q || (_templateObject$Q = _taggedTemplateLiteral(["\n    // display: block;\n    padding: $dropdown-item-padding-y $dropdown-item-padding-x;\n  "]))),
  '.dropdown-item-text --text': css(_templateObject2$B || (_templateObject2$B = _taggedTemplateLiteral(["\n    color: $dropdown-link-color;\n  "])))
});
const DropdownItemText = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$11);
  const classes = getStyles(styles$P, ['.dropdown-item-text']);
  const textClasses = getStyles(styles$P, ['.dropdown-item-text --text']);

  // composite component
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(Text, {
    style: [textClasses, textStyle]
  }, children));
});
DropdownItemText.displayName = 'DropdownItemText';
DropdownItemText.propTypes = propTypes$12;

const _excluded$10 = ["style"];
var _templateObject$P;
const propTypes$11 = {
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$O = StyleSheet.create({
  '.dropdown-divider': css(_templateObject$P || (_templateObject$P = _taggedTemplateLiteral(["\n    height: 0;\n    margin: $dropdown-divider-margin-y 0;\n    overflow: hidden;\n    border-top-width: 1px;\n    border-style: solid;\n    border-color: $dropdown-divider-bg;\n  "])))
});
const DropdownDivider = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$10);
  const classes = getStyles(styles$O, ['.dropdown-divider']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }));
});
DropdownDivider.displayName = 'DropdownDivider';
DropdownDivider.propTypes = propTypes$11;

function useDropdown(defaultVisible, controlledVisible, onToggle, direction, center, display, autoClose) {
  const identifier = useIdentifier('dropdown');
  const toggleRef = React.useRef();
  const [visible, setVisible] = useControlledState(defaultVisible, controlledVisible, onToggle);
  return React.useMemo(() => ({
    identifier,
    visible,
    setVisible,
    toggleRef,
    direction,
    center,
    display,
    autoClose
  }), [visible, direction, center, display, autoClose]);
}

const _excluded$$ = ["onPress"];
function useDismissDropdown(props) {
  const context = useForcedContext(DropdownContext);
  const {
      onPress: handlePress
    } = props,
    restProps = _objectWithoutProperties(props, _excluded$$);
  return _objectSpread2(_objectSpread2({}, restProps), {}, {
    onPress: event => {
      if (handlePress) handlePress(event);
      context.setVisible(false);
    }
  });
}

const _excluded$_ = ["children", "defaultVisible", "visible", "onToggle", "direction", "center", "display", "autoClose", "style"];
var _templateObject$O;
const DIRECTIONS = ['up', 'down', 'start', 'end'];
const propTypes$10 = {
  children: PropTypes__default["default"].node,
  defaultVisible: PropTypes__default["default"].bool,
  visible: PropTypes__default["default"].bool,
  onToggle: PropTypes__default["default"].func,
  direction: PropTypes__default["default"].oneOf(DIRECTIONS),
  center: PropTypes__default["default"].bool,
  display: PropTypes__default["default"].oneOf(['dynamic', 'static']),
  autoClose: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].oneOf(['inside', 'outside'])]),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$N = StyleSheet.create({
  '.dropdown': css(_templateObject$O || (_templateObject$O = _taggedTemplateLiteral(["\n    position: relative;\n  "])))
});
const Dropdown = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      defaultVisible = false,
      visible,
      onToggle,
      direction = 'down',
      center = false,
      display = 'dynamic',
      autoClose = 'outside',
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$_);
  const dropdown = useDropdown(defaultVisible, visible, onToggle, direction, center, display, autoClose);
  const classes = getStyles(styles$N, ['.dropdown']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(DropdownContext.Provider, {
    value: dropdown
  }, children));
});
Dropdown.displayName = 'Dropdown';
Dropdown.propTypes = propTypes$10;
Dropdown.Context = DropdownContext;
Dropdown.Toggle = DropdownToggle;
Dropdown.Menu = DropdownMenu;
Dropdown.Header = DropdownHeader;
Dropdown.Item = DropdownItem;
Dropdown.ItemText = DropdownItemText;
Dropdown.Divider = DropdownDivider;
Dropdown.useDismiss = useDismissDropdown;
Dropdown.useToggle = useToggleDropdown;

const _excluded$Z = ["children", "size", "style"];
var _templateObject$N;
const propTypes$$ = {
  children: PropTypes__default["default"].node.isRequired,
  size: PropTypes__default["default"].oneOf(Object.keys(DISPLAY_FONT_SIZES).map(k => Number(k))).isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$M = StyleSheet.create(_objectSpread2({}, each(DISPLAY_FONT_SIZES, (size, value) => ({
  [".display-".concat(size)]: css(_templateObject$N || (_templateObject$N = _taggedTemplateLiteral(["\n      font-size: ", ";\n      line-height: ", " * $headings-line-height;\n    "])), value, value)
}))));
const DisplayHeading = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      size,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$Z);
  const classes = getStyles(styles$M, [".display-".concat(size)]);
  return /*#__PURE__*/React__default["default"].createElement(Heading$1, _extends({}, elementProps, {
    ref: ref,
    size: 1,
    style: [classes, style]
  }), children);
});
DisplayHeading.displayName = 'Heading';
DisplayHeading.propTypes = propTypes$$;

const _excluded$Y = ["children", "type", "style"];
var _templateObject$M;
const propTypes$_ = {
  children: PropTypes__default["default"].node.isRequired,
  type: PropTypes__default["default"].oneOf(Object.keys(FORM_VALIDATION_STATES)),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$L = StyleSheet.create(_objectSpread2({}, each(FORM_VALIDATION_STATES, (state, data) => ({
  [".".concat(state, "-feedback")]: css(_templateObject$M || (_templateObject$M = _taggedTemplateLiteral(["\n      // display: none;\n      width: 100%;\n      margin-top: $form-feedback-margin-top;\n      font-size: $form-feedback-font-size;\n      font-style: $form-feedback-font-style;\n      color: ", ";\n    "])), t => data(t).color)
}))));
const Feedback = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      type,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$Y);
  const classes = getStyles(styles$L, [".".concat(type, "-feedback")]);
  return /*#__PURE__*/React__default["default"].createElement(Text, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
Feedback.displayName = 'Feedback';
Feedback.propTypes = propTypes$_;

const _excluded$X = ["children", "htmlFor"];
const propTypes$Z = {
  children: PropTypes__default["default"].node.isRequired,
  htmlFor: PropTypes__default["default"].string
};
const Label = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      htmlFor
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$X);

  // Ref: https://github.com/necolas/react-native-web/issues/1651
  const forRef = React__default["default"].useCallback(node => {
    if (reactNative.Platform.OS !== 'web' || !htmlFor || !node) {
      return;
    }
    node.setAttribute('for', htmlFor);
  }, []);
  const role = reactNative.Platform.OS === 'web' ? 'label' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: concatRefs(forRef, ref),
    accessibilityRole: role
  }), children);
});
Label.displayName = 'Label';
Label.propTypes = propTypes$Z;

const _excluded$W = ["children", "style", "textStyle"];
var _templateObject$L, _templateObject2$A, _templateObject3$i, _templateObject4$f;
const propTypes$Y = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$K = StyleSheet.create(_objectSpread2({
  '.form-check-input:disabled ~ .form-check-label': css(_templateObject$L || (_templateObject$L = _taggedTemplateLiteral(["\n    @include platform(web) {\n      cursor: default;\n    }\n    opacity: $form-check-label-disabled-opacity;\n  "]))),
  '.form-check-label': css(_templateObject2$A || (_templateObject2$A = _taggedTemplateLiteral(["\n    flex-shrink: 1; // added for bootstrap-rn\n\n    @include platform(web) {\n      cursor: $form-check-label-cursor;\n    }\n  "]))),
  '.form-check-label --text': css(_templateObject3$i || (_templateObject3$i = _taggedTemplateLiteral(["\n    color: $form-check-label-color;\n  "])))
}, each(FORM_VALIDATION_STATES, (state, data) => ({
  [".form-check-input:".concat(state, " ~ .form-check-label --text")]: css(_templateObject4$f || (_templateObject4$f = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), t => data(t).color)
}))));
const FormCheckLabel = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$W);
  const {
    disabled,
    valid,
    invalid
  } = useForcedContext(FormCheckContext);
  const classes = getStyles(styles$K, [disabled && '.form-check-input:disabled ~ .form-check-label', '.form-check-label']);
  const textClasses = getStyles(styles$K, ['.form-check-label --text',
  // validation
  valid && '.form-check-input:valid ~ .form-check-label --text', invalid && '.form-check-input:invalid ~ .form-check-label --text']);
  return /*#__PURE__*/React__default["default"].createElement(Label, _extends({}, elementProps, {
    ref: ref,
    disabled: disabled,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
FormCheckLabel.displayName = 'FormCheckLabel';
FormCheckLabel.propTypes = propTypes$Y;

const _excluded$V = ["children", "reverse", "disabled", "valid", "invalid", "style"];
var _templateObject$K, _templateObject2$z, _templateObject3$h;
const propTypes$X = {
  children: PropTypes__default["default"].node.isRequired,
  reverse: PropTypes__default["default"].bool,
  disabled: PropTypes__default["default"].bool,
  valid: PropTypes__default["default"].bool,
  invalid: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$J = StyleSheet.create({
  '.form-check': css(_templateObject$K || (_templateObject$K = _taggedTemplateLiteral(["\n    // display: block;\n    flex-direction: row; // added for bootstrap-rn\n    min-height: $form-check-min-height;\n    // padding-left: $form-check-padding-start;\n    margin-bottom: $form-check-margin-bottom;\n  "]))),
  '.form-check-reverse': css(_templateObject2$z || (_templateObject2$z = _taggedTemplateLiteral(["\n    flex-direction: row-reverse; // added for bootstrap-rn\n    // padding-right: $form-check-padding-start;\n    // padding-left: 0;\n    // text-align: right;\n  "]))),
  '.form-switch.form-check': css(_templateObject3$h || (_templateObject3$h = _taggedTemplateLiteral(["\n    // padding-left: $form-switch-padding-start;\n  "])))
});
const FormCheck = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      reverse = false,
      disabled = false,
      valid = false,
      invalid = false,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$V);
  const classes = getStyles(styles$J, ['.form-check', reverse && '.form-check-reverse']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(FormCheckContext.Provider, {
    value: {
      reverse,
      disabled,
      valid,
      invalid
    }
  }, children));
});
FormCheck.displayName = 'FormCheck';
FormCheck.propTypes = propTypes$X;
FormCheck.Label = FormCheckLabel;

const _excluded$U = ["children", "style", "textStyle"];
var _templateObject$J, _templateObject2$y;
const propTypes$W = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$I = StyleSheet.create({
  '.form-label': css(_templateObject$J || (_templateObject$J = _taggedTemplateLiteral(["\n    margin-bottom: $form-label-margin-bottom;\n  "]))),
  '.form-label --text': css(_templateObject2$y || (_templateObject2$y = _taggedTemplateLiteral(["\n    font-size: $form-label-font-size;\n    line-height: $form-label-font-size * $line-height-base; // added for bootstrap-rn\n    font-style: $form-label-font-style;\n    font-weight: $form-label-font-weight;\n    color: $form-label-color;\n  "])))
});
const FormLabel = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$U);
  const classes = getStyles(styles$I, ['.form-label']);
  const textClasses = getStyles(styles$I, ['.form-label --text']);
  return /*#__PURE__*/React__default["default"].createElement(Label, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
FormLabel.displayName = 'FormLabel';
FormLabel.propTypes = propTypes$W;

const _excluded$T = ["children", "style", "textStyle"];
var _templateObject$I, _templateObject2$x;
const propTypes$V = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$H = StyleSheet.create({
  '.form-text': css(_templateObject$I || (_templateObject$I = _taggedTemplateLiteral(["\n    margin-top: $form-text-margin-top;\n  "]))),
  '.form-text --text': css(_templateObject2$x || (_templateObject2$x = _taggedTemplateLiteral(["\n    font-size: $form-text-font-size;\n    font-style: $form-text-font-style;\n    font-weight: $form-text-font-weight;\n    color: $form-text-color;\n  "])))
});
const FormText = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$T);
  const classes = getStyles(styles$H, ['.form-text']);
  const textClasses = getStyles(styles$H, ['.form-text --text']);

  // composite component
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(Text, {
    style: [textClasses, textStyle]
  }, children));
});
FormText.displayName = 'FormText';
FormText.propTypes = propTypes$V;

const _excluded$S = ["onFocus", "onBlur", "autoFocus", "style", "styleName"];
const propTypes$U = {
  onFocus: PropTypes__default["default"].func,
  onBlur: PropTypes__default["default"].func,
  autoFocus: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
const TextInput = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      onFocus = () => {},
      onBlur = () => {},
      autoFocus = false,
      style,
      styleName
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$S);
  const [focused, setFocused] = React.useState(autoFocus);
  const media = useMedia();
  const resolveStyle = useStyle(style, styleName);
  return /*#__PURE__*/React__default["default"].createElement(reactNative.TextInput, _extends({}, elementProps, {
    ref: ref,
    onFocus: event => {
      setFocused(true);
      onFocus(event);
    },
    onBlur: event => {
      setFocused(false);
      onBlur(event);
    },
    autoFocus: autoFocus,
    style: resolveStyle({
      media,
      interaction: {
        focus: focused,
        focusVisible: focused
      }
    })
  }));
});
TextInput.displayName = 'TextInput';
TextInput.propTypes = propTypes$U;

const _excluded$R = ["size", "placeholderTextColor", "multiline", "disabled", "valid", "invalid", "editable", "selectTextOnFocus", "style"];
var _templateObject$H, _templateObject2$w, _templateObject3$g, _templateObject4$e, _templateObject5$c, _templateObject6$b, _templateObject7$7, _templateObject8$7, _templateObject9$7, _templateObject10$7, _templateObject11$5;
const propTypes$T = {
  size: PropTypes__default["default"].oneOf(['sm', 'lg']),
  placeholderTextColor: PropTypes__default["default"].string,
  multiline: PropTypes__default["default"].bool,
  disabled: PropTypes__default["default"].bool,
  valid: PropTypes__default["default"].bool,
  invalid: PropTypes__default["default"].bool,
  editable: PropTypes__default["default"].bool,
  selectTextOnFocus: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};

// Known issues:
//
// line-height (iOS)
// If a line height is defined on iOS the text will be displayed on the bottom
// of the line. As a workaround the line height is only defined for multi line
// inputs.
//
// multi line height (iOS)
// A multi line input on iOS has only the height of a single line input. As a
// workaround we added a height of $input-height-sm + 8rem for multi line
// inputs on iOS.
//
// single line height (Android)
// If no height is defined, Android sets a text line height of 28px auto-
// matically, which leads to a larger height than min height for the default
// and sm size. As a workaround we set a height for single line inputs.
const styles$G = StyleSheet.create(_objectSpread2({
  '.form-control': css(_templateObject$H || (_templateObject$H = _taggedTemplateLiteral(["\n    // display: block;\n    width: 100%;\n    min-height: $input-height; // added for bootstrap-rn\n    padding: $input-padding-y $input-padding-x;\n    font-family: $input-font-family;\n    font-size: $input-font-size;\n    font-weight: $input-font-weight;\n    @include platform(web) {\n      line-height: $input-font-size * $input-line-height;\n    }\n    color: $input-color;\n    background-color: $input-bg;\n    // background-clip: padding-box;\n    border: $input-border-width solid $input-border-color;\n    @include platform(web) {\n      appearance: none; // Fix appearance for date inputs in Safari\n    }\n\n    // Note: This has no effect on <select>s in some browsers, due to the limited stylability of \"<select>\"s in CSS.\n    border-radius: $input-border-radius;\n\n    // @include box-shadow($input-box-shadow);\n    // @include transition($input-transition);\n\n    // Customize the \":focus\" state to imitate native WebKit styles.\n    &:focus {\n      color: $input-focus-color;\n      background-color: $input-focus-bg;\n      border-color: $input-focus-border-color;\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n        // @if $enable-shadows {\n        //   @include box-shadow($input-box-shadow, $input-focus-box-shadow);\n        // } @else {\n        //   // Avoid using mixin so we can pass custom focus shadow properly\n        box-shadow: $input-focus-box-shadow;\n        // }\n      }\n    }\n  "]))),
  '.form-control.disabled': css(_templateObject2$w || (_templateObject2$w = _taggedTemplateLiteral(["\n    background-color: $input-disabled-bg;\n    border-color: $input-disabled-border-color;\n    // iOS fix for unreadable disabled content; see https://github.com/twbs/bootstrap/issues/11655.\n    opacity: 1;\n  "]))),
  '.form-control-sm': css(_templateObject3$g || (_templateObject3$g = _taggedTemplateLiteral(["\n    min-height: $input-height-sm;\n    padding: $input-padding-y-sm $input-padding-x-sm;\n    font-size: $input-font-size-sm;\n    @include platform(web) {\n      line-height: $input-font-size-sm * $line-height-base; // added for bootstrap-rn\n    }\n    border-radius: $input-border-radius-sm;\n  "]))),
  '.form-control-lg': css(_templateObject4$e || (_templateObject4$e = _taggedTemplateLiteral(["\n    min-height: $input-height-lg;\n    padding: $input-padding-y-lg $input-padding-x-lg;\n    font-size: $input-font-size-lg;\n    @include platform(web) {\n      line-height: $input-font-size-lg * $line-height-base; // added for bootstrap-rn\n    }\n    border-radius: $input-border-radius-lg;\n  "]))),
  '.form-control:not(textarea)': css(_templateObject5$c || (_templateObject5$c = _taggedTemplateLiteral(["\n    @include platform(android) {\n      height: $input-height; // added for bootstrap-rn\n    }\n  "]))),
  '.form-control-sm:not(textarea)': css(_templateObject6$b || (_templateObject6$b = _taggedTemplateLiteral(["\n    @include platform(android) {\n      height: $input-height-sm; // added for bootstrap-rn\n    }\n  "]))),
  '.form-control-lg:not(textarea)': css(_templateObject7$7 || (_templateObject7$7 = _taggedTemplateLiteral(["\n    @include platform(android) {\n      height: $input-height-lg; // added for bootstrap-rn\n    }\n  "]))),
  'textarea.form-control': css(_templateObject8$7 || (_templateObject8$7 = _taggedTemplateLiteral(["\n    text-align-vertical: top; // added for bootstrap-rn\n    min-height: $input-height;\n\n    @include platform(ios) {\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n    @include platform(native) {\n      line-height: $input-font-size * $input-line-height; // added for bootstrap-rn\n    }\n  "]))),
  'textarea.form-control-sm': css(_templateObject9$7 || (_templateObject9$7 = _taggedTemplateLiteral(["\n    min-height: $input-height-sm;\n\n    @include platform(ios) {\n      // TODO: Adjust ios height to sm size\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n    @include platform(native) {\n      line-height: $input-font-size-sm * $line-height-base; // added for bootstrap-rn\n    }\n  "]))),
  'textarea.form-control-lg': css(_templateObject10$7 || (_templateObject10$7 = _taggedTemplateLiteral(["\n    min-height: $input-height-lg;\n\n    @include platform(ios) {\n      // TODO: Adjust ios height to lg size\n      min-height: $input-height-sm + 8rem; // added for bootstrap-rn\n    }\n    @include platform(native) {\n      line-height: $input-font-size-sm * $line-height-base; // added for bootstrap-rn\n    }\n  "])))
}, each(FORM_VALIDATION_STATES, (state, data) => ({
  [".form-control:".concat(state)]: css(_templateObject11$5 || (_templateObject11$5 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:focus {\n        border-color: ", ";\n        @include platform(web) {\n          box-shadow: 0 0 $input-btn-focus-blur $input-focus-width\n            rgba(", ", $input-btn-focus-color-opacity);\n        }\n      }\n    "])), t => data(t).color, t => data(t).color, t => data(t).color)
}))));
const Input = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useFormField', props, ref);
  const {
      size,
      placeholderTextColor = StyleSheet.value('input-placeholder-color'),
      multiline = false,
      disabled = false,
      valid = false,
      invalid = false,
      editable = true,
      selectTextOnFocus = false,
      style
    } = modifierProps,
    elementProps = _objectWithoutProperties(modifierProps, _excluded$R);
  const classes = getStyles(styles$G, ['.form-control', disabled && '.form-control.disabled', size === 'sm' && '.form-control-sm', size === 'lg' && '.form-control-lg', !multiline && '.form-control:not(textarea)', !multiline && size === 'sm' && '.form-control-sm:not(textarea)', !multiline && size === 'lg' && '.form-control-lg:not(textarea)', multiline && 'textarea.form-control', multiline && size === 'sm' && 'textarea.form-control-sm', multiline && size === 'lg' && 'textarea.form-control-lg', valid && '.form-control:valid', invalid && '.form-control:invalid']);
  return /*#__PURE__*/React__default["default"].createElement(TextInput, _extends({}, elementProps, {
    ref: modifierRef,
    placeholderTextColor: placeholderTextColor,
    multiline: multiline,
    disabled: disabled,
    editable: disabled ? false : editable,
    selectTextOnFocus: disabled ? false : selectTextOnFocus,
    style: [classes, style]
  }));
});
Input.displayName = 'Input';
Input.propTypes = propTypes$T;

const PLACEMENTS$1 = ['top', 'bottom', 'left', 'right'];
const TRIGGERS = ['press', 'hover', 'focus', 'manual', 'press hover', 'hover press', 'hover focus', 'focus hover', 'press focus', 'focus press'];
const TriggerPropTypes = {
  trigger: PropTypes__default["default"].oneOf(TRIGGERS),
  placement: PropTypes__default["default"].oneOf(PLACEMENTS$1),
  offset: PropTypes__default["default"].number,
  defaultVisible: PropTypes__default["default"].bool,
  visible: PropTypes__default["default"].bool,
  onToggle: PropTypes__default["default"].func
};
function useTrigger(rawTrigger, props, elementProps, ref) {
  const {
    defaultVisible = false,
    visible: controlledVisible,
    onToggle
  } = props;
  const {
    onPress,
    onFocus,
    onBlur,
    onMouseOver,
    onMouseLeave
  } = elementProps;
  const trigger = rawTrigger.split(' ');
  const identifier = useIdentifier('overlay');
  const [visible, setVisible] = useControlledState(defaultVisible, controlledVisible, onToggle);
  const [focused, setFocused] = React.useState(false);
  const [hovered, setHovered] = React.useState(false);
  const targetRef = React.useRef();
  return {
    visible,
    setVisible,
    targetProps: _objectSpread2(_objectSpread2({
      ref: concatRefs(targetRef, ref)
    }, optional(visible, {
      accessibilityDescribedBy: identifier
    })), {}, {
      onPress: event => {
        const handleHoverAsPress = (reactNative.Platform.OS === 'android' || reactNative.Platform.OS === 'ios') && trigger.includes('hover');
        if (trigger.includes('press') || handleHoverAsPress) {
          setVisible(value => !value);
        }
        if (onPress) {
          onPress(event);
        }
      },
      onFocus: event => {
        if (trigger.includes('focus')) {
          setFocused(true);
          if (!visible) {
            setVisible(true);
          }
        }
        if (onFocus) {
          onFocus(event);
        }
      },
      onBlur: event => {
        if (trigger.includes('focus')) {
          setFocused(false);
          const activeHoverTrigger = trigger.includes('hover') && hovered;
          if (visible && !activeHoverTrigger) {
            setVisible(false);
          }
        }
        if (onBlur) {
          onBlur(event);
        }
      },
      onMouseOver: event => {
        if (trigger.includes('hover')) {
          setHovered(true);
          if (!visible && !focused) {
            setVisible(true);
          }
        }
        if (onMouseOver) {
          onMouseOver(event);
        }
      },
      onMouseLeave: event => {
        if (trigger.includes('hover')) {
          setHovered(false);
          const activeFocusTrigger = trigger.includes('focus') && focused;
          if (visible && !activeFocusTrigger) {
            setVisible(false);
          }
        }
        if (onMouseLeave) {
          onMouseLeave(event);
        }
      }
    }),
    targetRef,
    templateProps: {
      nativeID: identifier
    }
  };
}

const PopoverContext = /*#__PURE__*/React__default["default"].createContext();
PopoverContext.displayName = 'PopoverContext';

const _excluded$Q = ["style"];
var _templateObject$G, _templateObject2$v, _templateObject3$f, _templateObject4$d, _templateObject5$b, _templateObject6$a, _templateObject7$6, _templateObject8$6, _templateObject9$6, _templateObject10$6, _templateObject11$4, _templateObject12$3, _templateObject13$3, _templateObject14$2, _templateObject15$2;
const propTypes$S = {
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$F = StyleSheet.create({
  '.popover-arrow': css(_templateObject$G || (_templateObject$G = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    width: $popover-arrow-width;\n    height: $popover-arrow-height;\n  "]))),
  '.popover-arrow::before': css(_templateObject2$v || (_templateObject2$v = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
  '.popover-arrow::after': css(_templateObject3$f || (_templateObject3$f = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
  '.bs-popover-top .popover-arrow': css(_templateObject4$d || (_templateObject4$d = _taggedTemplateLiteral(["\n    bottom: ", ";\n  "])), subtract(t => "-".concat(t['popover-arrow-height']), t => t['popover-border-width'])),
  '.bs-popover-top .popover-arrow::before': css(_templateObject5$b || (_templateObject5$b = _taggedTemplateLiteral(["\n    bottom: 0;\n    border-top-width: $popover-arrow-height;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $popover-arrow-outer-color;\n  "]))),
  '.bs-popover-top .popover-arrow::after': css(_templateObject6$a || (_templateObject6$a = _taggedTemplateLiteral(["\n    bottom: $popover-border-width;\n    border-top-width: $popover-arrow-height;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $popover-arrow-color;\n  "]))),
  '.bs-popover-end .popover-arrow': css(_templateObject7$6 || (_templateObject7$6 = _taggedTemplateLiteral(["\n    left: ", ";\n    width: $popover-arrow-height;\n    height: $popover-arrow-width;\n  "])), subtract(t => "-".concat(t['popover-arrow-height']), t => t['popover-border-width'])),
  '.bs-popover-end .popover-arrow::before': css(_templateObject8$6 || (_templateObject8$6 = _taggedTemplateLiteral(["\n    left: 0;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: $popover-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-right-color: $popover-arrow-outer-color;\n  "]))),
  '.bs-popover-end .popover-arrow::after': css(_templateObject9$6 || (_templateObject9$6 = _taggedTemplateLiteral(["\n    left: $popover-border-width;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: $popover-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-right-color: $popover-arrow-color;\n  "]))),
  '.bs-popover-bottom .popover-arrow': css(_templateObject10$6 || (_templateObject10$6 = _taggedTemplateLiteral(["\n    top: ", ";\n  "])), subtract(t => "-".concat(t['popover-arrow-height']), t => t['popover-border-width'])),
  '.bs-popover-bottom .popover-arrow::before': css(_templateObject11$4 || (_templateObject11$4 = _taggedTemplateLiteral(["\n    top: 0;\n    border-top-width: 0;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: $popover-arrow-height;\n    border-bottom-color: $popover-arrow-outer-color;\n  "]))),
  '.bs-popover-bottom .popover-arrow::after': css(_templateObject12$3 || (_templateObject12$3 = _taggedTemplateLiteral(["\n    top: $popover-border-width;\n    border-top-width: 0;\n    border-right-width: $popover-arrow-width * 0.5;\n    border-left-width: $popover-arrow-width * 0.5;\n    border-bottom-width: $popover-arrow-height;\n    border-bottom-color: $popover-arrow-color;\n  "]))),
  '.bs-popover-start .popover-arrow': css(_templateObject13$3 || (_templateObject13$3 = _taggedTemplateLiteral(["\n    right: ", ";\n    width: $popover-arrow-height;\n    height: $popover-arrow-width;\n  "])), subtract(t => "-".concat(t['popover-arrow-height']), t => t['popover-border-width'])),
  '.bs-popover-start .popover-arrow::before': css(_templateObject14$2 || (_templateObject14$2 = _taggedTemplateLiteral(["\n    right: 0;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $popover-arrow-height;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-left-color: $popover-arrow-outer-color;\n  "]))),
  '.bs-popover-start .popover-arrow::after': css(_templateObject15$2 || (_templateObject15$2 = _taggedTemplateLiteral(["\n    right: $popover-border-width;\n    border-top-width: $popover-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $popover-arrow-height;\n    border-bottom-width: $popover-arrow-width * 0.5;\n    border-left-color: $popover-arrow-color;\n  "])))
});
const PopoverArrow = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$Q);
  const {
    placement,
    arrowStyle,
    popper
  } = useForcedContext(PopoverContext);
  const classes = getStyles(styles$F, ['.popover-arrow', popper && ".bs-popover-".concat(placement, " .popover-arrow")]);
  const beforeClasses = getStyles(styles$F, ['.popover-arrow::before', popper && ".bs-popover-".concat(placement, " .popover-arrow::before")]);
  const afterClasses = getStyles(styles$F, ['.popover-arrow::after', popper && ".bs-popover-".concat(placement, " .popover-arrow::after")]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, arrowStyle, style]
  }), /*#__PURE__*/React__default["default"].createElement(View, {
    style: beforeClasses
  }), /*#__PURE__*/React__default["default"].createElement(View, {
    style: afterClasses
  }));
});
PopoverArrow.displayName = 'PopoverArrow';
PopoverArrow.propTypes = propTypes$S;

const _excluded$P = ["children", "style", "textStyle"];
var _templateObject$F, _templateObject2$u;
const propTypes$R = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$E = StyleSheet.create({
  '.popover-header': css(_templateObject$F || (_templateObject$F = _taggedTemplateLiteral(["\n    padding: $popover-header-padding-y $popover-header-padding-x;\n    background-color: $popover-header-bg;\n    border-bottom-width: $popover-border-width;\n    border-style: solid;\n    border-color: $popover-border-color;\n    border-top-left-radius: $popover-border-radius;\n    border-top-right-radius: $popover-border-radius;\n  "]))),
  '.popover-header --text': css(_templateObject2$u || (_templateObject2$u = _taggedTemplateLiteral(["\n    margin-bottom: 0; // Reset the default from Reboot\n    font-size: $font-size-base;\n    line-height: $font-size-base * $headings-line-height; // added for bootstrap-rn\n    color: $popover-header-color;\n  "])))
});
const PopoverHeader = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$P);
  const classes = getStyles(styles$E, ['.popover-header']);
  const textClasses = getStyles(styles$E, ['.popover-header --text']);

  // composite component
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(Heading$1, {
    size: 3,
    style: [textClasses, textStyle]
  }, children));
});
PopoverHeader.displayName = 'PopoverHeader';
PopoverHeader.propTypes = propTypes$R;

const _excluded$O = ["children", "style", "textStyle"];
var _templateObject$E, _templateObject2$t;
const propTypes$Q = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$D = StyleSheet.create({
  '.popover-body': css(_templateObject$E || (_templateObject$E = _taggedTemplateLiteral(["\n    padding: $popover-body-padding-y $popover-body-padding-x;\n  "]))),
  '.popover-body --text': css(_templateObject2$t || (_templateObject2$t = _taggedTemplateLiteral(["\n    color: $popover-body-color;\n  "])))
});
const PopoverBody = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$O);
  const classes = getStyles(styles$D, ['.popover-body']);
  const textClasses = getStyles(styles$D, ['.popover-body --text']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
PopoverBody.displayName = 'PopoverBody';
PopoverBody.propTypes = propTypes$Q;

const _excluded$N = ["children", "placement", "popper", "style", "textStyle", "arrowStyle"];
var _templateObject$D, _templateObject2$s;
const propTypes$P = {
  children: PropTypes__default["default"].node.isRequired,
  placement: PropTypes__default["default"].string,
  popper: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  arrowStyle: PropTypes__default["default"].any
};
const styles$C = StyleSheet.create({
  '.popover': css(_templateObject$D || (_templateObject$D = _taggedTemplateLiteral(["\n    position: absolute;\n    // top: 0;\n    // left: 0 #{\"/* rtl:ignore */\"};\n    z-index: $zindex-popover;\n    // display: block;\n    max-width: $popover-max-width;\n    background-color: $popover-bg;\n    // background-clip: padding-box;\n    border: $popover-border-width solid $popover-border-color;\n    border-radius: $popover-border-radius;\n    // @include box-shadow($popover-box-shadow);\n  "]))),
  '.popover --text': css(_templateObject2$s || (_templateObject2$s = _taggedTemplateLiteral(["\n    // Our parent element can be arbitrary since tooltips are by default inserted as a sibling of their target element.\n    // So reset our font and text properties to avoid inheriting weird values.\n    // @include reset-text();\n    font-size: $popover-font-size;\n    // Allow breaking very long words so they don't overflow the popover's bounds\n    // word-wrap: break-word;\n  "])))
});
const Popover = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      placement = 'right',
      popper,
      style,
      textStyle,
      arrowStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$N);
  const popover = {
    placement: transformPlacement$1(placement),
    arrowStyle,
    popper
  };
  const classes = getStyles(styles$C, ['.popover']);
  const textClasses = getStyles(styles$C, ['.popover --text']);

  // Accessiblity role tooltip is only supported on web.
  const role = reactNative.Platform.OS === 'web' ? 'tooltip' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/React__default["default"].createElement(PopoverContext.Provider, {
    value: popover
  }, children));
});
Popover.displayName = 'Popover';
Popover.propTypes = propTypes$P;
Popover.Arrow = PopoverArrow;
Popover.Header = PopoverHeader;
Popover.Body = PopoverBody;

const _excluded$M = ["title", "content", "autoClose", "trigger", "placement"],
  _excluded2$2 = ["popover"];
const propTypes$O = {
  popover: PropTypes__default["default"].shape(_objectSpread2({
    title: PropTypes__default["default"].node,
    content: PropTypes__default["default"].node.isRequired,
    autoClose: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].oneOf(['inside', 'outside'])])
  }, TriggerPropTypes))
};
function injectPopover(Target) {
  const OverlayPopover = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
    /* eslint-disable react/prop-types */
    const {
        popover: {
          title,
          content,
          autoClose = 'outside',
          trigger = 'press',
          placement = 'right'
        }
      } = props,
      tooltipProps = _objectWithoutProperties(props.popover, _excluded$M),
      elementProps = _objectWithoutProperties(props, _excluded2$2);
    /* eslint-enable */

    const {
      visible,
      setVisible,
      targetProps,
      targetRef,
      templateProps
    } = useTrigger(trigger, tooltipProps, elementProps, ref);
    const offset = normalizeNumber(StyleSheet.value('popover-arrow-height'));
    return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(Target, _extends({}, elementProps, targetProps)), visible && /*#__PURE__*/React__default["default"].createElement(overlays.OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
      placement: placement,
      offset: offset,
      arrowOffset: offset,
      targetRef: targetRef,
      visible: visible
    }, (overlay, overlayRef) => /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
      toggleRef: targetRef,
      dialogRef: overlayRef,
      onClose: () => {
        setVisible(false);
      },
      autoClose: autoClose
    }), /*#__PURE__*/React__default["default"].createElement(Popover, _extends({}, templateProps, {
      ref: overlayRef,
      placement: overlay.placement,
      popper: overlay.rendered,
      style: [overlay.overlayProps.style, {
        maxHeight: 'auto',
        opacity: overlay.rendered ? 1 : 0
      }],
      arrowStyle: overlay.arrowProps.style
    }), /*#__PURE__*/React__default["default"].createElement(Popover.Arrow, null), title && /*#__PURE__*/React__default["default"].createElement(Popover.Header, null, title), /*#__PURE__*/React__default["default"].createElement(Popover.Body, null, content))))));
  });
  OverlayPopover.displayName = 'Overlay(Popover)';
  OverlayPopover.propTypes = propTypes$O;
  return OverlayPopover;
}

const TooltipContext = /*#__PURE__*/React__default["default"].createContext();
TooltipContext.displayName = 'TooltipContext';

const _excluded$L = ["style"];
var _templateObject$C, _templateObject2$r, _templateObject3$e, _templateObject4$c, _templateObject5$a, _templateObject6$9, _templateObject7$5, _templateObject8$5, _templateObject9$5, _templateObject10$5;
const propTypes$N = {
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$B = StyleSheet.create({
  '.tooltip-arrow': css(_templateObject$C || (_templateObject$C = _taggedTemplateLiteral(["\n    position: absolute;\n    // display: block;\n    width: $tooltip-arrow-width;\n    height: $tooltip-arrow-height;\n  "]))),
  '.tooltip-arrow::before': css(_templateObject2$r || (_templateObject2$r = _taggedTemplateLiteral(["\n    position: absolute;\n    // content: \"\";\n    border-top-color: transparent;\n    border-right-color: transparent;\n    border-left-color: transparent;\n    border-bottom-color: transparent;\n    border-style: solid;\n  "]))),
  '.bs-tooltip-top .tooltip-arrow': css(_templateObject3$e || (_templateObject3$e = _taggedTemplateLiteral(["\n    bottom: 0;\n  "]))),
  '.bs-tooltip-top .tooltip-arrow::before': css(_templateObject4$c || (_templateObject4$c = _taggedTemplateLiteral(["\n    top: -1px;\n    border-top-width: $tooltip-arrow-height;\n    border-right-width: $tooltip-arrow-width * 0.5;\n    border-left-width: $tooltip-arrow-width * 0.5;\n    border-bottom-width: 0;\n    border-top-color: $tooltip-arrow-color;\n  "]))),
  '.bs-tooltip-end .tooltip-arrow': css(_templateObject5$a || (_templateObject5$a = _taggedTemplateLiteral(["\n    left: 0;\n    width: $tooltip-arrow-height;\n    height: $tooltip-arrow-width;\n  "]))),
  '.bs-tooltip-end .tooltip-arrow::before': css(_templateObject6$9 || (_templateObject6$9 = _taggedTemplateLiteral(["\n    right: -1px;\n    border-top-width: $tooltip-arrow-width * 0.5;\n    border-right-width: $tooltip-arrow-height;\n    border-left-width: 0;\n    border-bottom-width: $tooltip-arrow-width * 0.5;\n    border-right-color: $tooltip-arrow-color;\n  "]))),
  '.bs-tooltip-bottom .tooltip-arrow': css(_templateObject7$5 || (_templateObject7$5 = _taggedTemplateLiteral(["\n    top: 0;\n  "]))),
  '.bs-tooltip-bottom .tooltip-arrow::before': css(_templateObject8$5 || (_templateObject8$5 = _taggedTemplateLiteral(["\n    bottom: -1px;\n    border-top-width: 0;\n    border-right-width: $tooltip-arrow-width * 0.5;\n    border-left-width: $tooltip-arrow-width * 0.5;\n    border-bottom-width: $tooltip-arrow-height;\n    border-bottom-color: $tooltip-arrow-color;\n  "]))),
  '.bs-tooltip-start .tooltip-arrow': css(_templateObject9$5 || (_templateObject9$5 = _taggedTemplateLiteral(["\n    right: 0;\n    width: $tooltip-arrow-height;\n    height: $tooltip-arrow-width;\n  "]))),
  '.bs-tooltip-start .tooltip-arrow::before': css(_templateObject10$5 || (_templateObject10$5 = _taggedTemplateLiteral(["\n    left: -1px;\n    border-top-width: $tooltip-arrow-width * 0.5;\n    border-right-width: 0;\n    border-left-width: $tooltip-arrow-height;\n    border-bottom-width: $tooltip-arrow-width * 0.5;\n    border-left-color: $tooltip-arrow-color;\n  "])))
});
const TooltipArrow = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$L);
  const {
    placement,
    arrowStyle,
    popper
  } = useForcedContext(TooltipContext);
  const classes = getStyles(styles$B, ['.tooltip-arrow', popper && ".bs-tooltip-".concat(placement, " .tooltip-arrow")]);
  const beforeClasses = getStyles(styles$B, ['.tooltip-arrow::before', popper && ".bs-tooltip-".concat(placement, " .tooltip-arrow::before")]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, arrowStyle, style]
  }), /*#__PURE__*/React__default["default"].createElement(View, {
    style: beforeClasses
  }));
});
TooltipArrow.displayName = 'TooltipArrow';
TooltipArrow.propTypes = propTypes$N;

const _excluded$K = ["children", "style", "textStyle"];
var _templateObject$B, _templateObject2$q;
const propTypes$M = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$A = StyleSheet.create({
  '.tooltip-inner': css(_templateObject$B || (_templateObject$B = _taggedTemplateLiteral(["\n    max-width: $tooltip-max-width;\n    padding: $tooltip-padding-y $tooltip-padding-x;\n    background-color: $tooltip-bg;\n    border-radius: $tooltip-border-radius;\n  "]))),
  '.tooltip-inner --text': css(_templateObject2$q || (_templateObject2$q = _taggedTemplateLiteral(["\n    color: $tooltip-color;\n    text-align: center;\n  "])))
});
const TooltipInner = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$K);
  const classes = getStyles(styles$A, ['.tooltip-inner']);
  const textClasses = getStyles(styles$A, ['.tooltip-inner --text']);

  // composite component
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(Text, {
    style: [textClasses, textStyle]
  }, children));
});
TooltipInner.displayName = 'TooltipInner';
TooltipInner.propTypes = propTypes$M;

const _excluded$J = ["children", "placement", "popper", "style", "textStyle", "arrowStyle"];
var _templateObject$A, _templateObject2$p, _templateObject3$d, _templateObject4$b, _templateObject5$9, _templateObject6$8;
const propTypes$L = {
  children: PropTypes__default["default"].node.isRequired,
  placement: PropTypes__default["default"].string,
  popper: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  arrowStyle: PropTypes__default["default"].any
};
const styles$z = StyleSheet.create({
  '.tooltip': css(_templateObject$A || (_templateObject$A = _taggedTemplateLiteral(["\n    position: absolute;\n    z-index: $zindex-tooltip;\n    // display: block;\n    margin: $tooltip-margin;\n    // opacity: 0;\n  "]))),
  '.tooltip --text': css(_templateObject2$p || (_templateObject2$p = _taggedTemplateLiteral(["\n    // Our parent element can be arbitrary since tooltips are by default inserted as a sibling of their target element.\n    // So reset our font and text properties to avoid inheriting weird values.\n    // @include reset-text();\n    font-size: $tooltip-font-size;\n    // Allow breaking very long words so they don't overflow the tooltip's bounds\n    // word-wrap: break-word;\n  "]))),
  '.bs-tooltip-top': css(_templateObject3$d || (_templateObject3$d = _taggedTemplateLiteral(["\n    padding: $tooltip-arrow-height 0;\n  "]))),
  '.bs-tooltip-end': css(_templateObject4$b || (_templateObject4$b = _taggedTemplateLiteral(["\n    padding: 0 $tooltip-arrow-height;\n  "]))),
  '.bs-tooltip-bottom': css(_templateObject5$9 || (_templateObject5$9 = _taggedTemplateLiteral(["\n    padding: $tooltip-arrow-height 0;\n  "]))),
  '.bs-tooltip-start': css(_templateObject6$8 || (_templateObject6$8 = _taggedTemplateLiteral(["\n    padding: 0 $tooltip-arrow-height;\n  "])))
});
const Tooltip = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      placement = 'top',
      popper,
      style,
      textStyle,
      arrowStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$J);
  const tooltip = {
    placement: transformPlacement$1(placement),
    arrowStyle,
    popper
  };
  const classes = getStyles(styles$z, ['.tooltip',
  // Wait for rendering (of Overlay) before setting the offset.
  popper && ".bs-tooltip-".concat(tooltip.placement)]);
  const textClasses = getStyles(styles$z, ['.tooltip --text']);

  // Accessiblity role tooltip is only supported on web.
  const role = reactNative.Platform.OS === 'web' ? 'tooltip' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/React__default["default"].createElement(TooltipContext.Provider, {
    value: tooltip
  }, children));
});
Tooltip.displayName = 'Tooltip';
Tooltip.propTypes = propTypes$L;
Tooltip.Arrow = TooltipArrow;
Tooltip.Inner = TooltipInner;

const _excluded$I = ["title", "autoClose", "trigger", "placement"],
  _excluded2$1 = ["tooltip"];
const propTypes$K = {
  tooltip: PropTypes__default["default"].shape(_objectSpread2({
    title: PropTypes__default["default"].node.isRequired,
    autoClose: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].oneOf(['inside', 'outside'])])
  }, TriggerPropTypes))
};
function injectTooltip(Target) {
  const OverlayTooltip = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
    /* eslint-disable react/prop-types */
    const {
        tooltip: {
          title,
          autoClose = 'outside',
          trigger = 'hover focus',
          placement = 'top'
        }
      } = props,
      tooltipProps = _objectWithoutProperties(props.tooltip, _excluded$I),
      elementProps = _objectWithoutProperties(props, _excluded2$1);
    /* eslint-enable */

    const {
      visible,
      setVisible,
      targetProps,
      targetRef,
      templateProps
    } = useTrigger(trigger, tooltipProps, elementProps, ref);
    const offset = normalizeNumber(StyleSheet.value('tooltip-arrow-height'));
    return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(Target, _extends({}, elementProps, targetProps)), visible && /*#__PURE__*/React__default["default"].createElement(overlays.OverlayContainer, null, /*#__PURE__*/React__default["default"].createElement(Overlay, {
      placement: placement,
      targetRef: targetRef,
      arrowOffset: offset,
      visible: visible
    }, (overlay, overlayRef) => /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
      toggleRef: targetRef,
      dialogRef: overlayRef,
      onClose: () => {
        setVisible(false);
      },
      autoClose: autoClose
    }), /*#__PURE__*/React__default["default"].createElement(Tooltip, _extends({}, templateProps, {
      ref: overlayRef,
      placement: overlay.placement,
      popper: overlay.rendered,
      style: [overlay.overlayProps.style, {
        maxHeight: 'auto',
        opacity: overlay.rendered ? 1 : 0
      }],
      arrowStyle: overlay.arrowProps.style
    }), /*#__PURE__*/React__default["default"].createElement(Tooltip.Arrow, null), /*#__PURE__*/React__default["default"].createElement(Tooltip.Inner, null, title))))));
  });
  OverlayTooltip.displayName = 'Overlay(Tooltip)';
  OverlayTooltip.propTypes = propTypes$K;
  return OverlayTooltip;
}

const _excluded$H = ["style", "styleName"];
const propTypes$J = {
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
const Image = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      style,
      styleName
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$H);
  const media = useMedia();
  const resolveStyle = useStyle(style, styleName);
  return /*#__PURE__*/React__default["default"].createElement(reactNative.Image, _extends({}, elementProps, {
    ref: ref,
    style: resolveStyle({
      media
    })
  }));
});
Image.displayName = 'Image';
Image.propTypes = propTypes$J;

const _excluded$G = ["style", "styleName"];
const propTypes$I = {
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
const ImageBackground = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      style,
      styleName
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$G);
  const media = useMedia();
  const resolveStyle = useStyle(style, styleName);
  return /*#__PURE__*/React__default["default"].createElement(reactNative.ImageBackground, _extends({}, elementProps, {
    ref: ref,
    style: resolveStyle({
      media
    })
  }));
});
ImageBackground.displayName = 'ImageBackground';
ImageBackground.propTypes = propTypes$I;

const ListGroupContext = /*#__PURE__*/React__default["default"].createContext();
ListGroupContext.displayName = 'ListGroupContext';

const _excluded$F = ["children", "color", "active", "disabled", "style", "textStyle"];
var _templateObject$z, _templateObject2$o, _templateObject3$c, _templateObject4$a, _templateObject5$8, _templateObject6$7, _templateObject7$4, _templateObject8$4, _templateObject9$4, _templateObject10$4, _templateObject11$3, _templateObject12$2, _templateObject13$2, _templateObject14$1, _templateObject15$1;
const propTypes$H = {
  children: PropTypes__default["default"].node.isRequired,
  color: PropTypes__default["default"].oneOf(Object.keys(THEME_COLORS)),
  active: PropTypes__default["default"].bool,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$y = StyleSheet.create(_objectSpread2({
  '.list-group-item': css(_templateObject$z || (_templateObject$z = _taggedTemplateLiteral(["\n    position: relative;\n    // display: block;\n    padding: $list-group-item-padding-y $list-group-item-padding-x;\n    background-color: $list-group-bg;\n    border: $list-group-border-width solid $list-group-border-color;\n  "]))),
  '.list-group-item --text': css(_templateObject2$o || (_templateObject2$o = _taggedTemplateLiteral(["\n    color: $list-group-color;\n    text-decoration: none; // if($link-decoration == none, null, none);\n  "]))),
  '.list-group-item:first-child': css(_templateObject3$c || (_templateObject3$c = _taggedTemplateLiteral(["\n    border-top-left-radius: $list-group-border-radius;\n    border-top-right-radius: $list-group-border-radius;\n  "]))),
  '.list-group-item:last-child': css(_templateObject4$a || (_templateObject4$a = _taggedTemplateLiteral(["\n    border-bottom-left-radius: $list-group-border-radius;\n    border-bottom-right-radius: $list-group-border-radius;\n  "]))),
  '.list-group-item.disabled': css(_templateObject5$8 || (_templateObject5$8 = _taggedTemplateLiteral(["\n    // pointer-events: none;\n    background-color: $list-group-disabled-bg;\n  "]))),
  '.list-group-item.disabled --text': css(_templateObject6$7 || (_templateObject6$7 = _taggedTemplateLiteral(["\n    color: $list-group-disabled-color;\n  "]))),
  '.list-group-item.active': css(_templateObject7$4 || (_templateObject7$4 = _taggedTemplateLiteral(["\n    z-index: 2; // Place active items above their siblings for proper border styling\n    background-color: $list-group-active-bg;\n    border-color: $list-group-active-border-color;\n  "]))),
  '.list-group-item.active --text': css(_templateObject8$4 || (_templateObject8$4 = _taggedTemplateLiteral(["\n    color: $list-group-active-color;\n  "]))),
  '.list-group-item + .list-group-item': css(_templateObject9$4 || (_templateObject9$4 = _taggedTemplateLiteral(["\n    border-top-width: 0;\n  "]))),
  '.list-group-item + .list-group-item.active': css(_templateObject10$4 || (_templateObject10$4 = _taggedTemplateLiteral(["\n    margin-top: -$list-group-border-width;\n    border-top-width: $list-group-border-width;\n  "]))),
  '.list-group-item-flush': css(_templateObject11$3 || (_templateObject11$3 = _taggedTemplateLiteral(["\n    border-top-left-radius: 0; // added for bootstrap-rn\n    border-top-right-radius: 0; // added for bootstrap-rn\n    border-bottom-left-radius: 0; // added for bootstrap-rn\n    border-bottom-right-radius: 0; // added for bootstrap-rn\n    border-top-width: 0;\n    border-right-width: 0;\n    border-bottom-width: $list-group-border-width;\n    border-left-width: 0;\n  "]))),
  '.list-group-item-flush:last-child': css(_templateObject12$2 || (_templateObject12$2 = _taggedTemplateLiteral(["\n    border-bottom-width: 0;\n  "]))),
  '.list-group-item-flush + .list-group-item-flush.active': css(_templateObject13$2 || (_templateObject13$2 = _taggedTemplateLiteral(["\n    border-top-width: $list-group-border-width; // added for bootstrap-rn\n  "])))
}, each(THEME_COLORS, (state, value) => ({
  [".list-group-item-".concat(state)]: css(_templateObject14$1 || (_templateObject14$1 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), shiftColor(value, t => t['list-group-item-bg-scale'])),
  [".list-group-item-".concat(state, " --text")]: css(_templateObject15$1 || (_templateObject15$1 = _taggedTemplateLiteral(["\n      color: ", ";\n    "])), shiftColor(value, t => t['list-group-item-color-scale']))
}))));
const ListGroupItem = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      color,
      active = false,
      disabled = false,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$F);
  const {
    first,
    last
  } = useForcedContext(ListContext);
  const {
    flush
  } = useForcedContext(ListGroupContext);
  const classes = getStyles(styles$y, ['.list-group-item', first && '.list-group-item:first-child', last && '.list-group-item:last-child', active && '.list-group-item.active', disabled && '.list-group-item.disabled', !first && '.list-group-item + .list-group-item', !first && active && '.list-group-item + .list-group-item.active', flush && '.list-group-item-flush', flush && last && '.list-group-item-flush:last-child', !first && flush && active && '.list-group-item-flush + .list-group-item-flush.active', color && ".list-group-item-".concat(color)]);
  const textClasses = getStyles(styles$y, ['.list-group-item --text', active && '.list-group-item.active --text', disabled && '.list-group-item.disabled --text', color && ".list-group-item-".concat(color, " --text")]);
  const role = reactNative.Platform.OS === 'web' ? 'listitem' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
ListGroupItem.displayName = 'ListGroupItem';
ListGroupItem.propTypes = propTypes$H;

const _excluded$E = ["children", "color", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];
var _templateObject$y, _templateObject2$n, _templateObject3$b, _templateObject4$9, _templateObject5$7, _templateObject6$6;
const propTypes$G = {
  children: PropTypes__default["default"].node.isRequired,
  color: PropTypes__default["default"].oneOf(Object.keys(THEME_COLORS)),
  active: PropTypes__default["default"].bool,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  activeStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  activeTextStyle: PropTypes__default["default"].any
};
const actionStyles = StyleSheet.create(_objectSpread2({
  '.list-group-item-action': css(_templateObject$y || (_templateObject$y = _taggedTemplateLiteral(["\n    width: 100%; // For \"<button>\"s (anchors become 100% by default though)\n\n    // Hover state\n    &:hover {\n      z-index: 1; // Place hover/focus items above their siblings for proper border styling\n      background-color: $list-group-hover-bg;\n    }\n\n    &:focus {\n      z-index: 1; // Place hover/focus items above their siblings for proper border styling\n      background-color: $list-group-hover-bg;\n    }\n\n    &:active {\n      background-color: $list-group-action-active-bg;\n    }\n  "]))),
  '.list-group-item-action --text': css(_templateObject2$n || (_templateObject2$n = _taggedTemplateLiteral(["\n    color: $list-group-action-color;\n    // text-align: inherit; // For \"<button>\"s (anchors inherit)\n\n    // Hover state\n    &:hover {\n      color: $list-group-action-hover-color;\n      text-decoration: none;\n    }\n\n    &:focus {\n      color: $list-group-action-hover-color;\n      text-decoration: none;\n    }\n\n    &:active {\n      color: $list-group-action-active-color;\n    }\n  "])))
}, each(THEME_COLORS, (state, value) => ({
  [".list-group-item-".concat(state, "-action")]: css(_templateObject3$b || (_templateObject3$b = _taggedTemplateLiteral(["\n      &:hover {\n        background-color: ", ";\n      }\n\n      &:focus {\n        background-color: ", ";\n      }\n    "])), shadeColor(shiftColor(value, t => t['list-group-item-bg-scale']), 0.1), shadeColor(shiftColor(value, t => t['list-group-item-bg-scale']), 0.1)),
  [".list-group-item-".concat(state, "-action --text")]: css(_templateObject4$9 || (_templateObject4$9 = _taggedTemplateLiteral(["\n      &:hover {\n        color: ", ";\n      }\n\n      &:focus {\n        color: ", ";\n      }\n    "])), shiftColor(value, t => t['list-group-item-color-scale']), shiftColor(value, t => t['list-group-item-color-scale'])),
  [".list-group-item-".concat(state, "-action.active")]: css(_templateObject5$7 || (_templateObject5$7 = _taggedTemplateLiteral(["\n      background-color: ", ";\n      border-color: ", ";\n    "])), shiftColor(value, t => t['list-group-item-color-scale']), shiftColor(value, t => t['list-group-item-color-scale'])),
  [".list-group-item-".concat(state, "-action.active --text")]: css(_templateObject6$6 || (_templateObject6$6 = _taggedTemplateLiteral(["\n      color: $white;\n    "])))
}))));
const ListGroupItemAction = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useTabbable', props, ref);
  const {
      children,
      color,
      active = false,
      disabled = false,
      style,
      activeStyle,
      textStyle,
      activeTextStyle
    } = modifierProps,
    elementProps = _objectWithoutProperties(modifierProps, _excluded$E);
  const {
    first,
    last
  } = useForcedContext(ListContext);
  const {
    flush
  } = useForcedContext(ListGroupContext);
  const styles = _objectSpread2(_objectSpread2({}, styles$y), actionStyles);
  const classes = getStyles(styles, ['.list-group-item', '.list-group-item-action', first && '.list-group-item:first-child', last && '.list-group-item:last-child', disabled && '.list-group-item.disabled', !first && '.list-group-item + .list-group-item', !first && active && '.list-group-item + .list-group-item.active', flush && '.list-group-item-flush', flush && last && '.list-group-item-flush:last-child', !first && flush && active && '.list-group-item-flush + .list-group-item-flush.active', color && ".list-group-item-".concat(color), color && ".list-group-item-".concat(color, "-action")]);
  const activeClasses = getStyles(styles, ['.list-group-item.active', color && ".list-group-item-".concat(color, "-action.active")]);
  const textClasses = getStyles(styles, ['.list-group-item --text', '.list-group-item-action --text', disabled && '.list-group-item.disabled --text', color && ".list-group-item-".concat(color, " --text"), color && ".list-group-item-".concat(color, "-action --text")]);
  const activeTextClasses = getStyles(styles, ['.list-group-item.active --text', color && ".list-group-item-".concat(color, "-action.active --text")]);
  const role = reactNative.Platform.OS === 'web' ? 'listitem' : null;
  return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends({}, elementProps, {
    ref: modifierRef,
    accessibilityRole: role,
    active: active,
    disabled: disabled,
    style: [...classes, style],
    activeStyle: [...activeClasses, activeStyle],
    textStyle: [...textClasses, textStyle],
    activeTextStyle: [...activeTextClasses, activeTextStyle]
  }), children);
});
ListGroupItemAction.displayName = 'ListGroupItemAction';
ListGroupItemAction.propTypes = propTypes$G;

const _excluded$D = ["children", "flush", "style"];
var _templateObject$x, _templateObject2$m;
const propTypes$F = {
  children: PropTypes__default["default"].node.isRequired,
  flush: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$x = StyleSheet.create({
  '.list-group': css(_templateObject$x || (_templateObject$x = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column;\n\n    // No need to set list-style: none; since .list-group-item is block level\n    padding-left: 0; // reset padding because ul and ol\n    margin-bottom: 0;\n    border-radius: $list-group-border-radius;\n  "]))),
  '.list-group-flush': css(_templateObject2$m || (_templateObject2$m = _taggedTemplateLiteral(["\n    border-radius: 0;\n  "])))
});
const getRole$1 = tabbable => {
  if (tabbable) {
    return 'tablist';
  }
  if (reactNative.Platform.OS === 'web') {
    return 'list';
  }
  return null;
};
const ListGroup = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      flush,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$D);
  const list = useList(children);
  const classes = getStyles(styles$x, ['.list-group', flush && '.list-group-flush']);

  // TODO: Implement TabContext
  const tabbable = false;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: getRole$1(tabbable),
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(ListGroupContext.Provider, {
    value: {
      flush
    }
  }, list));
});
ListGroup.displayName = 'ListGroup';
ListGroup.propTypes = propTypes$F;
ListGroup.Item = ListGroupItem;
ListGroup.ItemAction = ListGroupItemAction;

const _excluded$C = ["children", "onHoverIn", "onHoverOut", "onMouseEnter", "onMouseLeave", "style"],
  _excluded2 = ["onHoverIn", "onHoverOut"];
var _templateObject$w;
const propTypes$E = {
  children: PropTypes__default["default"].node.isRequired,
  onMouseEnter: PropTypes__default["default"].func,
  onMouseLeave: PropTypes__default["default"].func,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$w = StyleSheet.create({
  link: css(_templateObject$w || (_templateObject$w = _taggedTemplateLiteral(["\n    color: $link-color;\n    text-decoration-color: $link-color; // added for bootstrap-rn\n    text-decoration-line: $link-decoration;\n\n    &:hover {\n      color: $link-hover-color;\n      text-decoration-color: $link-hover-color; // added for bootstrap-rn\n      text-decoration-line: $link-hover-decoration;\n    }\n  "])))
});
const Link = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useActionable', props, ref);
  const [actionProps, actionRef] = useAction(modifierProps, modifierRef);
  const {
      children,
      // Filter hover handlers, because Text component does not have hover
      // handlers. Instead we use mouse enter/leave handlers.
      onHoverIn,
      onHoverOut,
      onMouseEnter: handleMouseEnter = () => {},
      onMouseLeave: handleMouseLeave = () => {},
      style
    } = actionProps,
    elementProps = _objectWithoutProperties(actionProps, _excluded$C);
  const media = useMedia();
  const classes = getStyles(styles$w, ['link']);
  const resolveStyle = useStyle([classes, style]);
  const _useInteractionState = useInteractionState(elementProps),
    {
      interaction,
      interactionProps: {
        onHoverIn: handleMouseEnterInteraction,
        onHoverOut: handleMouseLeaveInteraction
      }
    } = _useInteractionState,
    interactionProps = _objectWithoutProperties(_useInteractionState.interactionProps, _excluded2);
  return /*#__PURE__*/React__default["default"].createElement(Text, _extends({}, elementProps, interactionProps, {
    onMouseEnter: event => {
      handleMouseEnter(event);
      handleMouseEnterInteraction(event);
    },
    onMouseLeave: event => {
      handleMouseLeave(event);
      handleMouseLeaveInteraction(event);
    },
    ref: actionRef,
    accessibilityRole: getRole$2(actionProps),
    accessible: true,
    style: resolveStyle({
      media,
      interaction
    })
  }), children);
});
Link.displayName = 'Link';
Link.propTypes = propTypes$E;

const _excluded$B = ["children", "contentContainerStyle", "style", "textStyle", "styleName"];
const propTypes$D = {
  children: PropTypes__default["default"].node,
  // eslint-disable-next-line react/forbid-prop-types
  contentContainerStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
const ScrollView = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      contentContainerStyle,
      style,
      textStyle,
      styleName
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$B);
  const media = useMedia();
  const context = React.useContext(TextStyleContext);
  const resolveContentContainerStyle = useStyle(contentContainerStyle);
  const resolveStyle = useStyle(style, styleName);
  const resolveTextStyle = useStyle([context && context.style, textStyle]);
  const hasTextStyle = context && context.style || textStyle;
  return /*#__PURE__*/React__default["default"].createElement(reactNative.ScrollView, _extends({}, elementProps, {
    ref: ref,
    contentContainerStyle: resolveContentContainerStyle({
      media
    }),
    style: resolveStyle({
      media
    })
  }), hasTextStyle ? /*#__PURE__*/React__default["default"].createElement(TextStyleContext.Provider, {
    value: {
      style: resolveTextStyle({
        media
      }),
      hasAncestor: context && context.hasTextAncestor
    }
  }, children) : children);
});
ScrollView.displayName = 'ScrollView';
ScrollView.propTypes = propTypes$D;

const computeScrollbarWidth = () => {
  const documentWidth = document.documentElement.clientWidth;
  return Math.abs(window.innerWidth - documentWidth);
};
function useScrollbarEffects(_ref) {
  let {
    keepBodyScroll,
    visible
  } = _ref;
  if (reactNative.Platform.OS !== 'web' || keepBodyScroll) {
    return;
  }
  const context = React.useContext(Context);
  const scrollbarWidth = React.useRef();
  React.useEffect(() => {
    if (!visible) {
      return undefined;
    }
    if (!scrollbarWidth.current) {
      scrollbarWidth.current = computeScrollbarWidth();
    }
    const rect = document.body.getBoundingClientRect();
    const isBodyOverflowing = rect.left + rect.right < window.innerWidth;

    // Set body and fixed elements padding adjustments.
    const fixedElements = context.fixed.filter(ref => ref.current).map(ref => reactNative.findNodeHandle(ref.current));
    const elements = [document.body, ...fixedElements];
    const originalWidths = elements.map(el => el.style.width || '');
    const originalBodyOverflow = document.body.style.overflow || '';
    if (isBodyOverflowing) {
      elements.forEach(el => {
        // eslint-disable-next-line no-param-reassign
        el.style.width = "calc(100% - ".concat(scrollbarWidth.current, "px)");
      });
    }

    // Add "overflow: hidden" to body element.
    document.body.style.overflow = 'hidden';
    return () => {
      // Reset body padding adjustments.
      elements.forEach((el, key) => {
        // eslint-disable-next-line no-param-reassign
        el.style.width = originalWidths[key] || '';
      });

      // Remove "overflow: hidden" from body element.
      document.body.style.overflow = originalBodyOverflow;
    };
  }, [visible]);
}

function useModal(scrollable) {
  return React.useMemo(() => ({
    scrollable
  }), [scrollable]);
}

const _excluded$A = ["children", "style"];
var _templateObject$v;
const propTypes$C = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$v = StyleSheet.create({
  '.modal-header': css(_templateObject$v || (_templateObject$v = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-shrink: 0;\n    align-items: center;\n    justify-content: space-between; // Put modal header elements (title and dismiss) on opposite ends\n    padding: $modal-header-padding;\n    border-bottom-width: $modal-header-border-width;\n    border-style: solid;\n    border-color: $modal-header-border-color;\n    border-top-left-radius: $modal-content-inner-border-radius;\n    border-top-right-radius: $modal-content-inner-border-radius;\n  "])))
});
const ModalHeader = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$A);
  const classes = getStyles(styles$v, ['.modal-header']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
ModalHeader.displayName = 'ModalHeader';
ModalHeader.propTypes = propTypes$C;

const _excluded$z = ["children", "style"];
var _templateObject$u;
const propTypes$B = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$u = StyleSheet.create({
  '.modal-title': css(_templateObject$u || (_templateObject$u = _taggedTemplateLiteral(["\n    margin-bottom: 0;\n    line-height: $font-size-base * $modal-title-line-height;\n  "])))
});
const ModalTitle = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$z);
  const classes = getStyles(styles$u, ['.modal-title']);
  return /*#__PURE__*/React__default["default"].createElement(Heading$1, _extends({
    size: 5
  }, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
ModalTitle.displayName = 'ModalTitle';
ModalTitle.propTypes = propTypes$B;

const _excluded$y = ["children", "style", "contentContainerStyle"];
var _templateObject$t;
const propTypes$A = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  contentContainerStyle: PropTypes__default["default"].any
};
const styles$t = StyleSheet.create({
  '.modal-body': css(_templateObject$t || (_templateObject$t = _taggedTemplateLiteral(["\n    position: relative;\n    // Enable \"flex-grow: 1\" so that the body take up as much space as possible\n    // when there should be a fixed height on \".modal-dialog\".\n    // Note from bootstrap-rn: Centered modals do not work with this style, but\n    // everything just works fine without this style.\n    // flex: 1 1 auto;\n    padding: $modal-inner-padding;\n  "])))
});
const ModalBody = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      contentContainerStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$y);
  const {
    scrollable
  } = useForcedContext(ModalContext);
  const classes = getStyles(styles$t, ['.modal-body']);
  const FlexView = scrollable ? ScrollView : View;
  return /*#__PURE__*/React__default["default"].createElement(FlexView, _extends({}, elementProps, {
    ref: ref,
    style: scrollable ? style : [classes, style],
    contentContainerStyle: scrollable ? [classes, contentContainerStyle] : undefined
  }), children);
});
ModalBody.displayName = 'ModalBody';
ModalBody.propTypes = propTypes$A;

const _excluded$x = ["children", "style"];
var _templateObject$s;
const propTypes$z = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$s = StyleSheet.create({
  '.modal-footer': css(_templateObject$s || (_templateObject$s = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-shrink: 0;\n    flex-wrap: wrap;\n    align-items: center; // vertically center\n    justify-content: flex-end; // Right align buttons with flex property because text-align doesn't work on flex items\n    padding: $modal-inner-padding;\n    border-top-width: $modal-footer-border-width;\n    border-style: solid;\n    border-color: $modal-footer-border-color;\n    border-bottom-start-radius: $modal-content-inner-border-radius;\n    border-bottom-end-radius: $modal-content-inner-border-radius;\n  "])))
});
const ModalFooter = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$x);
  const classes = getStyles(styles$s, ['.modal-footer']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
ModalFooter.displayName = 'ModalFooter';
ModalFooter.propTypes = propTypes$z;

const _excluded$w = ["children", "visible", "size", "backdrop", "scrollable", "centered", "onToggle", "style", "contentContainerStyle", "dialogStyle", "contentStyle", "textStyle", "dialogTextStyle", "contentTextStyle"];
var _templateObject$r, _templateObject2$l, _templateObject3$a, _templateObject4$8, _templateObject5$6, _templateObject6$5, _templateObject7$3, _templateObject8$3, _templateObject9$3, _templateObject10$3, _templateObject11$2;
const MODAL_SIZES = ['sm', 'lg', 'xl'];
const propTypes$y = {
  children: PropTypes__default["default"].node.isRequired,
  visible: PropTypes__default["default"].bool.isRequired,
  size: PropTypes__default["default"].oneOf(MODAL_SIZES),
  backdrop: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].oneOf(['static'])]),
  scrollable: PropTypes__default["default"].bool,
  centered: PropTypes__default["default"].bool,
  onToggle: PropTypes__default["default"].func.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  contentContainerStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  dialogStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  contentStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  dialogTextStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  contentTextStyle: PropTypes__default["default"].any
};
const styles$r = StyleSheet.create({
  '.modal': css(_templateObject$r || (_templateObject$r = _taggedTemplateLiteral(["\n    position: absolute; // fixed;\n    top: 0;\n    left: 0;\n    z-index: $zindex-modal;\n    // display: none;\n    width: 100%;\n    height: 100%;\n    // overflow-x: hidden;\n    // overflow-y: auto;\n    // Prevent Chrome on Windows from adding a focus outline. For details, see\n    // https://github.com/twbs/bootstrap/pull/10951.\n    @include platform(web) {\n      outline-width: 0; // outline: 0;\n    }\n    // We deliberately don't use \"-webkit-overflow-scrolling: touch;\" due to a\n    // gnarly iOS Safari bug: https://bugs.webkit.org/show_bug.cgi?id=158342\n    // See also https://github.com/twbs/bootstrap/issues/17695\n  "]))),
  '.modal-dialog': css(_templateObject2$l || (_templateObject2$l = _taggedTemplateLiteral(["\n    position: relative;\n    width: auto;\n    margin: $modal-dialog-margin;\n    // allow clicks to pass through for custom click handling to close modal\n    // pointer-events: none;\n\n    @include media-breakpoint-up(sm) {\n      width: 100%; // added for bootstrap-rn\n      max-width: $modal-md;\n      margin: $modal-dialog-margin-y-sm-up auto;\n    }\n  "]))),
  '.modal-dialog-scrollable': css(_templateObject3$a || (_templateObject3$a = _taggedTemplateLiteral(["\n    flex-shrink: 1; // added for bootstrap-rn\n    // height: calc(100% - var(--#{$prefix}modal-margin) * 2);\n  "]))),
  '.modal-dialog-scrollable .modal-content': css(_templateObject4$8 || (_templateObject4$8 = _taggedTemplateLiteral(["\n    max-height: 100%;\n    overflow: hidden;\n  "]))),
  '.modal-dialog-centered': css(_templateObject5$6 || (_templateObject5$6 = _taggedTemplateLiteral(["\n    display: flex;\n    // align-items: center;\n    // min-height: calc(100% - var(--#{$prefix}modal-margin) * 2);\n  "]))),
  '.modal-content': css(_templateObject6$5 || (_templateObject6$5 = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-direction: column;\n    width: 100%; // Ensure \".modal-content\" extends the full width of the parent \".modal-dialog\"\n    // counteract the pointer-events: none; in the .modal-dialog\n    // pointer-events: auto;\n    background-color: $modal-content-bg;\n    // background-clip: padding-box;\n    border: $modal-content-border-width solid $modal-content-border-color;\n    border-radius: $modal-content-border-radius;\n    // @include box-shadow($modal-content-box-shadow-xs);\n    // Remove focus outline from opened modal\n    // outline: 0;\n\n    @include media-breakpoint-up(sm) {\n      // @include box-shadow($modal-content-box-shadow-sm-up);\n    }\n  "]))),
  '.modal-content --text': css(_templateObject7$3 || (_templateObject7$3 = _taggedTemplateLiteral(["\n    color: $modal-content-color;\n  "]))),
  '.modal-backdrop': css(_templateObject8$3 || (_templateObject8$3 = _taggedTemplateLiteral(["\n    position: absolute;\n    top: 0;\n    left: 0;\n    z-index: $zindex-modal-backdrop;\n    width: 100%;\n    height: 100%;\n    background-color: $modal-backdrop-bg;\n    opacity: $modal-backdrop-opacity;\n  "]))),
  '.modal-sm': css(_templateObject9$3 || (_templateObject9$3 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(sm) {\n      max-width: $modal-sm;\n    }\n  "]))),
  '.modal-lg': css(_templateObject10$3 || (_templateObject10$3 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(lg) {\n      max-width: $modal-lg;\n    }\n  "]))),
  '.modal-xl': css(_templateObject11$2 || (_templateObject11$2 = _taggedTemplateLiteral(["\n    @include media-breakpoint-up(lg) {\n      max-width: $modal-lg;\n    }\n    @include media-breakpoint-up(xl) {\n      max-width: $modal-xl;\n    }\n  "])))
});
const Modal = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      visible,
      size,
      backdrop = true,
      scrollable = false,
      centered = false,
      onToggle: handleToggle,
      style,
      contentContainerStyle,
      dialogStyle,
      contentStyle,
      textStyle,
      dialogTextStyle,
      contentTextStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$w);
  const dialogRef = React.useRef();
  const modal = useModal(scrollable);
  useScrollbarEffects({
    keepBodyScroll: false,
    visible
  });
  const backdropClasses = getStyles(styles$r, ['.modal-backdrop']);
  const classes = getStyles(styles$r, ['.modal']);
  const dialogClasses = getStyles(styles$r, ['.modal-dialog', size === 'sm' && '.modal-sm', size === 'lg' && '.modal-lg', size === 'xl' && '.modal-xl', scrollable && '.modal-dialog-scrollable', centered && '.modal-dialog-centered']);
  const contentClasses = getStyles(styles$r, ['.modal-content', scrollable && '.modal-dialog-scrollable .modal-content']);
  const contentTextClasses = getStyles(styles$r, ['.modal-content --text']);

  // If scrollable we use a ScrollView in ModalBody, so we can use a View here.
  const FlexView = scrollable ? View : ScrollView;
  const centeredStyle = centered && {
    justifyContent: 'center'
  };
  return /*#__PURE__*/React__default["default"].createElement(reactNative.Modal, {
    transparent: true,
    visible: visible,
    onRequestClose: handleToggle
  }, backdrop && /*#__PURE__*/React__default["default"].createElement(View, {
    style: backdropClasses
  }), /*#__PURE__*/React__default["default"].createElement(FlexView, _extends({}, elementProps, {
    ref: ref,
    style: [classes, scrollable && centeredStyle, style],
    textStyle: textStyle,
    contentContainerStyle: scrollable ? undefined : [{
      flexGrow: 1
    }, centeredStyle, contentContainerStyle]
  }), /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
    dialogRef: dialogRef,
    onClose: handleToggle,
    backdrop: backdrop
  }), /*#__PURE__*/React__default["default"].createElement(reactNative.SafeAreaView, {
    style: {
      flexShrink: 1
    }
  }, /*#__PURE__*/React__default["default"].createElement(View, {
    ref: dialogRef,
    style: [dialogClasses, dialogStyle],
    textStyle: dialogTextStyle
  }, /*#__PURE__*/React__default["default"].createElement(View, {
    style: [contentClasses, contentStyle],
    textStyle: [contentTextClasses, contentTextStyle]
  }, /*#__PURE__*/React__default["default"].createElement(ModalContext.Provider, {
    value: modal
  }, /*#__PURE__*/React__default["default"].createElement(overlays.OverlayProvider, null, children)))))));
});
Modal.displayName = 'Modal';
Modal.propTypes = propTypes$y;
Modal.Context = ModalContext;
Modal.Header = ModalHeader;
Modal.Title = ModalTitle;
Modal.Body = ModalBody;
Modal.Footer = ModalFooter;

const NavContext = /*#__PURE__*/React__default["default"].createContext();
NavContext.displayName = 'NavContext';

const _excluded$v = ["children", "active", "disabled", "style", "activeStyle", "textStyle", "activeTextStyle"];
var _templateObject$q, _templateObject2$k, _templateObject3$9, _templateObject4$7, _templateObject5$5, _templateObject6$4, _templateObject7$2, _templateObject8$2, _templateObject9$2, _templateObject10$2, _templateObject11$1, _templateObject12$1, _templateObject13$1, _templateObject14, _templateObject15, _templateObject16, _templateObject17, _templateObject18, _templateObject19, _templateObject20;
const propTypes$x = {
  children: PropTypes__default["default"].node.isRequired,
  active: PropTypes__default["default"].bool,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  activeStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  activeTextStyle: PropTypes__default["default"].any
};
const styles$q = StyleSheet.create(_objectSpread2(_objectSpread2({
  '.nav-link': css(_templateObject$q || (_templateObject$q = _taggedTemplateLiteral(["\n    // display: block;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center; // added for bootstrap-rn\n    padding: $nav-link-padding-y $nav-link-padding-x;\n    // @include transition($nav-link-transition);\n  "]))),
  '.nav-link --text': css(_templateObject2$k || (_templateObject2$k = _taggedTemplateLiteral(["\n    font-size: $nav-link-font-size;\n    font-weight: $nav-link-font-weight;\n    color: $nav-link-color;\n    text-decoration: none; // if($link-decoration == none, null, none);\n\n    &:hover {\n      color: $nav-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      color: $nav-link-hover-color;\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
  '.nav-link.disabled': css(_templateObject3$9 || (_templateObject3$9 = _taggedTemplateLiteral(["\n    @include platform(web) {\n      pointer-events: none;\n      cursor: default;\n    }\n  "]))),
  '.nav-link.disabled --text': css(_templateObject4$7 || (_templateObject4$7 = _taggedTemplateLiteral(["\n    color: $nav-link-disabled-color;\n  "]))),
  '.nav-tabs .nav-link': css(_templateObject5$5 || (_templateObject5$5 = _taggedTemplateLiteral(["\n    margin-bottom: -$nav-tabs-border-width;\n    background: transparent; // none;\n    // Use longform for border, so that the border color is applied correctly on Android.\n    border-width: $nav-tabs-border-width;\n    border-style: solid;\n    border-color: transparent transparent;\n    border-top-left-radius: $nav-tabs-border-radius;\n    border-top-right-radius: $nav-tabs-border-radius;\n\n    &:hover {\n      // Prevents active .nav-link tab overlapping focus outline of previous/next .nav-link\n      // isolation: isolate;\n      border-color: $nav-tabs-link-hover-border-color;\n    }\n    &:focus {\n      // Prevents active .nav-link tab overlapping focus outline of previous/next .nav-link\n      // isolation: isolate;\n      border-color: $nav-tabs-link-hover-border-color;\n    }\n  "]))),
  '.nav-tabs .nav-link.disabled': css(_templateObject6$4 || (_templateObject6$4 = _taggedTemplateLiteral(["\n    background-color: transparent;\n    border-color: transparent;\n  "]))),
  '.nav-tabs .nav-link.disabled --text': css(_templateObject7$2 || (_templateObject7$2 = _taggedTemplateLiteral(["\n    color: $nav-link-disabled-color;\n  "]))),
  '.nav-tabs .nav-link.active': css(_templateObject8$2 || (_templateObject8$2 = _taggedTemplateLiteral(["\n    background-color: $nav-tabs-link-active-bg;\n    border-color: $nav-tabs-link-active-border-color;\n\n    &:hover {\n      background-color: $nav-tabs-link-active-bg; // added for bootstrap-rn\n      border-color: $nav-tabs-link-active-border-color; // added for bootstrap-rn\n    }\n    &:focus {\n      background-color: $nav-tabs-link-active-bg; // added for bootstrap-rn\n      border-color: $nav-tabs-link-active-border-color; // added for bootstrap-rn\n    }\n  "]))),
  '.nav-tabs .nav-link.active --text': css(_templateObject9$2 || (_templateObject9$2 = _taggedTemplateLiteral(["\n    color: $nav-tabs-link-active-color;\n\n    &:hover {\n      color: $nav-tabs-link-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $nav-tabs-link-active-color; // added for bootstrap-rn\n    }\n  "]))),
  '.nav-pills .nav-link': css(_templateObject10$2 || (_templateObject10$2 = _taggedTemplateLiteral(["\n    background: transparent; // none;\n    border: 0;\n    border-radius: $nav-pills-border-radius;\n  "]))),
  '.nav-pills .nav-link.active': css(_templateObject11$1 || (_templateObject11$1 = _taggedTemplateLiteral(["\n    // @include gradient-bg($nav-pills-link-active-bg);\n    background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n\n    &:hover {\n      background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n    }\n    &:focus {\n      background-color: $nav-pills-link-active-bg; // added for bootstrap-rn\n    }\n  "]))),
  '.nav-pills .nav-link.active --text': css(_templateObject12$1 || (_templateObject12$1 = _taggedTemplateLiteral(["\n    color: $nav-pills-link-active-color;\n\n    &:hover {\n      color: $nav-pills-link-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $nav-pills-link-active-color; // added for bootstyl\n    }\n  "]))),
  // Navbar styles
  '.navbar-nav .nav-link': css(_templateObject13$1 || (_templateObject13$1 = _taggedTemplateLiteral(["\n    padding-right: 0;\n    padding-left: 0;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav .nav-link")]: css(_templateObject14 || (_templateObject14 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        padding-right: $navbar-nav-link-padding-x;\n        padding-left: $navbar-nav-link-padding-x;\n      }\n    "])), next(breakpoint))
}))), {}, {
  '.navbar-light .navbar-nav .nav-link --text': css(_templateObject15 || (_templateObject15 = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n\n    &:hover {\n      color: $navbar-light-hover-color;\n    }\n    &:focus {\n      color: $navbar-light-hover-color;\n    }\n  "]))),
  '.navbar-light .navbar-nav .nav-link.disabled --text': css(_templateObject16 || (_templateObject16 = _taggedTemplateLiteral(["\n    color: $navbar-light-disabled-color;\n  "]))),
  '.navbar-light .navbar-nav .nav-link.active --text': css(_templateObject17 || (_templateObject17 = _taggedTemplateLiteral(["\n    color: $navbar-light-active-color;\n\n    &:hover {\n      color: $navbar-light-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $navbar-light-active-color; // added for bootstrap-rn\n    }\n  "]))),
  '.navbar-dark .navbar-nav .nav-link --text': css(_templateObject18 || (_templateObject18 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n\n    &:hover {\n      color: $navbar-dark-hover-color;\n    }\n    &:focus {\n      color: $navbar-dark-hover-color;\n    }\n  "]))),
  '.navbar-dark .navbar-nav .nav-link.disabled --text': css(_templateObject19 || (_templateObject19 = _taggedTemplateLiteral(["\n    color: $navbar-dark-disabled-color;\n  "]))),
  '.navbar-dark .navbar-nav .nav-link.active --text': css(_templateObject20 || (_templateObject20 = _taggedTemplateLiteral(["\n    color: $navbar-dark-active-color;\n\n    &:hover {\n      color: $navbar-dark-active-color; // added for bootstrap-rn\n    }\n    &:focus {\n      color: $navbar-dark-active-color; // added for bootstrap-rn\n    }\n  "])))
}));
const NavLink = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useTabbable', props, ref);
  const {
      children,
      active,
      disabled,
      style,
      activeStyle,
      textStyle,
      activeTextStyle
    } = modifierProps,
    elementProps = _objectWithoutProperties(modifierProps, _excluded$v);
  const {
    variant
  } = useForcedContext(NavContext);
  const navbar = React.useContext(NavbarContext);
  const classes = getStyles(styles$q, ['.nav-link', disabled && '.nav-link.disabled', variant && ".nav-".concat(variant, " .nav-link"), variant === 'tabs' && disabled && '.nav-tabs .nav-link.disabled',
  // Navbar styles
  navbar && '.navbar-nav .nav-link', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav .nav-link"), navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link"), navbar && disabled && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link.disabled")]);
  const activeClasses = getStyles(styles$q, [variant && ".nav-".concat(variant, " .nav-link.active"),
  // Navbar styles
  navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link.active")]);
  const textClasses = getStyles(styles$q, ['.nav-link --text', disabled && '.nav-link.disabled --text', variant && ".nav-".concat(variant, " .nav-link --text"), variant === 'tabs' && disabled && '.nav-tabs .nav-link.disabled --text',
  // Navbar styles
  navbar && '.navbar-nav .nav-link --text', navbar && navbar.expand && ".navbar-expand".concat(infix(navbar.expand), " .navbar-nav .nav-link --text"), navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link --text"), navbar && disabled && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link.disabled --text")]);
  const activeTextClasses = getStyles(styles$q, [variant && ".nav-".concat(variant, " .nav-link.active --text"),
  // Navbar styles
  navbar && ".navbar-".concat(navbar.variant, " .navbar-nav .nav-link.active --text")]);
  return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends({}, elementProps, {
    ref: modifierRef,
    active: active,
    disabled: disabled,
    style: [...classes, style],
    activeStyle: [...activeClasses, activeStyle],
    textStyle: [...textClasses, textStyle],
    activeTextStyle: [...activeTextClasses, activeTextStyle]
  }), children);
});
NavLink.displayName = 'NavLink';
NavLink.propTypes = propTypes$x;

const TabContext = /*#__PURE__*/React.createContext();
TabContext.displayName = 'TabContext';

const _excluded$u = ["children", "variant", "style"];
var _templateObject$p, _templateObject2$j, _templateObject3$8, _templateObject4$6;
const propTypes$w = {
  children: PropTypes__default["default"].node.isRequired,
  variant: PropTypes__default["default"].oneOf(['tabs', 'pills']),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$p = StyleSheet.create(_objectSpread2({
  '.nav': css(_templateObject$p || (_templateObject$p = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    // flex-wrap: wrap; // bootstrap-rn: width will shrink on native with \"flex-direction: column;\"\n    padding-left: 0;\n    margin-bottom: 0;\n    // list-style: none;\n  "]))),
  '.nav-tabs': css(_templateObject2$j || (_templateObject2$j = _taggedTemplateLiteral(["\n    border-bottom-width: $nav-tabs-border-width;\n    border-style: solid;\n    border-color: $nav-tabs-border-color;\n  "]))),
  // Navbar styles
  '.navbar-nav': css(_templateObject3$8 || (_templateObject3$8 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column; // cannot use \"inherit\" to get the \".navbar\"s value\n    padding-left: 0;\n    margin-bottom: 0;\n    // list-style: none;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .navbar-nav")]: css(_templateObject4$6 || (_templateObject4$6 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-direction: row;\n      }\n    "])), next(breakpoint))
}))));
const getRole = (tabbable, navbar) => {
  if (tabbable) {
    return 'tablist';
  }
  if (reactNative.Platform.OS === 'web' && !navbar) {
    return 'navigation';
  }
  return null;
};
const Nav = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      variant,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$u);
  const navbar = React.useContext(NavbarContext);
  const tabbable = React.useContext(TabContext);
  const classes = getStyles(styles$p, [!navbar && '.nav', variant === 'tabs' && '.nav-tabs',
  // Navbar styles
  navbar && '.navbar-nav', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .navbar-nav")]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: getRole(tabbable, navbar),
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(NavContext.Provider, {
    value: {
      variant
    }
  }, children));
});
Nav.displayName = 'Nav';
Nav.propTypes = propTypes$w;
Nav.Context = NavContext;
Nav.Link = NavLink;

const _excluded$t = ["children", "style", "textStyle"];
var _templateObject$o, _templateObject2$i, _templateObject3$7;
const propTypes$v = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$o = StyleSheet.create({
  '.navbar-text': css(_templateObject$o || (_templateObject$o = _taggedTemplateLiteral(["\n    padding-top: $nav-link-padding-y;\n    padding-bottom: $nav-link-padding-y;\n  "]))),
  '.navbar-light .navbar-text --text': css(_templateObject2$i || (_templateObject2$i = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n  "]))),
  '.navbar-dark .navbar-text --text': css(_templateObject3$7 || (_templateObject3$7 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n  "])))
});
const NavbarText = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$t);
  const {
    variant
  } = useForcedContext(NavbarContext);
  const classes = getStyles(styles$o, ['.navbar-text']);
  const textClasses = getStyles(styles$o, [".navbar-".concat(variant, " .navbar-text --text")]);

  // composite component
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(Text, {
    style: [textClasses, textStyle]
  }, children));
});
NavbarText.displayName = 'NavbarText';
NavbarText.propTypes = propTypes$v;

const _excluded$s = ["children", "style", "textStyle"];
var _templateObject$n, _templateObject2$h, _templateObject3$6, _templateObject4$5;
const propTypes$u = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$n = StyleSheet.create({
  '.navbar-brand': css(_templateObject$n || (_templateObject$n = _taggedTemplateLiteral(["\n    padding-top: $navbar-brand-padding-y;\n    padding-bottom: $navbar-brand-padding-y;\n    margin-right: $navbar-brand-margin-end;\n  "]))),
  '.navbar-brand --text': css(_templateObject2$h || (_templateObject2$h = _taggedTemplateLiteral(["\n    font-size: $navbar-brand-font-size;\n    line-height: $navbar-brand-font-size * $line-height-base; // added for bootstrap-rn\n    text-decoration: none; // if($link-decoration == none, null, none);\n    // white-space: nowrap;\n\n    &:hover {\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n    &:focus {\n      text-decoration: none; // if($link-hover-decoration == underline, none, null);\n    }\n  "]))),
  '.navbar-light .navbar-brand --text': css(_templateObject3$6 || (_templateObject3$6 = _taggedTemplateLiteral(["\n    color: $navbar-light-brand-color;\n\n    &:hover {\n      color: $navbar-light-brand-hover-color;\n    }\n    &:focus {\n      color: $navbar-light-brand-hover-color;\n    }\n  "]))),
  '.navbar-dark .navbar-brand --text': css(_templateObject4$5 || (_templateObject4$5 = _taggedTemplateLiteral(["\n    color: $navbar-dark-brand-color;\n\n    &:hover {\n      color: $navbar-dark-brand-hover-color;\n    }\n    &:focus {\n      color: $navbar-dark-brand-hover-color;\n    }\n  "])))
});
const NavbarBrand = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$s);
  const {
    variant
  } = useForcedContext(NavbarContext);
  const classes = getStyles(styles$n, ['.navbar-brand']);
  const textClasses = getStyles(styles$n, ['.navbar-brand --text', ".navbar-".concat(variant, " .navbar-brand --text")]);
  return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
NavbarBrand.displayName = 'NavbarBrand';
NavbarBrand.propTypes = propTypes$u;

const _excluded$r = ["children", "style"];
var _templateObject$m, _templateObject2$g;
const propTypes$t = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$m = StyleSheet.create(_objectSpread2({
  '.navbar-collapse': css(_templateObject$m || (_templateObject$m = _taggedTemplateLiteral(["\n    flex-basis: 100%;\n    flex-grow: 1;\n    // For always expanded or extra full navbars, ensure content aligns itself\n    // properly vertically. Can be easily overridden with flex utilities.\n    // align-items: center;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .navbar-collapse")]: css(_templateObject2$g || (_templateObject2$g = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-direction: row; // added for bootstrap-rn\n        display: flex;\n        flex-basis: auto;\n        align-items: center; // added for bootstrap-rn\n      }\n    "])), next(breakpoint))
}))));
const NavbarCollapse = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$r);
  const {
    expand,
    expanded
  } = useForcedContext(NavbarContext);
  const media = useMedia();
  const classes = getStyles(styles$m, ['.navbar-collapse', expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand), " .navbar-collapse")]);
  const show = expanded || expand && (expand === true || media.up(expand));
  if (!show) {
    return null;
  }
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
NavbarCollapse.displayName = 'NavbarCollapse';
NavbarCollapse.propTypes = propTypes$t;

const _excluded$q = ["onPress"];
function useToggleNavbar(props) {
  const context = useForcedContext(NavbarContext);
  const {
      onPress: handlePress
    } = props,
    restProps = _objectWithoutProperties(props, _excluded$q);
  return _objectSpread2(_objectSpread2({}, restProps), {}, {
    nativeID: context.identifier,
    onPress: event => {
      if (handlePress) handlePress(event);
      context.setExpanded(value => !value);
    },
    accessibilitControls: context.identifier,
    accessibilityExpanded: context.expanded,
    accessibilityLabel: 'Toggle navigation'
  });
}

const _excluded$p = ["style", "textStyle", "iconStyle"];
var _templateObject$l, _templateObject2$f, _templateObject3$5, _templateObject4$4, _templateObject5$4, _templateObject6$3, _templateObject7$1, _templateObject8$1, _templateObject9$1, _templateObject10$1;
const propTypes$s = {
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  iconStyle: PropTypes__default["default"].any
};
const styles$l = StyleSheet.create(_objectSpread2(_objectSpread2({
  '.navbar-toggler': css(_templateObject$l || (_templateObject$l = _taggedTemplateLiteral(["\n    padding: $navbar-toggler-padding-y $navbar-toggler-padding-x;\n    background-color: transparent; // remove default button style\n    border: $border-width solid transparent; // remove default button style\n    border-radius: $navbar-toggler-border-radius;\n    // @include transition($navbar-toggler-transition);\n\n    &:focus {\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n      }\n      // box-shadow: 0 0 0 $navbar-toggler-focus-width;\n    }\n  "]))),
  '.navbar-toggler --text': css(_templateObject2$f || (_templateObject2$f = _taggedTemplateLiteral(["\n    font-size: $navbar-toggler-font-size;\n    line-height: $navbar-toggler-font-size * $line-height-base;\n\n    &:hover {\n      text-decoration: none;\n    }\n\n    &:focus {\n      text-decoration: none;\n    }\n  "]))),
  '.navbar-toggler-icon': css(_templateObject3$5 || (_templateObject3$5 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $navbar-toggler-font-size * 1.5; // 1.5em;\n    height: $navbar-toggler-font-size * 1.5; // 1.5em;\n    // vertical-align: middle;\n    background-repeat: no-repeat;\n    background-position: center;\n    background-size: 100%;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .navbar-toggler")]: css(_templateObject4$4 || (_templateObject4$4 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: none;\n      }\n    "])), next(breakpoint))
}))), {}, {
  '.navbar-light .navbar-toggler': css(_templateObject5$4 || (_templateObject5$4 = _taggedTemplateLiteral(["\n    border-color: $navbar-light-toggler-border-color;\n  "]))),
  '.navbar-light .navbar-toggler --text': css(_templateObject6$3 || (_templateObject6$3 = _taggedTemplateLiteral(["\n    color: $navbar-light-color;\n  "]))),
  '.navbar-light .navbar-toggler-icon': css(_templateObject7$1 || (_templateObject7$1 = _taggedTemplateLiteral(["\n    background-image: ", ";\n  "])), t => escapeSvg(t['navbar-light-toggler-icon-bg'])),
  '.navbar-dark .navbar-toggler': css(_templateObject8$1 || (_templateObject8$1 = _taggedTemplateLiteral(["\n    border-color: $navbar-dark-toggler-border-color;\n  "]))),
  '.navbar-dark .navbar-toggler --text': css(_templateObject9$1 || (_templateObject9$1 = _taggedTemplateLiteral(["\n    color: $navbar-dark-color;\n  "]))),
  '.navbar-dark .navbar-toggler-icon': css(_templateObject10$1 || (_templateObject10$1 = _taggedTemplateLiteral(["\n    background-image: ", ";\n  "])), t => escapeSvg(t['navbar-dark-toggler-icon-bg']))
}));
const NavbarToggler = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      style,
      textStyle,
      iconStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$p);
  const media = useMedia();
  const {
    variant,
    expand
  } = useForcedContext(NavbarContext);
  const classes = getStyles(styles$l, ['.navbar-toggler', ".navbar-".concat(variant, " .navbar-toggler"), expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand), " .navbar-toggler")]);
  const textClasses = getStyles(styles$l, ['.navbar-toggler --text', ".navbar-".concat(variant, " .navbar-toggler --text")]);
  const iconClasses = getStyles(styles$l, ['.navbar-toggler-icon', ".navbar-".concat(variant, " .navbar-toggler-icon")]);
  const resolveIconStyle = useStyle([iconClasses, iconStyle]);
  const background = useBackground(resolveIconStyle({
    media
  }));
  return /*#__PURE__*/React__default["default"].createElement(Pressable, _extends({}, elementProps, {
    ref: ref,
    toggle: useToggleNavbar,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/React__default["default"].createElement(View, {
    style: background.style
  }, background.element));
});
NavbarToggler.displayName = 'NavbarToggler';
NavbarToggler.propTypes = propTypes$s;

function useNavbar(variant, defaultExpanded, controlledExpanded, onToggle, expand) {
  const identifier = useIdentifier('navbar');
  const [expanded, setExpanded] = useControlledState(defaultExpanded, controlledExpanded, onToggle);
  return React.useMemo(() => ({
    identifier,
    variant,
    expanded,
    setExpanded,
    expand
  }), [variant, expanded, expand]);
}

const _excluded$o = ["onPress"];
function useDismissNavbar(props) {
  const context = useForcedContext(NavbarContext);
  const {
      onPress: handlePress
    } = props,
    restProps = _objectWithoutProperties(props, _excluded$o);
  return _objectSpread2(_objectSpread2({}, restProps), {}, {
    onPress: event => {
      if (handlePress) handlePress(event);
      context.setExpanded(false);
    },
    accessibilityLabel: 'Close'
  });
}

const _excluded$n = ["children", "variant", "defaultExpanded", "expanded", "onToggle", "expand", "style"];
var _templateObject$k, _templateObject2$e;
const propTypes$r = {
  children: PropTypes__default["default"].node.isRequired,
  variant: PropTypes__default["default"].oneOf(['light', 'dark']),
  defaultExpanded: PropTypes__default["default"].bool,
  expanded: PropTypes__default["default"].bool,
  onToggle: PropTypes__default["default"].func,
  expand: PropTypes__default["default"].oneOf([true, 'sm', 'md', 'lg', 'xl', 'xxl']),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$k = StyleSheet.create(_objectSpread2({
  '.navbar': css(_templateObject$k || (_templateObject$k = _taggedTemplateLiteral(["\n    position: relative;\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap; // allow us to do the line break for collapsing content\n    align-items: center;\n    justify-content: space-between; // space out brand from logo\n    padding-top: $navbar-padding-y;\n    padding-right: $navbar-padding-x; // default: null\n    padding-bottom: $navbar-padding-y;\n    padding-left: $navbar-padding-x; // default: null\n    // @include gradient-bg();\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)))]: css(_templateObject2$e || (_templateObject2$e = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        flex-wrap: nowrap;\n        justify-content: flex-start;\n      }\n    "])), next(breakpoint))
}))));
const Navbar = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      variant = 'light',
      defaultExpanded = false,
      expanded,
      onToggle,
      expand,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$n);
  const navbar = useNavbar(variant, defaultExpanded, expanded, onToggle, expand);
  const classes = getStyles(styles$k, ['.navbar', expand && ".navbar-expand".concat(expand === true ? '' : "-".concat(expand))]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(NavbarContext.Provider, {
    value: navbar
  }, children));
});
Navbar.displayName = 'Navbar';
Navbar.propTypes = propTypes$r;
Navbar.Brand = NavbarBrand;
Navbar.Text = NavbarText;
Navbar.Collapse = NavbarCollapse;
Navbar.Toggler = NavbarToggler;
Navbar.useDismiss = useDismissNavbar;
Navbar.useToggle = useToggleNavbar;

function useOffcanvas() {
  return React.useMemo(() => ({}), []);
}

const _excluded$m = ["children", "style"];
var _templateObject$j, _templateObject2$d;
const propTypes$q = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$j = StyleSheet.create(_objectSpread2({
  '.offcanvas-header': css(_templateObject$j || (_templateObject$j = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center;\n    justify-content: space-between;\n    padding: $offcanvas-padding-y $offcanvas-padding-x;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas-header")]: css(_templateObject2$d || (_templateObject2$d = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: none;\n      }\n    "])), next(breakpoint))
}))));
const OffcanvasHeader = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$m);
  const navbar = React.useContext(NavbarContext);
  const classes = getStyles(styles$j, ['.offcanvas-header', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas-header")]);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
OffcanvasHeader.displayName = 'OffcanvasHeader';
OffcanvasHeader.propTypes = propTypes$q;

const _excluded$l = ["children", "style"];
var _templateObject$i;
const propTypes$p = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$i = StyleSheet.create({
  '.offcanvas-title': css(_templateObject$i || (_templateObject$i = _taggedTemplateLiteral(["\n    margin-bottom: 0;\n    line-height: $font-size-base * $offcanvas-title-line-height;\n  "])))
});
const OffcanvasTitle = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$l);
  const classes = getStyles(styles$i, ['.offcanvas-title']);
  return /*#__PURE__*/React__default["default"].createElement(Heading$1, _extends({
    size: 5
  }, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
OffcanvasTitle.displayName = 'OffcanvasTitle';
OffcanvasTitle.propTypes = propTypes$p;

const _excluded$k = ["children", "style", "contentContainerStyle"];
var _templateObject$h, _templateObject2$c;
const propTypes$o = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  contentContainerStyle: PropTypes__default["default"].any
};
const styles$h = StyleSheet.create(_objectSpread2({
  '.offcanvas-body': css(_templateObject$h || (_templateObject$h = _taggedTemplateLiteral(["\n    // flex-grow: 1;\n    padding: $offcanvas-padding-y $offcanvas-padding-x;\n    // overflow-y: auto;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas-body")]: css(_templateObject2$c || (_templateObject2$c = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        display: flex;\n        flex-grow: 0;\n        padding: 0;\n        // overflow-y: visible;\n      }\n    "])), next(breakpoint))
}))));
const OffcanvasBody = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      contentContainerStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$k);
  const navbar = React.useContext(NavbarContext);
  const contentContainerClasses = getStyles(styles$h, ['.offcanvas-body', navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas-body")]);
  return /*#__PURE__*/React__default["default"].createElement(ScrollView, _extends({}, elementProps, {
    ref: ref,
    style: style,
    contentContainerStyle: [contentContainerClasses, contentContainerStyle]
  }), children);
});
OffcanvasBody.displayName = 'OffcanvasBody';
OffcanvasBody.propTypes = propTypes$o;

const _excluded$j = ["children", "visible", "placement", "backdrop", "scroll", "onToggle", "style", "dialogStyle", "textStyle", "dialogTextStyle"];
var _templateObject$g, _templateObject2$b, _templateObject3$4, _templateObject4$3, _templateObject5$3, _templateObject6$2, _templateObject7, _templateObject8, _templateObject9, _templateObject10, _templateObject11, _templateObject12, _templateObject13;
const PLACEMENTS = ['top', 'bottom', 'start', 'end']; // , 'auto'

const propTypes$n = {
  children: PropTypes__default["default"].node.isRequired,
  visible: PropTypes__default["default"].bool,
  placement: PropTypes__default["default"].oneOf(PLACEMENTS),
  backdrop: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].oneOf(['static'])]),
  // Currently only supported on web.
  scroll: PropTypes__default["default"].bool,
  onToggle: PropTypes__default["default"].func,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  dialogStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  dialogTextStyle: PropTypes__default["default"].any
};
const styles$g = StyleSheet.create(_objectSpread2({
  '.offcanvas': css(_templateObject$g || (_templateObject$g = _taggedTemplateLiteral(["\n    position: absolute; // fixed;\n    // bottom: 0;\n    z-index: $zindex-offcanvas;\n    display: flex;\n    flex-direction: column;\n    max-width: 100%;\n    // visibility: hidden;\n    background-color: $offcanvas-bg-color;\n    // background-clip: padding-box;\n    @include platform(web) {\n      outline-width: 0; // outline: 0;\n    }\n    // @include box-shadow($offcanvas-box-shadow);\n    // @include transition(transform $offcanvas-transition-duration ease-in-out);\n  "]))),
  '.offcanvas --text': css(_templateObject2$b || (_templateObject2$b = _taggedTemplateLiteral(["\n    color: $offcanvas-color;\n  "]))),
  '.offcanvas-backdrop': css(_templateObject3$4 || (_templateObject3$4 = _taggedTemplateLiteral(["\n    position: absolute;\n    top: 0;\n    left: 0;\n    z-index: $zindex-offcanvas-backdrop;\n    width: 100%;\n    height: 100%;\n    background-color: $offcanvas-backdrop-bg;\n    opacity: $offcanvas-backdrop-opacity;\n  "]))),
  '.offcanvas-start': css(_templateObject4$3 || (_templateObject4$3 = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0; // added for bootstrap-rn\n    left: 0;\n    // width: $offcanvas-horizontal-width;\n    border-right-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateX(-100%);\n  "]))),
  '.offcanvas-end': css(_templateObject5$3 || (_templateObject5$3 = _taggedTemplateLiteral(["\n    top: 0;\n    bottom: 0; // added for bootstrap-rn\n    right: 0;\n    // width: $offcanvas-horizontal-width;\n    border-left-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateX(100%);\n  "]))),
  '.offcanvas-top': css(_templateObject6$2 || (_templateObject6$2 = _taggedTemplateLiteral(["\n    top: 0;\n    right: 0;\n    left: 0;\n    // height: $offcanvas-vertical-height;\n    max-height: 100%;\n    border-bottom-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateY(-100%);\n  "]))),
  '.offcanvas-bottom': css(_templateObject7 || (_templateObject7 = _taggedTemplateLiteral(["\n    bottom: 0; // added for bootstrap-rn\n    right: 0;\n    left: 0;\n    // height: $offcanvas-vertical-height;\n    max-height: 100%;\n    width: 100%;\n    border-top-width: $offcanvas-border-width;\n    border-style: solid;\n    border-color: $offcanvas-border-color;\n    // transform: translateY(100%);\n  "]))),
  // The following .offcanvas-dialog classes are added for bootstrap-rn,
  // because otherwise the text would exceed a width of 100% on native
  // and also additional width by SafeAreaView would not be applied.
  '.offcanvas-dialog': css(_templateObject8 || (_templateObject8 = _taggedTemplateLiteral(["\n    max-width: 100%;\n    max-height: 100%;\n  "]))),
  '.offcanvas-dialog-start': css(_templateObject9 || (_templateObject9 = _taggedTemplateLiteral(["\n    width: $offcanvas-horizontal-width;\n  "]))),
  '.offcanvas-dialog-end': css(_templateObject10 || (_templateObject10 = _taggedTemplateLiteral(["\n    width: $offcanvas-horizontal-width;\n  "]))),
  '.offcanvas-dialog-top': css(_templateObject11 || (_templateObject11 = _taggedTemplateLiteral(["\n    height: $offcanvas-vertical-height;\n  "]))),
  '.offcanvas-dialog-bottom': css(_templateObject12 || (_templateObject12 = _taggedTemplateLiteral(["\n    height: $offcanvas-vertical-height;\n  "])))
}, each(GRID_BREAKPOINTS, breakpoint => ({
  [".navbar-expand".concat(infix(next(breakpoint)), " .offcanvas")]: css(_templateObject13 || (_templateObject13 = _taggedTemplateLiteral(["\n      @include media-breakpoint-up(", ") {\n        position: relative; // inherit;\n        bottom: 0;\n        // z-index: auto;\n        flex-grow: 1;\n        // visibility: visible !important; // stylelint-disable-line declaration-no-important\n        background-color: transparent;\n        border-right-width: 0;\n        border-left-width: 0;\n        // @include box-shadow(none);\n        // @include transition(none);\n        // transform: none;\n      }\n    "])), next(breakpoint))
}))));
const Offcanvas = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      visible,
      placement = 'top',
      backdrop = true,
      scroll = false,
      onToggle: handleToggle,
      style,
      dialogStyle,
      textStyle,
      dialogTextStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$j);
  const media = useMedia();
  const navbar = React.useContext(NavbarContext);
  const offcanvasRef = React.useRef();
  const offcanvas = useOffcanvas();
  useScrollbarEffects({
    keepBodyScroll: scroll,
    visible
  });
  const backdropClasses = getStyles(styles$g, ['.offcanvas-backdrop']);
  const classes = getStyles(styles$g, ['.offcanvas', ".offcanvas-".concat(placement), navbar && navbar.expand && ".navbar-expand".concat(navbar.expand === true ? '' : "-".concat(navbar.expand), " .offcanvas")]);
  const dialogClasses = getStyles(styles$g, ['.offcanvas-dialog', ".offcanvas-dialog-".concat(placement)]);
  const textClasses = getStyles(styles$g, ['.offcanvas-content --text']);

  // Render children without modal for navbar.
  if (navbar && navbar.expand && (navbar.expand === true || media.up(navbar.expand))) {
    return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
      ref: ref,
      style: [classes, style],
      textStyle: [textClasses, textStyle]
    }), children);
  }
  return /*#__PURE__*/React__default["default"].createElement(reactNative.Modal, {
    transparent: true,
    visible: navbar ? navbar.expanded : visible,
    onRequestClose: handleToggle
  }, placement !== 'bottom' && /*#__PURE__*/React__default["default"].createElement(reactNative.SafeAreaView, {
    style: {
      flexGrow: 0
    }
  }), /*#__PURE__*/React__default["default"].createElement(reactNative.SafeAreaView, {
    style: {
      flexGrow: 1
    }
  }, backdrop && /*#__PURE__*/React__default["default"].createElement(View, {
    style: backdropClasses
  }, /*#__PURE__*/React__default["default"].createElement(BackdropHandler, {
    dialogRef: offcanvasRef,
    onClose: handleToggle,
    backdrop: backdrop
  })), /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: concatRefs(offcanvasRef, ref),
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/React__default["default"].createElement(View, {
    style: [dialogClasses, dialogStyle],
    textStyle: dialogTextStyle
  }, /*#__PURE__*/React__default["default"].createElement(OffcanvasContext.Provider, {
    value: offcanvas
  }, /*#__PURE__*/React__default["default"].createElement(overlays.OverlayProvider, null, children))))));
});
Offcanvas.displayName = 'Offcanvas';
Offcanvas.propTypes = propTypes$n;
Offcanvas.Context = OffcanvasContext;
Offcanvas.Header = OffcanvasHeader;
Offcanvas.Title = OffcanvasTitle;
Offcanvas.Body = OffcanvasBody;

const PickerWebContext = /*#__PURE__*/React__default["default"].createContext();
PickerWebContext.displayName = 'PickerWebContext';

const _excluded$i = ["children", "selectedValue", "onValueChange", "onFocus", "onBlur", "placeholder", "placeholderTextColor", "disabled", "style"];
const propTypes$m = {
  children: PropTypes__default["default"].node.isRequired,
  selectedValue: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].number, PropTypes__default["default"].string, PropTypes__default["default"].object]),
  onValueChange: PropTypes__default["default"].func,
  onFocus: PropTypes__default["default"].func,
  onBlur: PropTypes__default["default"].func,
  placeholder: PropTypes__default["default"].string,
  placeholderTextColor: PropTypes__default["default"].string,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const PLACEHOLDER = '__PLACEHOLDER__';
const getOptionStyle = (style, showPlaceholder) => {
  if (!showPlaceholder) {
    return null;
  }
  const flattenedStyle = reactNative.StyleSheet.flatten(style);
  return flattenedStyle.color;
};
const PickerWeb = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      selectedValue,
      onValueChange = () => {},
      onFocus = () => {},
      onBlur = () => {},
      placeholder,
      placeholderTextColor,
      disabled,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$i);
  const background = useBackground(style);
  const showPlaceholder = selectedValue === undefined || selectedValue === null;
  return /*#__PURE__*/React__default["default"].createElement(reactNative.Picker, _extends({}, elementProps, {
    ref: ref,
    selectedValue: showPlaceholder ? PLACEHOLDER : selectedValue,
    onValueChange: onValueChange,
    onFocus: onFocus,
    onBlur: onBlur,
    disabled: disabled,
    style: [background.style, showPlaceholder && {
      color: placeholderTextColor
    }]
  }), /*#__PURE__*/React__default["default"].createElement("option", {
    value: PLACEHOLDER,
    disabled: true,
    hidden: true
  }, placeholder), /*#__PURE__*/React__default["default"].createElement(PickerWebContext.Provider, {
    value: {
      optionColor: getOptionStyle(background.style, showPlaceholder)
    }
  }, children));
});
PickerWeb.propTypes = propTypes$m;

const PickerNativeContext = /*#__PURE__*/React__default["default"].createContext();
PickerNativeContext.displayName = 'PickerNativeContext';

const _excluded$h = ["children", "selectedValue", "onValueChange", "onFocus", "onBlur", "placeholder", "placeholderTextColor", "disabled", "MenuComponent", "style"];
var _templateObject$f;
const propTypes$l = {
  children: PropTypes__default["default"].node.isRequired,
  selectedValue: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].number, PropTypes__default["default"].string, PropTypes__default["default"].object]),
  onValueChange: PropTypes__default["default"].func,
  onFocus: PropTypes__default["default"].func,
  onBlur: PropTypes__default["default"].func,
  placeholder: PropTypes__default["default"].string,
  placeholderTextColor: PropTypes__default["default"].string,
  disabled: PropTypes__default["default"].bool,
  MenuComponent: PropTypes__default["default"].elementType,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$f = StyleSheet.create({
  menu: css(_templateObject$f || (_templateObject$f = _taggedTemplateLiteral(["\n    align-items: center;\n  "])))
});

// Ref: https://reactnative.dev/docs/text-style-props
const textStyleKeys = ['color', 'fontFamily', 'fontSize', 'fontStyle', 'fontWeight', 'includeFontPaddingAndroid', 'fontVariant', 'letterSpacing', 'lineHeight', 'textAlign', 'textAlignVerticalAndroid', 'textDecorationColoriOS', 'textDecorationLine', 'textDecorationStyleiOS', 'textShadowColor', 'textShadowOffset', 'textShadowRadius', 'textTransform', 'writingDirection'];
const extractTextStyles = style => {
  const textStyles = {};
  Object.entries(style).forEach(_ref => {
    let [key, value] = _ref;
    if (textStyleKeys.includes(key)) {
      textStyles[key] = value;
    }
  });
  return textStyles;
};
const getText = _ref2 => {
  let {
    children,
    selectedValue
  } = _ref2;
  const items = React__default["default"].Children.map(children, child => ({
    label: child.props.label,
    value: child.props.value
  }));
  const selectedItem = items.find(item => item.value === selectedValue);
  return selectedItem === null || selectedItem === void 0 ? void 0 : selectedItem.label;
};

/* eslint-disable react/prop-types */
const DefaultMenuComponent = _ref3 => {
  let {
    children,
    selectedValue,
    onValueChange: handleValueChange,
    onClose: handleClose
  } = _ref3;
  return /*#__PURE__*/React__default["default"].createElement(Offcanvas, {
    placement: "bottom",
    visible: true,
    onToggle: handleClose
  }, /*#__PURE__*/React__default["default"].createElement(Offcanvas.Body, {
    contentContainerStyle: styles$f.menu
  }, /*#__PURE__*/React__default["default"].createElement(PickerNativeContext.Provider, {
    value: {
      selectedValue,
      handleValueChange
    }
  }, children)));
};
/* eslint-enable */

const PickerNative = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      selectedValue,
      onValueChange = () => {},
      onFocus = () => {},
      onBlur = () => {},
      placeholder,
      placeholderTextColor,
      disabled = false,
      MenuComponent = DefaultMenuComponent,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$h);
  const background = useBackground(style);
  const [visible, setVisible] = React.useState(false);
  const textStyle = extractTextStyles(background.style);
  const showPlaceholder = selectedValue === undefined || selectedValue === null;
  const handleValueChange = nextValue => {
    onValueChange(nextValue);
    setVisible(false);
  };
  const handleClose = () => {
    setVisible(false);
  };
  return /*#__PURE__*/React__default["default"].createElement(React__default["default"].Fragment, null, /*#__PURE__*/React__default["default"].createElement(Pressable, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: "combobox",
    onPress: () => {
      setVisible(true);
    },
    onFocus: onFocus,
    onBlur: onBlur,
    disabled: disabled,
    style: background.style
  }), background.element, /*#__PURE__*/React__default["default"].createElement(Text, {
    numberOfLines: 1,
    style: [textStyle, showPlaceholder && {
      color: placeholderTextColor
    }]
  }, showPlaceholder ? placeholder || /*#__PURE__*/React__default["default"].createElement(Text, null, "\xA0") : getText({
    children,
    selectedValue
  }))), visible && /*#__PURE__*/React__default["default"].createElement(MenuComponent, {
    selectedValue: selectedValue,
    onValueChange: handleValueChange,
    onClose: handleClose
  }, children));
});
PickerNative.propTypes = propTypes$l;

const PickerContext = /*#__PURE__*/React__default["default"].createContext();
PickerContext.displayName = 'PickerContext';

const propTypes$k = {
  label: PropTypes__default["default"].string.isRequired,
  value: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].number, PropTypes__default["default"].string, PropTypes__default["default"].object]),
  disabled: PropTypes__default["default"].bool
};
const PickerWebItem = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
    label,
    value,
    disabled = false
  } = props;
  const {
    optionColor
  } = useForcedContext(PickerWebContext);
  return /*#__PURE__*/React__default["default"].createElement(reactNative.Picker.Item, {
    ref: ref,
    label: label,
    value: value,
    disabled: disabled,
    color: optionColor
  });
});
PickerWebItem.displayName = 'PickerWebItem';
PickerWebItem.propTypes = propTypes$k;

var _templateObject$e, _templateObject2$a;
const propTypes$j = {
  label: PropTypes__default["default"].string.isRequired,
  value: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].number, PropTypes__default["default"].string, PropTypes__default["default"].object]),
  disabled: PropTypes__default["default"].bool
};
const styles$e = StyleSheet.create({
  item: css(_templateObject$e || (_templateObject$e = _taggedTemplateLiteral(["\n    margin: 0.25rem 1rem;\n    padding: 0.25rem;\n  "]))),
  itemDisabled: css(_templateObject2$a || (_templateObject2$a = _taggedTemplateLiteral([""])))
});
const PickerNativeItem = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
    label,
    value,
    disabled = false
  } = props;
  const {
    selectedValue,
    handleValueChange
  } = useForcedContext(PickerNativeContext);
  const media = useMedia();
  const classes = getStyles(styles$e, ['item', disabled && 'itemDisabled']);
  const resolveStyle = useStyle(classes);
  const selected = value === selectedValue;
  return /*#__PURE__*/React__default["default"].createElement(Pressable, {
    ref: ref,
    onPress: () => {
      handleValueChange(value);
    },
    accessibilitySelected: selected,
    disabled: disabled,
    style: resolveStyle({
      media
    })
  }, /*#__PURE__*/React__default["default"].createElement(Text, {
    styleName: selected && 'text-primary'
  }, label));
});
PickerNativeItem.displayName = 'PickerNativeItem';
PickerNativeItem.propTypes = propTypes$j;

const propTypes$i = {
  label: PropTypes__default["default"].string.isRequired,
  value: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].number, PropTypes__default["default"].string, PropTypes__default["default"].object]),
  disabled: PropTypes__default["default"].bool
};
const PickerItem = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
    label,
    value,
    disabled = false
  } = props;
  const {
    useNativeComponent
  } = useForcedContext(PickerContext);
  const BasePickerItem = reactNative.Platform.OS === 'web' && !useNativeComponent ? PickerWebItem : PickerNativeItem;
  return /*#__PURE__*/React__default["default"].createElement(BasePickerItem, {
    ref: ref,
    label: label,
    value: value,
    disabled: disabled
  });
});
PickerItem.displayName = 'PickerItem';
PickerItem.propTypes = propTypes$i;

const _excluded$g = ["children", "onFocus", "onBlur", "placeholderTextColor", "size", "disabled", "valid", "invalid", "useNativeComponent", "autoFocus", "style", "styleName"];
var _templateObject$d, _templateObject2$9, _templateObject3$3, _templateObject4$2, _templateObject5$2, _templateObject6$1;

/* eslint-disable react/no-unused-prop-types */
const propTypes$h = {
  children: PropTypes__default["default"].node.isRequired,
  onFocus: PropTypes__default["default"].func,
  onBlur: PropTypes__default["default"].func,
  placeholderTextColor: PropTypes__default["default"].string,
  size: PropTypes__default["default"].oneOf(['sm', 'lg']),
  disabled: PropTypes__default["default"].bool,
  valid: PropTypes__default["default"].bool,
  invalid: PropTypes__default["default"].bool,
  useNativeComponent: PropTypes__default["default"].bool,
  autoFocus: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  styleName: PropTypes__default["default"].any
};
/* eslint-enable */

const styles$d = StyleSheet.create(_objectSpread2({
  select: css(_templateObject$d || (_templateObject$d = _taggedTemplateLiteral(["\n    opacity: 1;\n  "]))),
  '.form-select': css(_templateObject2$9 || (_templateObject2$9 = _taggedTemplateLiteral(["\n    // display: block;\n    width: 100%;\n    padding: $form-select-padding-y $form-select-indicator-padding\n      $form-select-padding-y $form-select-padding-x;\n    /* @include platform(web) {\n      // See https://github.com/twbs/bootstrap/issues/32636\n      -moz-padding-start: subtract($form-select-padding-x, 3px);\n    } */\n    font-family: $form-select-font-family;\n    font-size: $form-select-font-size;\n    font-weight: $form-select-font-weight;\n    line-height: $form-select-font-size * $form-select-line-height;\n    color: $form-select-color;\n    background-color: $form-select-bg;\n    background-image: ", ";\n    background-repeat: no-repeat;\n    background-position: $form-select-bg-position;\n    background-size: $form-select-bg-size;\n    border: $form-select-border-width solid $form-select-border-color;\n    border-radius: $form-select-border-radius;\n    // @include box-shadow($form-select-box-shadow);\n    // @include transition($form-select-transition);\n    @include platform(web) {\n      appearance: none;\n    }\n\n    &:focus {\n      border-color: $form-select-focus-border-color;\n      @include platform(web) {\n        outline-width: 0; // outline: 0;\n        // @if $enable-shadows {\n        //   @include box-shadow(\n        //     $form-select-box-shadow,\n        //     $form-select-focus-box-shadow\n        //   );\n        // } @else {\n        //   // Avoid using mixin so we can pass custom focus shadow properly\n        box-shadow: $form-select-focus-box-shadow;\n        // }\n      }\n    }\n  "])), t => escapeSvg(t['form-select-indicator'])),
  '.form-select.disabled': css(_templateObject3$3 || (_templateObject3$3 = _taggedTemplateLiteral(["\n    color: $form-select-disabled-color;\n    background-color: $form-select-disabled-bg;\n    border-color: $form-select-disabled-border-color;\n  "]))),
  '.form-select-sm': css(_templateObject4$2 || (_templateObject4$2 = _taggedTemplateLiteral(["\n    padding-top: $form-select-padding-y-sm;\n    padding-bottom: $form-select-padding-y-sm;\n    padding-left: $form-select-padding-x-sm;\n    font-size: $form-select-font-size-sm;\n    border-radius: $form-select-border-radius-sm;\n  "]))),
  '.form-select-lg': css(_templateObject5$2 || (_templateObject5$2 = _taggedTemplateLiteral(["\n    padding-top: $form-select-padding-y-lg;\n    padding-bottom: $form-select-padding-y-lg;\n    padding-left: $form-select-padding-x-lg;\n    font-size: $form-select-font-size-lg;\n    border-radius: $form-select-border-radius-lg;\n  "])))
}, each(FORM_VALIDATION_STATES, (state, data) => ({
  [".form-select:".concat(state)]: css(_templateObject6$1 || (_templateObject6$1 = _taggedTemplateLiteral(["\n      border-color: ", ";\n\n      &:focus {\n        border-color: ", ";\n        @include platform(web) {\n          box-shadow: 0 0 $input-btn-focus-blur $input-focus-width\n            rgba(", ", $input-btn-focus-color-opacity);\n        }\n      }\n    "])), t => data(t).color, t => data(t).color, t => data(t).color)
}))));
const Picker = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const [modifierProps, modifierRef] = useModifier('useFormField', props, ref);
  const {
      children,
      onFocus = () => {},
      onBlur = () => {},
      placeholderTextColor = StyleSheet.value('input-placeholder-color'),
      size,
      disabled = false,
      valid = false,
      invalid = false,
      useNativeComponent = false,
      autoFocus = false,
      style,
      styleName
    } = modifierProps,
    elementProps = _objectWithoutProperties(modifierProps, _excluded$g);
  const media = useMedia();
  const [focused, setFocused] = React.useState(autoFocus);
  const classes = getStyles(styles$d, ['select',
  // reboot
  '.form-select', disabled && '.form-select.disabled', size === 'sm' && '.form-select-sm', size === 'lg' && '.form-select-lg', valid && '.form-select:valid', invalid && '.form-select:invalid']);
  const resolveStyle = useStyle([classes, style], styleName);
  const BasePicker = reactNative.Platform.OS === 'web' && !useNativeComponent ? PickerWeb : PickerNative;
  return /*#__PURE__*/React__default["default"].createElement(PickerContext.Provider, {
    value: {
      useNativeComponent
    }
  }, /*#__PURE__*/React__default["default"].createElement(BasePicker, _extends({}, elementProps, {
    ref: modifierRef,
    placeholderTextColor: placeholderTextColor,
    onFocus: event => {
      setFocused(true);
      onFocus(event);
    },
    onBlur: event => {
      setFocused(false);
      onBlur(event);
    },
    disabled: disabled,
    autoFocus: autoFocus,
    style: resolveStyle({
      media,
      interaction: {
        focus: focused,
        focusVisible: focused
      }
    })
  }), children));
});
Picker.displayName = 'Picker';
Picker.propTypes = propTypes$h;
Picker.Item = PickerItem;

const _excluded$f = ["children", "style"];
var _templateObject$c;
const propTypes$g = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$c = StyleSheet.create({
  '.placeholders': css(_templateObject$c || (_templateObject$c = _taggedTemplateLiteral([""])))
});
const Placeholders = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$f);
  const classes = getStyles(styles$c, ['.placeholders']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
Placeholders.displayName = 'Placeholders';
Placeholders.propTypes = propTypes$g;

/*
$placeholder-opacity-max:           .5;
$placeholder-opacity-min:           .2;
*/

const ProgressContext = /*#__PURE__*/React__default["default"].createContext();
ProgressContext.displayName = 'ProgressContext';

const _excluded$e = ["children", "value", "style", "textStyle"];
var _templateObject$b, _templateObject2$8;
const propTypes$f = {
  children: PropTypes__default["default"].node,
  value: PropTypes__default["default"].number.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$b = StyleSheet.create({
  '.progress-bar': css(_templateObject$b || (_templateObject$b = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: column;\n    justify-content: center;\n    overflow: hidden;\n    background-color: $progress-bar-bg;\n    // @include transition($progress-bar-transition);\n  "]))),
  '.progress-bar --text': css(_templateObject2$8 || (_templateObject2$8 = _taggedTemplateLiteral(["\n    color: $progress-bar-color;\n    text-align: center;\n    // white-space: nowrap;\n  "])))
});
const ROUND_PRECISION = 1000;
const getPercentage = (value, min, max) => {
  const percentage = (value - min) / (max - min) * 100;
  return Math.round(percentage * ROUND_PRECISION) / ROUND_PRECISION;
};
const ProgressBar = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      value,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$e);
  const {
    min,
    max
  } = useForcedContext(ProgressContext);
  const classes = getStyles(styles$b, ['.progress-bar']);
  const textClasses = getStyles(styles$b, ['.progress-bar --text']);

  // composite component
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: "progressbar",
    accessibilityValueNow: value,
    accessibilityValueMin: min,
    accessibilityValueMax: max,
    style: [classes, style, {
      width: "".concat(getPercentage(value, min, max), "%")
    }]
  }), children && /*#__PURE__*/React__default["default"].createElement(Text, {
    style: [textClasses, textStyle]
  }, children));
});
ProgressBar.displayName = 'ProgressBar';
ProgressBar.propTypes = propTypes$f;

function useProgress(min, max) {
  return React.useMemo(() => ({
    min,
    max
  }), [min, max]);
}

const _excluded$d = ["children", "min", "max", "style", "textStyle"];
var _templateObject$a, _templateObject2$7;
const propTypes$e = {
  children: PropTypes__default["default"].node.isRequired,
  min: PropTypes__default["default"].number,
  max: PropTypes__default["default"].number,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$a = StyleSheet.create({
  '.progress': css(_templateObject$a || (_templateObject$a = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    height: $progress-height;\n    overflow: hidden; // force rounded corners by cropping it\n    background-color: $progress-bg;\n    border-radius: $progress-border-radius;\n    // @include box-shadow($progress-box-shadow);\n  "]))),
  '.progress --text': css(_templateObject2$7 || (_templateObject2$7 = _taggedTemplateLiteral(["\n    font-size: $progress-font-size;\n    line-height: $progress-font-size * $line-height-base; // added for bootstrap-rn\n  "])))
});
const Progress = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      min = 0,
      max = 100,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$d);
  const progress = useProgress(min, max);
  const classes = getStyles(styles$a, ['.progress']);
  const textClasses = getStyles(styles$a, ['.progress --text']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), /*#__PURE__*/React__default["default"].createElement(ProgressContext.Provider, {
    value: progress
  }, children));
});
Progress.displayName = 'Progress';
Progress.propTypes = propTypes$e;
Progress.Bar = ProgressBar;

const _excluded$c = ["children", "lead", "style"];
var _templateObject$9, _templateObject2$6;
const propTypes$d = {
  children: PropTypes__default["default"].node.isRequired,
  lead: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$9 = StyleSheet.create({
  paragraph: css(_templateObject$9 || (_templateObject$9 = _taggedTemplateLiteral(["\n    margin-top: 0;\n    margin-bottom: $paragraph-margin-bottom;\n  "]))),
  '.lead': css(_templateObject2$6 || (_templateObject2$6 = _taggedTemplateLiteral(["\n    font-size: $lead-font-size;\n    line-height: $lead-font-size * $line-height-base; // added for bootstrap-rn\n    font-weight: $lead-font-weight;\n  "])))
});
const Heading = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      lead,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$c);
  const classes = getStyles(styles$9, ['paragraph', lead && '.lead']);

  // Accessiblity role paragraph is only supported on web.
  const role = reactNative.Platform.OS === 'web' ? 'paragraph' : null;
  return /*#__PURE__*/React__default["default"].createElement(Text, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style]
  }), children);
});
Heading.displayName = 'Heading';
Heading.propTypes = propTypes$d;

const _excluded$b = ["children", "active", "disabled", "style", "textStyle"];
var _templateObject$8, _templateObject2$5, _templateObject3$2, _templateObject4$1, _templateObject5$1;
const propTypes$c = {
  children: PropTypes__default["default"].node.isRequired,
  active: PropTypes__default["default"].bool,
  disabled: PropTypes__default["default"].bool,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$8 = StyleSheet.create({
  '.pagination-item': css(_templateObject$8 || (_templateObject$8 = _taggedTemplateLiteral(["\n    padding-bottom: $pagination-padding-y;\n    padding-top: $pagination-padding-y;\n    padding-left: $pagination-padding-x;\n    padding-right: $pagination-padding-x;\n    border: $list-group-border-width solid $list-group-border-color;\n\n    &:hover {\n      color: $pagination-hover-color;\n      background-color: $pagination-hover-bg;\n      border-color: $pagination-hover-border-color;\n    }\n\n    &:focus {\n      color: $pagination-focus-color;\n      background-color: $pagination-focus-bg;\n      //$pagination-focus-box-shadow:\n      //$pagination-focus-outline:\n    }\n  "]))),
  '.pagination-item:first-child': css(_templateObject2$5 || (_templateObject2$5 = _taggedTemplateLiteral(["\n    border-top-left-radius: $list-group-border-radius;\n    border-bottom-left-radius: $list-group-border-radius;\n  "]))),
  '.pagination-item:last-child': css(_templateObject3$2 || (_templateObject3$2 = _taggedTemplateLiteral(["\n    border-top-right-radius: $list-group-border-radius;\n    border-bottom-right-radius: $list-group-border-radius;\n  "]))),
  '.pagination-item.active': css(_templateObject4$1 || (_templateObject4$1 = _taggedTemplateLiteral(["\n    color: $pagination-active-color;\n    background-color: $pagination-active-bg;\n    border-color: $pagination-active-border-color;\n  "]))),
  '.pagination-item.disabled': css(_templateObject5$1 || (_templateObject5$1 = _taggedTemplateLiteral(["\n    color: $pagination-disabled-color;\n    background-color: $pagination-disabled-bg;\n    border-color: $pagination-disabled-border-color;\n  "])))
});
const PaginationItem = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      active = false,
      disabled = false,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$b);
  const {
    first,
    last
  } = useForcedContext(ListContext);
  const classes = getStyles(styles$8, ['.pagination-item', first && '.pagination-item:first-child', last && '.pagination-item:last-child', active && '.pagination-item.active', disabled && '.pagination-item.disabled']);
  const textClasses = getStyles(styles$8, [active && '.pagination-item.active', disabled && '.pagination-item.disabled']);
  const role = reactNative.Platform.OS === 'web' ? 'listitem' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
PaginationItem.displayName = 'PaginationItem';
PaginationItem.propTypes = propTypes$c;

/*
$pagination-padding-y:              .375rem;
$pagination-padding-x:              .75rem;
$pagination-padding-y-sm:           .25rem;
$pagination-padding-x-sm:           .5rem;
$pagination-padding-y-lg:           .75rem;
$pagination-padding-x-lg:           1.5rem;

$pagination-color:                  $link-color;
$pagination-bg:                     $white;
$pagination-border-width:           $border-width;
$pagination-border-radius:          $border-radius;
$pagination-margin-start:           -$pagination-border-width;
$pagination-border-color:           $gray-300;

$pagination-focus-color:            $link-hover-color;
$pagination-focus-bg:               $gray-200;
$pagination-focus-box-shadow:       $input-btn-focus-box-shadow;
$pagination-focus-outline:          0;

$pagination-hover-color:            $link-hover-color;
$pagination-hover-bg:               $gray-200;
$pagination-hover-border-color:     $gray-300;

$pagination-active-color:           $component-active-color;
$pagination-active-bg:              $component-active-bg;
$pagination-active-border-color:    $pagination-active-bg;

$pagination-disabled-color:         $gray-600;
$pagination-disabled-bg:            $white;
$pagination-disabled-border-color:  $gray-300;

$pagination-transition:              color .15s ease-in-out, background-color .15s ease-in-out, border-color .15s ease-in-out, box-shadow .15s ease-in-out;

$pagination-border-radius-sm:       $border-radius-sm;
$pagination-border-radius-lg:       $border-radius-lg;

*/

const _excluded$a = ["children", "style"];
var _templateObject$7;
const propTypes$b = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$7 = StyleSheet.create({
  '.pagination': css(_templateObject$7 || (_templateObject$7 = _taggedTemplateLiteral(["\n    background-color: $white;\n    flex-direction: row;\n  "])))
});
const Pagination = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$a);
  const list = useList(children);
  const classes = getStyles(styles$7, ['.pagination']);
  const role = reactNative.Platform.OS === 'web' ? 'list' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    style: [classes, style]
  }), list);
});
Pagination.displayName = 'Pagination';
Pagination.propTypes = propTypes$b;
Pagination.Item = PaginationItem;

const RadioContext = /*#__PURE__*/React__default["default"].createContext();
RadioContext.displayName = 'RadioContext';

const _excluded$9 = ["children", "selectedValue", "onValueChange", "disabled"];
const propTypes$a = {
  children: PropTypes__default["default"].node.isRequired,
  selectedValue: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].number, PropTypes__default["default"].string, PropTypes__default["default"].object]),
  onValueChange: PropTypes__default["default"].func,
  disabled: PropTypes__default["default"].bool
};
const RadioGroup = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      selectedValue,
      onValueChange = () => {},
      disabled = false
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$9);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: "radiogroup"
  }), /*#__PURE__*/React__default["default"].createElement(RadioContext.Provider, {
    value: {
      selectedValue,
      onValueChange,
      disabled
    }
  }, children));
});
RadioGroup.displayName = 'RadioGroup';
RadioGroup.propTypes = propTypes$a;

const _excluded$8 = ["value"];
const propTypes$9 = {
  value: PropTypes__default["default"].oneOfType([PropTypes__default["default"].bool, PropTypes__default["default"].number, PropTypes__default["default"].string, PropTypes__default["default"].object])
};
const Radio = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      value
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$8);
  const {
    selectedValue,
    onValueChange,
    disabled
  } = useForcedContext(RadioContext);
  return /*#__PURE__*/React__default["default"].createElement(FormCheckInput, _extends({}, elementProps, {
    ref: ref,
    type: "radio",
    value: value === selectedValue,
    onValueChange: () => {
      onValueChange(value);
    },
    disabled: disabled
  }));
});
Radio.displayName = 'Radio';
Radio.propTypes = propTypes$9;
Radio.Group = RadioGroup;

const _excluded$7 = ["children", "style"];
var _templateObject$6;
const propTypes$8 = {
  children: PropTypes__default["default"].node.isRequired,
  rows: PropTypes__default["default"].number,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$6 = StyleSheet.create({
  '.row': css(_templateObject$6 || (_templateObject$6 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    flex-wrap: wrap;\n    margin-top: 0;\n    margin-right: -0.5 * $grid-gutter-width;\n    margin-left: -0.5 * $grid-gutter-width;\n  "])))
});
const Row = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$7);
  const classes = getStyles(styles$6, ['.row']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), children);
});
Row.displayName = 'Row';
Row.propTypes = propTypes$8;

const Switch = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const elementProps = _extends({}, (_objectDestructuringEmpty(props), props));
  return /*#__PURE__*/React__default["default"].createElement(FormCheckInput, _extends({}, elementProps, {
    ref: ref,
    type: "switch"
  }));
});
Switch.displayName = 'Switch';

const _excluded$6 = ["variant", "color", "size", "style"];
var _templateObject$5, _templateObject2$4, _templateObject3$1, _templateObject4, _templateObject5, _templateObject6;
const propTypes$7 = {
  variant: PropTypes__default["default"].oneOf(['border', 'grow']),
  color: PropTypes__default["default"].oneOf(Object.keys(THEME_COLORS)),
  size: PropTypes__default["default"].oneOf(['sm']),
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$5 = StyleSheet.create(_objectSpread2(_objectSpread2(_objectSpread2({
  '.spinner-border': css(_templateObject$5 || (_templateObject$5 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $spinner-width;\n    height: $spinner-height;\n    // vertical-align: $spinner-vertical-align;\n    border-width: $spinner-border-width;\n    border-style: solid;\n    border-top-color: $body-color;\n    border-bottom-color: $body-color;\n    border-left-color: $body-color;\n    // workaround for issue https://github.com/facebook/react-native/issues/34722\n    border-right-color: rgba(0, 0, 0, 0.01); // transparent;\n    border-radius: $spinner-width * 50%;\n    // animation: $spinner-animation-speed linear infinite spinner-border;\n  "])))
}, each(THEME_COLORS, (color, value) => ({
  [".spinner-border-".concat(color)]: css(_templateObject2$4 || (_templateObject2$4 = _taggedTemplateLiteral(["\n      border-top-color: ", ";\n      border-bottom-color: ", ";\n      border-left-color: ", ";\n    "])), value, value, value)
}))), {}, {
  '.spinner-border-sm': css(_templateObject3$1 || (_templateObject3$1 = _taggedTemplateLiteral(["\n    width: $spinner-width-sm;\n    height: $spinner-height-sm;\n    border-width: $spinner-border-width-sm;\n  "]))),
  '.spinner-grow': css(_templateObject4 || (_templateObject4 = _taggedTemplateLiteral(["\n    // display: inline-block;\n    width: $spinner-width;\n    height: $spinner-height;\n    // vertical-align: $spinner-vertical-align;\n    background-color: $body-color;\n    border-radius: $spinner-width * 50%;\n    opacity: 0;\n    // animation: $spinner-animation-speed linear infinite spinner-grow;\n  "])))
}, each(THEME_COLORS, (color, value) => ({
  [".spinner-grow-".concat(color)]: css(_templateObject5 || (_templateObject5 = _taggedTemplateLiteral(["\n      background-color: ", ";\n    "])), value)
}))), {}, {
  '.spinner-grow-sm': css(_templateObject6 || (_templateObject6 = _taggedTemplateLiteral(["\n    width: $spinner-width-sm;\n    height: $spinner-height-sm;\n  "])))
}));
const AnimatedView = reactNative.Animated.createAnimatedComponent(View);
const getAnimationStyle = (variant, animation) => {
  switch (variant) {
    case 'border':
      return {
        transform: [{
          rotate: animation.interpolate({
            inputRange: [0, 1],
            outputRange: ['0deg', '360deg']
          })
        }]
      };
    case 'grow':
      return {
        transform: [{
          scale: animation.interpolate({
            inputRange: [0, 0.5, 1],
            outputRange: [0, 1, 1]
          })
        }],
        opacity: animation.interpolate({
          inputRange: [0, 0.5, 1],
          outputRange: [0, 1, 0]
        })
      };
    default:
      throw new Error('Unknown spinner variant.');
  }
};
const Spinner = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      variant = 'border',
      color,
      size,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$6);
  const classes = getStyles(styles$5, [".spinner-".concat(variant), color && ".spinner-".concat(variant, "-").concat(color), size === 'sm' && ".spinner-".concat(variant, "-sm")]);
  const role = reactNative.Platform.OS === 'web' ? 'status' : null;
  const animation = React.useMemo(() => new reactNative.Animated.Value(0), []);
  React.useEffect(() => {
    const duration = parseFloat(StyleSheet.value('spinner-animation-speed')) * 1000;
    reactNative.Animated.loop(reactNative.Animated.timing(animation, {
      toValue: 1,
      duration,
      easing: reactNative.Easing.linear,
      useNativeDriver: reactNative.Platform.OS !== 'web'
    })).start();
  }, []);
  return /*#__PURE__*/React__default["default"].createElement(AnimatedView, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: role,
    accessibilityHidden: true,
    style: [classes, getAnimationStyle(variant, animation), style]
  }));
});
Spinner.displayName = 'Spinner';
Spinner.propTypes = propTypes$7;

function useTabbable(defaultActiveTarget, controlledActiveTarget, onChange) {
  const identifier = useIdentifier('tabbable');
  const [activeTarget, setActiveTarget] = useControlledState(defaultActiveTarget, controlledActiveTarget, onChange);
  return React.useMemo(() => ({
    identifier,
    activeTarget,
    setActiveTarget
  }), [activeTarget]);
}

const propTypes$6 = {
  children: PropTypes__default["default"].node.isRequired,
  defaultActiveTarget: PropTypes__default["default"].string.isRequired,
  activeTarget: PropTypes__default["default"].string,
  onChange: PropTypes__default["default"].func
};
const TabProvider = props => {
  const {
    children,
    defaultActiveTarget,
    activeTarget,
    onChange
  } = props;
  const tabbable = useTabbable(defaultActiveTarget, activeTarget, onChange);
  return /*#__PURE__*/React__default["default"].createElement(TabContext.Provider, {
    value: tabbable
  }, children);
};
TabProvider.displayName = 'TabProvider';
TabProvider.propTypes = propTypes$6;

const propTypes$5 = {
  children: PropTypes__default["default"].node.isRequired
};
const TabContent = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const elementProps = _extends({}, (_objectDestructuringEmpty(props), props));
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref
  }));
});
TabContent.displayName = 'TabContent';
TabContent.propTypes = propTypes$5;

const _excluded$5 = ["id", "style"];
var _templateObject$4, _templateObject2$3;
const propTypes$4 = {
  children: PropTypes__default["default"].node.isRequired,
  id: PropTypes__default["default"].string.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles$4 = StyleSheet.create({
  '.tab-pane': css(_templateObject$4 || (_templateObject$4 = _taggedTemplateLiteral(["\n    display: none;\n  "]))),
  '.active': css(_templateObject2$3 || (_templateObject2$3 = _taggedTemplateLiteral(["\n    display: flex;\n  "])))
});
const TabPane = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      id: target,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$5);
  const tabbable = useForcedContext(TabContext);
  const classes = getStyles(styles$4, ['.tab-pane', tabbable.activeTarget === target && '.active']);
  const id = getElementId(tabbable.identifier, target);

  // Accessiblity role tabpanel is only supported on web.
  const role = reactNative.Platform.OS === 'web' ? 'tabpanel' : null;
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    nativeID: id,
    accessibilityRole: role,
    accessibilityLabelledBy: "".concat(id, "-tab"),
    style: [classes, style]
  }));
});
TabPane.displayName = 'TabPane';
TabPane.propTypes = propTypes$4;

const _excluded$4 = ["target", "onPress"];
function useToggleTab(props) {
  const context = useForcedContext(TabContext);
  const {
      target,
      onPress: handlePress
    } = props,
    restProps = _objectWithoutProperties(props, _excluded$4);
  invariant__default["default"](target, 'Prop "target" is required.');
  const id = getElementId(context.identifier, target);
  const active = context.activeTarget === target;
  return _objectSpread2(_objectSpread2({}, restProps), {}, {
    nativeID: "".concat(id, "-tab"),
    onPress: event => {
      if (handlePress) handlePress(event);
      event.preventDefault();
      context.setActiveTarget(target);
    },
    active,
    accessibilityRole: 'tab',
    accessibilityControls: id,
    accessibilitySelected: active
  });
}

const Tab = {};
Tab.Context = TabContext;
Tab.Provider = TabProvider;
Tab.Content = TabContent;
Tab.Pane = TabPane;
Tab.useToggle = useToggleTab;

const _excluded$3 = ["children", "style", "textStyle"];
var _templateObject$3, _templateObject2$2;
const propTypes$3 = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$3 = StyleSheet.create({
  '.toast-header': css(_templateObject$3 || (_templateObject$3 = _taggedTemplateLiteral(["\n    display: flex;\n    flex-direction: row; // added for bootstrap-rn\n    align-items: center;\n    padding: $toast-padding-y $toast-padding-x;\n    background-color: $toast-header-background-color;\n    // background-clip: padding-box;\n    border-bottom-width: $toast-border-width;\n    border-style: solid;\n    border-color: $toast-header-border-color;\n    border-top-left-radius: ", ";\n    border-top-right-radius: ", ";\n  "])), subtract(t => t['toast-border-radius'], t => t['toast-border-width']), subtract(t => t['toast-border-radius'], t => t['toast-border-width'])),
  '.toast-header --text': css(_templateObject2$2 || (_templateObject2$2 = _taggedTemplateLiteral(["\n    color: $toast-header-color;\n  "])))
});
const ToastHeader = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$3);
  const classes = getStyles(styles$3, ['.toast-header']);
  const textClasses = getStyles(styles$3, ['.toast-header --text']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
ToastHeader.displayName = 'ToastHeader';
ToastHeader.propTypes = propTypes$3;

const _excluded$2 = ["children", "style", "textStyle"];
var _templateObject$2, _templateObject2$1;
const propTypes$2 = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$2 = StyleSheet.create({
  '.toast-body': css(_templateObject$2 || (_templateObject$2 = _taggedTemplateLiteral(["\n    padding: $toast-padding-x; // apply to both vertical and horizontal\n  "]))),
  '.toast-body --text': css(_templateObject2$1 || (_templateObject2$1 = _taggedTemplateLiteral(["\n    @include platform(web) {\n      word-wrap: break-word;\n    }\n  "])))
});
const ToastBody = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$2);
  const classes = getStyles(styles$2, ['.toast-body']);
  const textClasses = getStyles(styles$2, ['.toast-body --text']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
ToastBody.displayName = 'ToastBody';
ToastBody.propTypes = propTypes$2;

const ToastContainerContext = /*#__PURE__*/React__default["default"].createContext();
ToastContainerContext.displayName = 'ToastContainerContext';

const _excluded$1 = ["children", "style", "textStyle"];
var _templateObject$1, _templateObject2, _templateObject3;
const propTypes$1 = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any,
  // eslint-disable-next-line react/forbid-prop-types
  textStyle: PropTypes__default["default"].any
};
const styles$1 = StyleSheet.create({
  '.toast': css(_templateObject$1 || (_templateObject$1 = _taggedTemplateLiteral(["\n    width: $toast-max-width;\n    max-width: 100%;\n    // pointer-events: auto;\n    background-color: $toast-background-color;\n    // background-clip: padding-box;\n    border: $toast-border-width solid $toast-border-color;\n    // box-shadow: $toast-box-shadow;\n    border-radius: $toast-border-radius;\n  "]))),
  '.toast --text': css(_templateObject2 || (_templateObject2 = _taggedTemplateLiteral(["\n    font-size: $toast-font-size;\n    line-height: $toast-font-size * $line-height-base; // added for bootstrap-rn\n    color: $toast-color;\n  "]))),
  '.toast-container > :not(:last-child)': css(_templateObject3 || (_templateObject3 = _taggedTemplateLiteral(["\n    margin-bottom: $toast-spacing;\n  "])))
});
const Toast = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style,
      textStyle
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded$1);
  const listItem = React.useContext(ListContext);
  const container = React.useContext(ToastContainerContext);
  const classes = getStyles(styles$1, ['.toast', container && !listItem.last && '.toast-container > :not(:last-child)']);
  const textClasses = getStyles(styles$1, ['.toast --text']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    accessibilityRole: "alert",
    accessibilityLive: "assertive",
    accessibilityAtomic: true,
    style: [classes, style],
    textStyle: [textClasses, textStyle]
  }), children);
});
Toast.displayName = 'Toast';
Toast.propTypes = propTypes$1;
Toast.Header = ToastHeader;
Toast.Body = ToastBody;

const _excluded = ["children", "style"];
var _templateObject;
const propTypes = {
  children: PropTypes__default["default"].node.isRequired,
  // eslint-disable-next-line react/forbid-prop-types
  style: PropTypes__default["default"].any
};
const styles = StyleSheet.create({
  '.toast-container': css(_templateObject || (_templateObject = _taggedTemplateLiteral(["\n    width: 100%; // max-content;\n    max-width: 100%;\n    // pointer-events: none;\n  "])))
});
const ToastContainer = /*#__PURE__*/React__default["default"].forwardRef((props, ref) => {
  const {
      children,
      style
    } = props,
    elementProps = _objectWithoutProperties(props, _excluded);
  const list = useList(children);
  const classes = getStyles(styles, ['.toast-container']);
  return /*#__PURE__*/React__default["default"].createElement(View, _extends({}, elementProps, {
    ref: ref,
    style: [classes, style]
  }), /*#__PURE__*/React__default["default"].createElement(ToastContainerContext.Provider, {
    value: true
  }, list));
});
ToastContainer.displayName = 'ToastContainer';
ToastContainer.propTypes = propTypes;

function useFixedElement() {
  const context = React.useContext(Context);
  const ref = React.useRef();
  React.useEffect(() => {
    const link = context.addFixedElement(ref);
    return () => {
      link.remove();
    };
  }, []);
  return ref;
}

Object.defineProperty(exports, 'PortalProvider', {
  enumerable: true,
  get: function () { return overlays.PortalProvider; }
});
exports.Alert = Alert;
exports.Badge = Badge;
exports.Blockquote = Blockquote;
exports.Body = Body;
exports.Breadcrumb = Breadcrumb;
exports.Button = Button;
exports.ButtonGroup = ButtonGroup;
exports.ButtonToolbar = ButtonToolbar;
exports.Card = Card;
exports.Caret = Caret;
exports.Checkbox = Checkbox;
exports.CloseButton = CloseButton;
exports.Code = Code;
exports.Col = Col;
exports.Collapse = Collapse;
exports.Container = Container;
exports.Context = Context;
exports.DisplayHeading = DisplayHeading;
exports.Dropdown = Dropdown;
exports.Feedback = Feedback;
exports.FormCheck = FormCheck;
exports.FormLabel = FormLabel;
exports.FormText = FormText;
exports.Heading = Heading$1;
exports.Image = Image;
exports.ImageBackground = ImageBackground;
exports.Input = Input;
exports.Label = Label;
exports.Link = Link;
exports.ListGroup = ListGroup;
exports.Modal = Modal;
exports.Nav = Nav;
exports.Navbar = Navbar;
exports.Offcanvas = Offcanvas;
exports.Pagination = Pagination;
exports.Paragraph = Heading;
exports.Picker = Picker;
exports.Placeholders = Placeholders;
exports.Popover = Popover;
exports.Pressable = Pressable;
exports.Progress = Progress;
exports.Provider = Provider;
exports.Radio = Radio;
exports.Row = Row;
exports.ScrollView = ScrollView;
exports.Spinner = Spinner;
exports.StyleSheet = StyleSheet;
exports.Switch = Switch;
exports.Tab = Tab;
exports.Text = Text;
exports.TextInput = TextInput;
exports.Toast = Toast;
exports.ToastContainer = ToastContainer;
exports.Tooltip = Tooltip;
exports.View = View;
exports.add = add;
exports.colorContrast = colorContrast;
exports.css = css;
exports.divide = divide;
exports.escapeSvg = escapeSvg;
exports.fn = fn;
exports.injectPopover = injectPopover;
exports.injectTooltip = injectTooltip;
exports.makeTheme = makeTheme;
exports.makeUtilities = makeUtilities;
exports.shadeColor = shadeColor;
exports.shiftColor = shiftColor;
exports.subtract = subtract;
exports.tintColor = tintColor;
exports.useFixedElement = useFixedElement;
exports.useMedia = useMedia;
exports.useStyle = useStyle;
